@@ -60,9 +60,9 @@ class Set(WMLResource):
             raise WMLClientError(u'Spaces API are not supported in Watson Studio Desktop.')
 
         if self._client.CLOUD_PLATFORM_SPACES or self._client.ICP_PLATFORM_SPACES:
-            space_endpoint = self._href_definitions.get_platform_space_href(space_uid)
+            space_endpoint = self._client.service_instance._href_definitions.get_platform_space_href(space_uid)
         else:
-            space_endpoint = self._href_definitions.get_space_href(space_uid)
+            space_endpoint = self._client.service_instance._href_definitions.get_space_href(space_uid)
 
         if not self._ICP:
             space_details = requests.get(space_endpoint, headers=self._client._get_headers())
@@ -136,13 +136,14 @@ class Set(WMLResource):
                     print("Unsetting the space_id ...")
                 self._client.default_space_id = None
 
-                project_endpoint = self._href_definitions.get_project_href(project_id)
+                project_endpoint = self._client.service_instance._href_definitions.get_project_href(project_id)
                 project_details = requests.get(project_endpoint, headers=self._client._get_headers(), verify=False)
                 if project_details.status_code != 200 and project_details.status_code != 204:
                     print("Failed to set Project: " + project_details.text)
                     self._client.default_project_id = None
                     return "FAILURE"
                 else:
+                    self._client.project_type = project_details.json()['entity']['storage']['type']
                     if self._client.CLOUD_PLATFORM_SPACES:
                         instance_id = "not_found"
                         if 'compute' in project_details.json()['entity'].keys():
@@ -160,6 +161,9 @@ class Set(WMLResource):
                             self._client.service_instance = ServiceInstanceNewPlan(self._client)
                             self._client.service_instance.details = None
 
+                    else:
+                        self._client.service_instance = ServiceInstanceNewPlan(self._client)
+
                     return "SUCCESS"
 
             else:
