@@ -167,6 +167,9 @@ class APIClient:
                     if '4.0' == wml_credentials[u'version'].lower():
                         self.ICP_PLATFORM_SPACES = True
                         self.ICP_40 = True
+                        if 'bedrock_url' not in wml_credentials:
+                            self.wml_credentials['bedrock_url'] = '.'.join(['https://cp-console'] + wml_credentials['url'].split('.')[1:])
+                            self._is_bedrock_url_autogenerated = True
 
                 else:
                     if 'version' in wml_credentials.keys() and \
