@@ -456,9 +456,11 @@ class BaseDeployment(ABC):
         else:
             raise TypeError('X should be of type pandas.DataFrame.')
 
+        transaction_id = kwargs.get('transaction_id')
+
         scoring_payload = {self._target_workspace.wml_client.deployments.ScoringMetaNames.INPUT_DATA: [payload]}
 
-        score = self._target_workspace.wml_client.deployments.score(self.id, scoring_payload)
+        score = self._target_workspace.wml_client.deployments.score(self.id, scoring_payload, transaction_id=transaction_id)
 
         return score
 
