@@ -172,6 +172,7 @@ class Batch(BaseDeployment):
     def run_job(self,
                 payload: Union[DataFrame, List[DataConnection]],
                 output_data_reference: 'DataConnection' = None,
+                transaction_id: str = None,
                 background_mode: 'bool' = True) -> Union[Dict, Dict[str, List], DataConnection]:
         """
         Batch scoring job on WML. Payload or Payload data reference is required. It is passed to the WML where model have been deployed.
@@ -185,6 +186,9 @@ class Batch(BaseDeployment):
              DataConnection to the output COS for storing predictions.
              Required nly when DataConnections are as a payload.
 
+        transaction_id: str, optional
+            Can be used to indicate under which id the records will be saved into payload table in IBM OpenScale.
+
         background_mode: bool, optional
             Indicator if score() method will run in background (async) or (sync).
 
