@@ -545,7 +545,7 @@ class Deployments(WMLResource):
 
 
     @docstring_parameter({'str_type': STR_TYPE_NAME})
-    def score(self,deployment_id, meta_props):
+    def score(self,deployment_id, meta_props, transaction_id=None):
         """
                     Make scoring requests against deployed artifact.
 
@@ -637,6 +637,9 @@ class Deployments(WMLResource):
 
         headers = self._client._get_headers()
 
+        if transaction_id is not None:
+            headers.update({'x-global-transaction-id': transaction_id})
+
         if self._client.CLOUD_PLATFORM_SPACES or self._client.ICP_PLATFORM_SPACES:
             scoring_url = self._wml_credentials["url"] + "/ml/v4/deployments/" + deployment_id + "/predictions"
         else:
@@ -1134,7 +1137,7 @@ class Deployments(WMLResource):
 
         return self._handle_response(202, u'scoring asynchronously', response_scoring)
 
-    def create_job(self, deployment_id, meta_props, retention=None):
+    def create_job(self, deployment_id, meta_props, retention=None, transaction_id=None):
         """
             Create an asynchronous deployment job.
 
@@ -1303,7 +1306,7 @@ class Deployments(WMLResource):
             payload.update({"deployment": {"href": "/v4/deployments/" + deployment_id}})
 
         return self._score_async(deployment_id, payload,
-                                 transaction_id=None,
+                                 transaction_id=transaction_id,
                                  retention=retention)
 
     def get_job_details(self, job_uid=None, limit=None):
