@@ -228,6 +228,13 @@ class WMLEngine(BaseEngine):
                 'positive_label'] = self._auto_pipelines_parameters.get('positive_label')
         # --- end note
 
+        # note: only pass daub_give_priority_to_runtime when is not None
+        if self._auto_pipelines_parameters.get('daub_give_priority_to_runtime'):
+            self._wml_pipeline_metadata[self._wml_client.pipelines.ConfigurationMetaNames.DOCUMENT][
+                'pipelines'][0]['nodes'][0]['parameters']['optimization'][
+                'daub_runtime_ranking_power'] = self._auto_pipelines_parameters.get('daub_give_priority_to_runtime')
+        # --- end note
+
         # note: only pass excel_sheet when it is different than 0
         if self._auto_pipelines_parameters.get('excel_sheet') != 0:
             self._wml_pipeline_metadata[self._wml_client.pipelines.ConfigurationMetaNames.DOCUMENT][
@@ -620,7 +627,7 @@ class WMLEngine(BaseEngine):
                       or (self._auto_pipelines_parameters['prediction_type'] == 'classification'
                           and 'multi_class_classification' in str(run_params))):
 
-                    one_vs_all_data = WMLEngine._get_data_from_property_or_file('one_vs_all',
+                    one_vs_all_data = self._get_data_from_property_or_file('one_vs_all',
                                                    pipeline['context'].get('multi_class_classification', {'one_vs_all': []}),
                                                    run_params['entity']['results_reference'], [{}, {}])
 
@@ -632,7 +639,7 @@ class WMLEngine(BaseEngine):
                     pipeline_parameters['features_importance'] = self._get_features_importance(pipeline)
 
                 elif self._auto_pipelines_parameters['prediction_type'] == 'forecasting':
-                    data = WMLEngine._get_data_from_property_or_file('daub_status', pipeline['context']['timeseries'],
+                    data = self._get_data_from_property_or_file('daub_status', pipeline['context']['timeseries'],
                                                                      run_params['entity']['results_reference'],
                                                                      [{}, {}])
                     if 'visualization' in data:
@@ -671,21 +678,20 @@ class WMLEngine(BaseEngine):
 
         return metrics
 
-    @staticmethod
-    def _get_data_from_property_or_file(property_name: str, details: Dict, results_reference: Dict, default_value: List) -> List:
+    def _get_data_from_property_or_file(self, property_name: str, details: Dict, results_reference: Dict, default_value: List) -> List:
         if f'{property_name}_location' in details:
             path = details[f'{property_name}_location']
             conn = DataConnection._from_dict(results_reference)
+            conn._wml_client = self._wml_client
             return conn._download_json_file(path)
         elif property_name in details:  # TODO probably should be removed in future
             return details[property_name]
         else:
             return default_value
 
-    @staticmethod
-    def _get_confusion_matrix(pipeline_details: Dict, run_params: Dict) -> 'DataFrame':
+    def _get_confusion_matrix(self, pipeline_details: Dict, run_params: Dict) -> 'DataFrame':
         """Retrieve confusion matrix data from particular pipeline details or from file. (Binary)"""
-        data = WMLEngine._get_data_from_property_or_file('confusion_matrix',
+        data = self._get_data_from_property_or_file('confusion_matrix',
                                                          pipeline_details['context'].get('binary_classification', {}),
                                                          run_params['entity']['results_reference'],
                                                          [{}, {}])
@@ -711,10 +717,9 @@ class WMLEngine(BaseEngine):
 
         return features_importance_data
 
-    @staticmethod
-    def _get_roc_curve(pipeline_details: Dict, run_params: Dict) -> 'DataFrame':
+    def _get_roc_curve(self, pipeline_details: Dict, run_params: Dict) -> 'DataFrame':
         """Retrieve roc curve data from particular pipeline details or from file. (Binary)"""
-        data = WMLEngine._get_data_from_property_or_file('roc_curve',
+        data = self._get_data_from_property_or_file('roc_curve',
                                                          pipeline_details['context'].get('binary_classification', {}),
                                                          run_params['entity']['results_reference'],
                                                          [])
@@ -730,11 +735,10 @@ class WMLEngine(BaseEngine):
 
         return roc_curve
 
-    @staticmethod
-    def _get_one_vs_all(one_vs_all_data: List, run_params: Dict, option: str) -> 'DataFrame':
+    def _get_one_vs_all(self, one_vs_all_data: List, run_params: Dict, option: str) -> 'DataFrame':
         """Retrieve roc curve or confusion matrix data from particular pipeline details. (Multiclass)"""
         if option == 'confusion_matrix':
-            confusion_matrix_data = [WMLEngine._get_data_from_property_or_file('confusion_matrix', item,
+            confusion_matrix_data = [self._get_data_from_property_or_file('confusion_matrix', item,
                                      run_params['entity']['results_reference'], [{}, {}]) for item in one_vs_all_data]
 
             columns = ['fn', 'fp', 'tn', 'tp', 'true_class']
@@ -747,7 +751,7 @@ class WMLEngine(BaseEngine):
             return confusion_matrix_data
 
         elif option == 'roc_curve':
-            roc_curve_data = [WMLEngine._get_data_from_property_or_file('roc_curve', item,
+            roc_curve_data = [self._get_data_from_property_or_file('roc_curve', item,
                               run_params['entity']['results_reference'], []) for item in one_vs_all_data]
 
             true_classes = [item['true_class'] for item in roc_curve_data]
