@@ -142,6 +142,7 @@ class RemoteAutoPipelines(BaseAutoPipelines):
                  drop_duplicates: bool = True,
                  text_processing: bool = True,
                  word2vec_feature_number: int = None,
+                 daub_give_priority_to_runtime: float = None,
                  notebooks=False,
                  autoai_pod_version=None,
                  obm_pod_version=None,
@@ -175,7 +176,8 @@ class RemoteAutoPipelines(BaseAutoPipelines):
             'autoai_pod_version': autoai_pod_version,
             'obm_pod_version': obm_pod_version,
             'text_processing': text_processing,
-            'word2vec_feature_number': word2vec_feature_number
+            'word2vec_feature_number': word2vec_feature_number,
+            'daub_give_priority_to_runtime': daub_give_priority_to_runtime
         }
         self._engine: 'WMLEngine' = engine
         self._engine.initiate_remote_resources(params=self.params, **kwargs)
@@ -336,6 +338,12 @@ class RemoteAutoPipelines(BaseAutoPipelines):
         training_data_reference = validate_source_data_connections(training_data_reference, workspace=self._workspace,
                                                                    deployment=False)
 
+        # note: for FSLocation we are creating asset and changing location to AssetLocation
+        # so href is not set properly, setter on wml_client will resolve that issue
+        for conn in training_data_reference:
+            conn._wml_client = self._workspace.wml_client
+        # --- end note
+
         # note: if user did not provide results storage information, use default ones
         if training_results_reference is None:
             if isinstance(training_data_reference[0].location, S3Location):
