@@ -212,7 +212,7 @@ class AutoPipelinesRuns(BaseAutoPipelinesRuns):
 
             if kb_parameters.get('train_sample_rows_test_size'):
                 params['train_sample_rows_test_size'] = kb_parameters['train_sample_rows_test_size']
-            if kb_parameters.get('scoring'):
+            if kb_parameters.get('scorer_for_ranking'):
                 params['scoring'] = kb_parameters['scorer_for_ranking']
 
         else:
