@@ -84,7 +84,7 @@ class LocalAutoPipelinesRuns(BaseAutoPipelinesRuns):
         >>> metadata = dict(
         >>>        prediction_type ='classification',
         >>>        prediction_column='species',
-        >>>        test_size=0.2,
+        >>>        holdout_size=0.2,
         >>>        scoring='roc_auc',
         >>>        max_number_of_estimators=1,
         >>>        training_data_reference = [DataConnection(
@@ -160,7 +160,7 @@ class LocalAutoPipelinesRuns(BaseAutoPipelinesRuns):
                     data._fill_experiment_parameters(
                         prediction_type=metadata.get('prediction_type'),
                         prediction_column=metadata.get('prediction_column'),
-                        test_size=metadata.get('test_size'),
+                        holdout_size=metadata.get('holdout_size'),
                         csv_separator=metadata.get('csv_separator', ','),
                         excel_sheet=metadata.get('excel_sheet', 0),
                         encoding=metadata.get('encoding', 'utf-8')
@@ -169,7 +169,7 @@ class LocalAutoPipelinesRuns(BaseAutoPipelinesRuns):
                 self.training_result_reference._fill_experiment_parameters(
                     prediction_type=metadata.get('prediction_type'),
                     prediction_column=metadata.get('prediction_column'),
-                    test_size=metadata.get('test_size'),
+                    holdout_size=metadata.get('holdout_size'),
                     csv_separator=metadata.get('csv_separator', ','),
                     excel_sheet=metadata.get('excel_sheet', 0),
                     encoding=metadata.get('encoding', 'utf-8')
@@ -186,7 +186,7 @@ class LocalAutoPipelinesRuns(BaseAutoPipelinesRuns):
                     prediction_type=metadata.get('prediction_type'),
                     prediction_column=metadata.get('prediction_column'),
                     scoring=metadata.get('scoring'),
-                    test_size=metadata.get('test_size'),
+                    holdout_size=metadata.get('holdout_size'),
                     max_num_daub_ensembles=metadata.get('max_number_of_estimators'),
                     _data_clients=data_clients,
                     _result_client=result_client
