@@ -105,7 +105,7 @@ class Export(WMLResource):
 
         start_meta[u'assets'] = assets
 
-        href = self._href_definitions.exports_href()
+        href = self._client.service_instance._href_definitions.exports_href()
 
         params = {}
 
@@ -196,7 +196,7 @@ class Export(WMLResource):
         if space_id is not None and project_id is not None:
             raise WMLClientError("Either 'space_id' or 'project_id' can be provided, not both")
 
-        href = self._href_definitions.export_href(export_id)
+        href = self._client.service_instance._href_definitions.export_href(export_id)
 
         params = {}
 
@@ -259,7 +259,7 @@ class Export(WMLResource):
 
         Export._validate_type(export_id, u'export_id', STR_TYPE, True)
 
-        href = self._href_definitions.export_href(export_id)
+        href = self._client.service_instance._href_definitions.export_href(export_id)
 
         params = {"hard_delete": True}
 
@@ -330,7 +330,7 @@ class Export(WMLResource):
         Export._validate_type(export_id, u'export_id', STR_TYPE, False)
         Export._validate_type(limit, u'limit', int, False)
 
-        href = self._href_definitions.exports_href()
+        href = self._client.service_instance._href_definitions.exports_href()
 
         params = {}
 
@@ -470,7 +470,7 @@ class Export(WMLResource):
 
         Export._validate_type(file_path, u'file_path', STR_TYPE, True)
 
-        href = self._href_definitions.export_content_href(export_id)
+        href = self._client.service_instance._href_definitions.export_content_href(export_id)
 
         try:
             if not self._ICP:
