@@ -249,9 +249,9 @@ score = {}()
                         # set the default to 3.6 runtime as 3.5 is no longer supported.
                         runtime_uid="ai-function_0.1-py3.6"
                         if not self._ICP:
-                            check_runtime = requests.get(self._href_definitions.get_runtime_href(runtime_uid),  headers=self._client._get_headers())
+                            check_runtime = requests.get(self._client.service_instance._href_definitions.get_runtime_href(runtime_uid),  headers=self._client._get_headers())
                         else:
-                            check_runtime = requests.get(self._href_definitions.get_runtime_href(runtime_uid),  headers=self._client._get_headers(),verify=False)
+                            check_runtime = requests.get(self._client.service_instance._href_definitions.get_runtime_href(runtime_uid),  headers=self._client._get_headers(),verify=False)
 
                         if check_runtime.status_code != 200:
                             print('No matching default runtime found. Creating one...', end="")
@@ -312,23 +312,23 @@ score = {}()
 
                 if not self._ICP:
                     if self._client.CLOUD_PLATFORM_SPACES:
-                        response_post = requests.post(self._href_definitions.get_functions_href(),
+                        response_post = requests.post(self._client.service_instance._href_definitions.get_functions_href(),
                                                       json=function_metadata,
                                                       params=self._client._params(skip_for_create=True),
                                                       headers=self._client._get_headers())
                     else:
-                        response_post = requests.post(self._href_definitions.get_functions_href(),
+                        response_post = requests.post(self._client.service_instance._href_definitions.get_functions_href(),
                                                       json=function_metadata,
                                                       headers=self._client._get_headers())
                 else:
                     if self._client.ICP_PLATFORM_SPACES:
-                        response_post = requests.post(self._href_definitions.get_functions_href(),
+                        response_post = requests.post(self._client.service_instance._href_definitions.get_functions_href(),
                                                       json=function_metadata,
                                                       params=self._client._params(skip_for_create=True),
                                                       headers=self._client._get_headers(),
                                                       verify=False)
                     else:
-                        response_post = requests.post(self._href_definitions.get_functions_href(),
+                        response_post = requests.post(self._client.service_instance._href_definitions.get_functions_href(),
                                                       json=function_metadata,
                                                       headers=self._client._get_headers(),
                                                       verify=False)
@@ -339,10 +339,10 @@ score = {}()
                 ##TODO_V4 Take care of this since the latest swagger endpoint is not working
 
                 if self._client.CLOUD_PLATFORM_SPACES or self._client.ICP_PLATFORM_SPACES:
-                    function_content_url = self._href_definitions.get_function_href(
+                    function_content_url = self._client.service_instance._href_definitions.get_function_href(
                         details['metadata']['id']) + "/code"
                 else:
-                    function_content_url = self._href_definitions.get_function_href(details['metadata']['guid']) + "/content"
+                    function_content_url = self._client.service_instance._href_definitions.get_function_href(details['metadata']['guid']) + "/content"
 
                 put_header = self._client._get_headers(no_content_type=True)
                 with open(content_path, 'rb') as data:
@@ -417,7 +417,7 @@ score = {}()
         patch_payload = self.ConfigurationMetaNames._generate_patch_payload(details['entity'], changes,
                                                                             with_validation=True)
 
-        url = self._href_definitions.get_function_href(function_uid)
+        url = self._client.service_instance._href_definitions.get_function_href(function_uid)
         headers = self._client._get_headers()
         if not self._ICP:
             response = requests.patch(url, json=patch_payload, params = self._client._params(),headers=headers)
@@ -513,9 +513,9 @@ score = {}()
 
         try:
             if self._client.CLOUD_PLATFORM_SPACES or self._client.ICP_PLATFORM_SPACES:
-                function_content_url = self._href_definitions.get_function_href(function_uid) + "/code"
+                function_content_url = self._client.service_instance._href_definitions.get_function_href(function_uid) + "/code"
             else:
-                function_content_url = self._href_definitions.get_function_href(function_uid) + "/content"
+                function_content_url = self._client.service_instance._href_definitions.get_function_href(function_uid) + "/content"
 
             put_header = self._client._get_headers(no_content_type=True)
             with open(content_path, 'rb') as data:
@@ -577,23 +577,23 @@ score = {}()
         filename = str_type_conv(filename)
         Functions._validate_type(filename, u'filename', STR_TYPE, True)
 
-        artifact_url = self._href_definitions.get_function_href(artifact_uid)
+        artifact_url = self._client.service_instance._href_definitions.get_function_href(artifact_uid)
         if self._client.WSD:
             import urllib
-            function_get_response = requests.get(self._href_definitions.get_data_asset_href(function_uid),
+            function_get_response = requests.get(self._client.service_instance._href_definitions.get_data_asset_href(function_uid),
                                               params=self._client._params(),
                                               headers=self._client._get_headers())
 
             function_details = self._handle_response(200, u'get function', function_get_response)
            # function_details = self.get_details(function_uid)
             attachment_url = function_details['attachments'][0]['object_key']
-            artifact_content_url = self._href_definitions.get_wsd_model_attachment_href() + \
+            artifact_content_url = self._client.service_instance._href_definitions.get_wsd_model_attachment_href() + \
                                    urllib.parse.quote('wml_function/' + attachment_url, safe='')
         else:
             if self._client.CLOUD_PLATFORM_SPACES or self._client.ICP_PLATFORM_SPACES:
-                artifact_content_url = self._href_definitions.get_function_href(artifact_uid) + '/code'
+                artifact_content_url = self._client.service_instance._href_definitions.get_function_href(artifact_uid) + '/code'
             else:
-                artifact_content_url = self._href_definitions.get_function_latest_revision_content_href(artifact_uid)
+                artifact_content_url = self._client.service_instance._href_definitions.get_function_latest_revision_content_href(artifact_uid)
 
         try:
             if not self._ICP and not self._client.WSD:
@@ -681,9 +681,9 @@ score = {}()
         #        print(delete_status)
 
         if self._client.WSD:
-            function_endpoint = self._href_definitions.get_model_definition_assets_href() + "/" + function_uid
+            function_endpoint = self._client.service_instance._href_definitions.get_model_definition_assets_href() + "/" + function_uid
         else:
-            function_endpoint = self._href_definitions.get_function_href(function_uid)
+            function_endpoint = self._client.service_instance._href_definitions.get_function_href(function_uid)
         self._logger.debug(u'Deletion artifact function endpoint: {}'.format(function_endpoint))
         if not self._ICP and not self._client.WSD:
             response_delete = requests.delete(function_endpoint, params = self._client._params(),headers=self._client._get_headers())
@@ -704,9 +704,9 @@ score = {}()
         ##TODO_V4 Uncomment this after deployments is ready
         # Delete associated deployments, so there will be no orphans
         if self._client.WSD:
-            function_endpoint = self._href_definitions.get_model_definition_assets_href() + "/" + function_uid
+            function_endpoint = self._client.service_instance._href_definitions.get_model_definition_assets_href() + "/" + function_uid
         else:
-            function_endpoint = self._href_definitions.get_function_href(function_uid)
+            function_endpoint = self._client.service_instance._href_definitions.get_function_href(function_uid)
         self._logger.debug(u'Deletion artifact function endpoint: {}'.format(function_endpoint))
 
 
@@ -761,11 +761,11 @@ score = {}()
         Functions._validate_type(function_uid, u'function_uid', STR_TYPE, False)
         Functions._validate_type(limit, u'limit', int, False)
         if self._client.WSD:
-            url = self._href_definitions.get_model_definition_assets_href()
+            url = self._client.service_instance._href_definitions.get_model_definition_assets_href()
             response = self._get_artifact_details(url, function_uid, limit, 'function')
             return Functions._wsd_get_required_element_from_response(self, response)
         else:
-            url = self._href_definitions.get_functions_href()
+            url = self._client.service_instance._href_definitions.get_functions_href()
 
         return self._get_artifact_details(url, function_uid, limit, 'functions')
 
@@ -974,7 +974,7 @@ score = {}()
         if rev is not None:
             clone_meta["rev"] = rev
 
-        url = self._href_definitions.get_function_href(function_uid)
+        url = self._client.service_instance._href_definitions.get_function_href(function_uid)
         if not self._ICP:
             response_post = requests.post(url, json=clone_meta,
                                               headers=self._client._get_headers())
@@ -1007,7 +1007,7 @@ score = {}()
             raise WMLClientError(
                 u'Revision support is not there in this release')
         else:
-            url = self._href_definitions.get_functions_href()
+            url = self._client.service_instance._href_definitions.get_functions_href()
             return self._create_revision_artifact(url, function_uid, 'functions')
 
     def get_revision_details(self, function_uid, rev_uid):
@@ -1036,7 +1036,7 @@ score = {}()
             raise WMLClientError(
                 'Revision APIs are not supported in this release. ')
         else:
-            url = self._href_definitions.get_function_href(function_uid)
+            url = self._client.service_instance._href_definitions.get_function_href(function_uid)
             return self._get_with_or_without_limit(url, limit=None, op_name="function",
                                                    summary=None, pre_defined=None, revision=rev_uid)
 
@@ -1064,7 +1064,7 @@ score = {}()
         if self._client.ICP_30 is None and not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_PLATFORM_SPACES:
             raise WMLClientError(u'Revision support is not there in this release.')
         else:
-            url = self._href_definitions.get_function_href(function_uid)
+            url = self._client.service_instance._href_definitions.get_function_href(function_uid)
 
             # CP4D logic is wrong. By passing "revisions" in second param above for _get_artifact_details()
             # it won't even consider limit value and also GUID gives only rev number, not actual guid
