@@ -73,7 +73,7 @@ class ServiceInstance:
 
                 >>> instance_details = client.service_instance.get_api_key()
         """
-        return self._wml_credentials['api_key']
+        return self._wml_credentials['apikey']
 
     def get_url(self):
         """
