@@ -42,7 +42,7 @@ class LearningSystem(WMLResource):
             pool = Pool(processes=4)
 
             def url(model_uid):
-                return self._href_definitions.get_learning_iterations_href(model_uid)
+                return self._client.service_instance._href_definitions.get_learning_iterations_href(model_uid)
 
             headers = self._client._get_headers()
             isIcp = self._ICP
@@ -125,7 +125,7 @@ class LearningSystem(WMLResource):
             }
 
         response = requests.put(
-            self._href_definitions.get_learning_configuration_href(model_uid),
+            self._client.service_instance._href_definitions.get_learning_configuration_href(model_uid),
             json=payload,
             headers=headers
         )
@@ -155,7 +155,7 @@ class LearningSystem(WMLResource):
         patch_payload = self.ConfigurationMetaNames._generate_patch_payload(details, changes,
                                                                             with_validation=True)
 
-        url = self._href_definitions.get_learning_configuration_href(model_uid)
+        url = self._client.service_instance._href_definitions.get_learning_configuration_href(model_uid)
         response = requests.patch(url, json=patch_payload, headers=self._client._get_headers())
         updated_details = self._handle_response(200, u'learning system patch', response)
 
@@ -176,7 +176,7 @@ class LearningSystem(WMLResource):
         self._validate_type(model_uid, u'model_uid', STR_TYPE, True)
 
         response = requests.get(
-            self._href_definitions.get_published_model_href(model_uid),
+            self._client.service_instance._href_definitions.get_published_model_href(model_uid),
             headers=self._client._get_headers()
         )
 
@@ -221,7 +221,7 @@ class LearningSystem(WMLResource):
         self._validate_type(asynchronous, u'asynchronous', bool, True)
 
         response = requests.post(
-            self._href_definitions.get_learning_iterations_href(model_uid),
+            self._client.service_instance._href_definitions.get_learning_iterations_href(model_uid),
             json={},
             headers=self._client._get_headers()
         )
@@ -343,7 +343,7 @@ class LearningSystem(WMLResource):
         self._validate_type(model_uid, u'model_uid', STR_TYPE, True)
 
         response = requests.get(
-            self._href_definitions.get_learning_iterations_href(model_uid),
+            self._client.service_instance._href_definitions.get_learning_iterations_href(model_uid),
             headers=self._client._get_headers()
         )
 
@@ -369,7 +369,7 @@ class LearningSystem(WMLResource):
         self._validate_type(model_uid, u'model_uid', STR_TYPE, True)
 
         response = requests.get(
-            self._href_definitions.get_evaluation_metrics_href(model_uid),
+            self._client.service_instance._href_definitions.get_evaluation_metrics_href(model_uid),
             headers=self._client._get_headers()
         )
 
@@ -428,7 +428,7 @@ class LearningSystem(WMLResource):
             pool = Pool(processes=4)
 
             def url(model_uid):
-                return self._href_definitions.get_learning_iterations_href(model_uid)
+                return self._client.service_instance._href_definitions.get_learning_iterations_href(model_uid)
             headers = self._client._get_headers()
             isIcp = self._ICP
 
@@ -481,7 +481,7 @@ class LearningSystem(WMLResource):
         model_uid = self._get_model_uid_by_run_uid(run_uid)
 
         response = requests.get(
-            self._href_definitions.get_learning_iteration_href(model_uid, run_uid),
+            self._client.service_instance._href_definitions.get_learning_iteration_href(model_uid, run_uid),
             headers=self._client._get_headers()
         )
 
@@ -516,7 +516,7 @@ class LearningSystem(WMLResource):
             data.update({"fields": fields})
 
         response = requests.post(
-            self._href_definitions.get_feedback_href(model_uid),
+            self._client.service_instance._href_definitions.get_feedback_href(model_uid),
             json=data,
             headers=self._client._get_headers()
         )
