@@ -22,7 +22,7 @@ class HybridPipelineModelLoader(HybridArtifactLoader):
         :return: model
         :rtype: hybrid.model
         """
-    def model_instance(self, artifact=None):
+    def model_instance(self, artifact='full'):
         """
            :param artifact: query param string referring to "pipeline_model" or "full"
            Currently accepts:
