@@ -36,13 +36,21 @@ class TensorflowPipelineModelLoader(TensorflowArtifactLoader):
     def model_instance(self,session=None,tags=None):
         lib_checker.check_lib(TENSORFLOW)
         if session is None:
-            session = tf.Session(graph=tf.Graph())
+            if '2.1.0' in tf.__version__:
+                session = tf.compat.v1.Session(graph=tf.compat.v1.Graph())
+            else:
+                session = tf.Session(graph=tf.Graph())
         elif session is not None:
-            if not isinstance(session,tf.Session):
+            if '2.1.0' in tf.__version__ and not isinstance(session, tf.compat.v1.Session):
+                raise TypeError("sess should be of type : %s" % tf.compat.v1.Session)
+            elif not isinstance(session,tf.Session):
                 raise TypeError("sess should be of type : %s" % tf.Session)
 
         if tags is None:
-            tags = [tf.saved_model.tag_constants.SERVING]
+            if '2.1.0' in tf.__version__:
+                tags = [tf.compat.v1.saved_model.tag_constants.SERVING]
+            else:
+                tags = [tf.saved_model.tag_constants.SERVING]
         elif tags is not None:
             if not isinstance(tags,list):
                 raise TypeError("tags should be of type : %s" % list)
