@@ -83,7 +83,10 @@ class TensorflowPipelineReader(ArtifactReader):
         try:
             from tensorflow import logging
             logging.set_verbosity(logging.WARN)
-            builder = tf.saved_model.builder.SavedModelBuilder(path)
+            if '2.1.0' in tf.__version__ :
+                builder = tf.compat.v1.saved_model.builder.SavedModelBuilder(path)
+            else:
+                builder = tf.saved_model.builder.SavedModelBuilder(path)
             builder.add_meta_graph_and_variables(sess=self.tensorflow_pipeline,
                                                  tags=self.tags,
                                                  signature_def_map=self.signature_def_map,
