@@ -111,10 +111,10 @@ class ModelAdapter(object):
                 {}
             )
         else:
-            try:
-                raise ValueError('Invalid model_type: {}'.format(self.model_type.get('name')))
-            except:
+            if isinstance(self.model_type, str):
                 raise ValueError('Invalid model_type: {}'.format(self.model_type))
+            else:
+                raise ValueError('Invalid model_type: {}'.format(self.model_type.get('name')))
 
         prop_map = {
             MetaNames.TYPE: self.model_type
