@@ -215,13 +215,13 @@ class ModelDefinition(WMLResource):
         try:
             if not self._ICP:
                 creation_response = requests.post(
-                     self._href_definitions.get_model_definition_assets_href(),
+                     self._client.service_instance._href_definitions.get_model_definition_assets_href(),
                      params=paramvalue,
                      headers=self._client._get_headers(),
                      json=document)
             else:
                 creation_response = requests.post(
-                    self._href_definitions.get_model_definition_assets_href(),
+                    self._client.service_instance._href_definitions.get_model_definition_assets_href(),
                     params=paramvalue,
                     headers=self._client._get_headers(),
                     json=document,
@@ -230,9 +230,9 @@ class ModelDefinition(WMLResource):
             model_definition_details = self._handle_response(201, u'creating new model_definition', creation_response)
 
             if self._client.CLOUD_PLATFORM_SPACES:
-                model_definition_attachment_url = self._href_definitions.get_attachments_href(model_definition_details['metadata']['asset_id'])
+                model_definition_attachment_url = self._client.service_instance._href_definitions.get_attachments_href(model_definition_details['metadata']['asset_id'])
             else:
-                model_definition_attachment_url = self._href_definitions.get_model_definition_assets_href() + "/" + \
+                model_definition_attachment_url = self._client.service_instance._href_definitions.get_model_definition_assets_href() + "/" + \
                                                   model_definition_details['metadata']['asset_id'] + "/attachments"
 
             put_header = self._client._get_headers(no_content_type=True)
@@ -275,10 +275,10 @@ class ModelDefinition(WMLResource):
                                                     files=files,
                                                     verify=False)
                     if put_response.status_code == 201 or put_response.status_code == 200:
-                        complete_url = self._href_definitions.get_attachment_href(model_definition_id, attachment_id) \
+                        complete_url = self._client.service_instance._href_definitions.get_attachment_href(model_definition_id, attachment_id) \
                                        + "/complete"
                         if not self._ICP:
-                            complete_response = requests.post( self._href_definitions.get_attachment_complete_href(model_definition_id, attachment_id),
+                            complete_response = requests.post( self._client.service_instance._href_definitions.get_attachment_complete_href(model_definition_id, attachment_id),
                                                               params=paramvalue,
                                                               headers=self._client._get_headers(),
                                                               verify=False)
@@ -354,7 +354,7 @@ class ModelDefinition(WMLResource):
         modeldef_uid = str_type_conv(model_definition_uid)
         ModelDefinition._validate_type(modeldef_uid, u'model_definition_uid', STR_TYPE, False)
 
-        url = self._href_definitions.get_model_definition_assets_href() + u'/' + modeldef_uid
+        url = self._client.service_instance._href_definitions.get_model_definition_assets_href() + u'/' + modeldef_uid
         paramvalue = self._client._params()
         if not self._ICP:
             response_get = requests.get(
@@ -433,20 +433,20 @@ class ModelDefinition(WMLResource):
 
         if self._client.WSD:
             import urllib
-            response = requests.get(self._href_definitions.get_data_asset_href(model_definition_uid),
+            response = requests.get(self._client.service_instance._href_definitions.get_data_asset_href(model_definition_uid),
                                               params=self._client._params(),
                                               headers=self._client._get_headers())
 
             model_def_details = self._handle_response(200, u'get model', response)
             attachment_url = model_def_details['attachments'][0]['object_key']
-            attachment_signed_url = self._href_definitions.get_wsd_model_attachment_href() + \
+            attachment_signed_url = self._client.service_instance._href_definitions.get_wsd_model_attachment_href() + \
                                    urllib.parse.quote('wml_model_definition/' + attachment_url, safe='')
 
         else:
             attachment_id = self._get_attachment_id(model_definition_uid)
-            artifact_content_url = self._href_definitions.get_attachment_href(model_definition_uid, attachment_id)
+            artifact_content_url = self._client.service_instance._href_definitions.get_attachment_href(model_definition_uid, attachment_id)
             if not self._ICP and not self._WSD:
-                response = requests.get(self._href_definitions.get_attachment_href(model_definition_uid, attachment_id), params=self._client._params(),
+                response = requests.get(self._client.service_instance._href_definitions.get_attachment_href(model_definition_uid, attachment_id), params=self._client._params(),
                                     headers=self._client._get_headers())
             else:
                 response = requests.get(artifact_content_url, params=self._client._params(),
@@ -510,7 +510,7 @@ class ModelDefinition(WMLResource):
         ModelDefinition._validate_type(model_definition_uid, u'model_definition_uid', STR_TYPE, True)
         paramvalue = self._client._params()
 
-        model_definition_endpoint = self._href_definitions.get_model_definition_assets_href() + "/" + model_definition_uid
+        model_definition_endpoint = self._client.service_instance._href_definitions.get_model_definition_assets_href() + "/" + model_definition_uid
         if not self._ICP:
             response_delete = requests.delete(model_definition_endpoint, params=paramvalue, headers=self._client._get_headers())
         else:
@@ -544,7 +544,7 @@ class ModelDefinition(WMLResource):
         model_definition_uid = str_type_conv(model_definition_uid)
         ModelDefinition._validate_type(model_definition_uid, u'model_definition_uid', STR_TYPE, True)
         paramvalue = self._client._params()
-        model_definition_endpoint = self._href_definitions.get_model_definition_assets_href() + "/" + model_definition_uid
+        model_definition_endpoint = self._client.service_instance._href_definitions.get_model_definition_assets_href() + "/" + model_definition_uid
         if not self._ICP:
             response_delete = requests.delete(model_definition_endpoint, params=paramvalue, headers=self._client._get_headers())
         else:
@@ -567,8 +567,8 @@ class ModelDefinition(WMLResource):
                       'entity': response_data['entity']
 
                       }
-                href = "/v2/assets/" + response_data['metadata']['asset_type'] + "/" + response_data['metadata'][
-                    'asset_id'] + "?" + "space_id=" + response_data['metadata']['space_id']
+                href = self._client.service_instance._href_definitions.get_base_asset_with_type_href(response_data['metadata']['asset_type'], response_data['metadata'][
+                    'asset_id']) + "?" + "space_id=" + response_data['metadata']['space_id']
 
             elif self._client.default_project_id is not None:
                 new_el = {'metadata': {'project_id': response_data['metadata']['project_id'],
@@ -581,8 +581,8 @@ class ModelDefinition(WMLResource):
 
                           }
 
-                href = "/v2/assets/" + response_data['metadata']['asset_type'] + "/" + response_data['metadata'][
-                    'asset_id'] + "?" + "project_id=" + response_data['metadata']['project_id']
+                href = self._client.service_instance._href_definitions.get_base_asset_with_type_href(response_data['metadata']['asset_type'], response_data['metadata'][
+                    'asset_id']) + "?" + "project_id=" + response_data['metadata']['project_id']
 
             if 'revision_id' in response_data['metadata']:
                 new_el['metadata'].update({'revision_id': response_data['metadata']['revision_id']})
@@ -617,7 +617,7 @@ class ModelDefinition(WMLResource):
 
     def _get_attachment_id(self, model_definition_uid, rev_id=None):
         op_name = 'getting attachment id '
-        url = self._href_definitions.get_model_definition_assets_href() + u'/' + model_definition_uid
+        url = self._client.service_instance._href_definitions.get_model_definition_assets_href() + u'/' + model_definition_uid
         paramvalue = self._client._params()
 
         if rev_id is not None:
@@ -663,7 +663,7 @@ class ModelDefinition(WMLResource):
         """
         ##For CP4D, check if either spce or project ID is set
         self._client._check_if_either_is_set()
-        href = self._href_definitions.get_model_definition_search_asset_href()
+        href = self._client.service_instance._href_definitions.get_model_definition_search_asset_href()
         if limit is None:
             data = {
                 "query": "*:*"
@@ -814,7 +814,7 @@ class ModelDefinition(WMLResource):
 
         updated_details = None
 
-        url = self._href_definitions.get_asset_href(model_definition_id)
+        url = self._client.service_instance._href_definitions.get_asset_href(model_definition_id)
 
         # STEPS
         # STEP 1. Get existing metadata
@@ -888,7 +888,7 @@ class ModelDefinition(WMLResource):
                                                                                        asset_meta_patch=False)
 
             if meta_patch_payload:
-                meta_patch_url = self._href_definitions.get_asset_href(model_definition_id)
+                meta_patch_url = self._client.service_instance._href_definitions.get_asset_href(model_definition_id)
 
                 if not self._ICP:
                     response_patch = requests.patch(meta_patch_url,
@@ -905,7 +905,7 @@ class ModelDefinition(WMLResource):
                 updated_details = self._handle_response(200, u'script patch', response_patch)
 
             if entity_patch_payload:
-                entity_patch_url = self._href_definitions.get_asset_href(model_definition_id) + \
+                entity_patch_url = self._client.service_instance._href_definitions.get_asset_href(model_definition_id) + \
                                    '/attributes/wml_model_definition'
 
                 if not self._ICP:
@@ -937,7 +937,7 @@ class ModelDefinition(WMLResource):
             self._update_msg(updated_details)
 
         # Have to fetch again to reflect updated asset and attachment ids
-        url = self._href_definitions.get_asset_href(model_definition_id)
+        url = self._client.service_instance._href_definitions.get_asset_href(model_definition_id)
 
         if not self._ICP:
             response = requests.get(
@@ -1084,7 +1084,7 @@ class ModelDefinition(WMLResource):
         ModelDefinition._validate_type(modeldef_uid, u'model_definition_uid', STR_TYPE, True)
         ModelDefinition._validate_type(modeldef_uid, u'model_definition_uid', STR_TYPE, True)
 
-        url = self._href_definitions.get_model_definition_assets_href() + u'/' + modeldef_uid
+        url = self._client.service_instance._href_definitions.get_model_definition_assets_href() + u'/' + modeldef_uid
         paramvalue = self._client._params()
 
         if rev_uid is None:
@@ -1160,7 +1160,7 @@ class ModelDefinition(WMLResource):
             raise WMLClientError(
                 u'Revisions APIs are not supported in this release.')
         self._client._check_if_either_is_set()
-        href = self._href_definitions.get_model_definition_assets_href() + "/" + model_definition_uid +\
+        href = self._client.service_instance._href_definitions.get_model_definition_assets_href() + "/" + model_definition_uid +\
                u'/revisions'
         params = self._client._params()
         #params = None
