@@ -115,7 +115,7 @@ class Pipelines(WMLResource):
                   }
                 ]
               }
-        if self._client.CLOUD_PLATFORM_SPACES or self._client.ICP_35:
+        if self._client.CLOUD_PLATFORM_SPACES or self._client.ICP_35 or self._client.ICP_40:
             if self.ConfigurationMetaNames.COMMAND in meta_props:
                 doc["pipelines"][0]["nodes"][0]["parameters"]["command"] = meta_props[self.ConfigurationMetaNames.COMMAND]
             if self.ConfigurationMetaNames.RUNTIMES in meta_props:
@@ -199,7 +199,7 @@ class Pipelines(WMLResource):
             else:
                 raise WMLClientError("It is mandatory to set the space/project id. Use client.set.default_space(<SPACE_UID>)/client.set.default_project(<PROJECT_UID>) to proceed.")
 
-        if self._client.CLOUD_PLATFORM_SPACES or self._client.ICP_35:
+        if self._client.CLOUD_PLATFORM_SPACES or self._client.ICP_35 or self._client.ICP_40:
             if self._client.default_space_id is not None:
                 pipeline_meta['space_id'] = self._client.default_space_id
             elif self._client.default_project_id is not None:
@@ -221,7 +221,7 @@ class Pipelines(WMLResource):
         if not self._ICP and not self._client.WSD:
             if self._client.CLOUD_PLATFORM_SPACES:
                 creation_response = requests.post(
-                    self._href_definitions.get_pipelines_href(),
+                    self._client.service_instance._href_definitions.get_pipelines_href(),
                     headers=self._client._get_headers(),
                     params=self._client._params(skip_for_create=True),
                     json=pipeline_meta
@@ -248,7 +248,7 @@ class Pipelines(WMLResource):
 
                 import copy
                 cams_entity = copy.deepcopy(pipeline_meta)
-                pipeline_url = self._href_definitions.get_wsd_model_href()
+                pipeline_url = self._client.service_instance._href_definitions.get_wsd_model_href()
                 #cams_entity.pop('name')
                 if cams_entity.get('description') is not None:
                     cams_entity.pop('description')
@@ -258,7 +258,7 @@ class Pipelines(WMLResource):
                     "name": "wml_pipeline"
                 }
                 atype_payload = json.dumps(atype_body, separators=(',', ':'))
-                atype_url = self._href_definitions.get_wsd_asset_type_href()
+                atype_url = self._client.service_instance._href_definitions.get_wsd_asset_type_href()
                 aheaders = {
                     'Content-Type': "application/json"
                 }
@@ -284,9 +284,9 @@ class Pipelines(WMLResource):
                 pipeline_details = self._handle_response(201, u'creating new pipeline', creation_response)
                 return WMLResource._wsd_get_required_element_from_response(self, pipeline_details)
 
-            elif self._client.ICP_35:
+            elif self._client.ICP_35 or self._client.ICP_40:
                 creation_response = requests.post(
-                    self._href_definitions.get_pipelines_href(),
+                    self._client.service_instance._href_definitions.get_pipelines_href(),
                     headers=self._client._get_headers(),
                     params=self._client._params(skip_for_create=True),
                     json=pipeline_meta,
@@ -320,11 +320,11 @@ class Pipelines(WMLResource):
         pipeline_uid = str_type_conv(pipeline_uid)
         Pipelines._validate_type(pipeline_uid, u'pipeline_uid', STR_TYPE, False)
 
-        if self._client.ICP_30 is None and not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_35:
+        if not self._client.ICP_30 and not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_35 and not self._client.ICP_40:
             raise WMLClientError(
                 u'Revision support is not there in this version WML server. It is supported only from 3.1.0 onwards.')
         else:
-            url = self._href_definitions.get_pipelines_href()
+            url = self._client.service_instance._href_definitions.get_pipelines_href()
             #return self. _create_revision_artifact_for_assets(pipeline_uid, 'pipelines')
             return self._create_revision_artifact(url, pipeline_uid, 'pipelines')
 
@@ -373,7 +373,7 @@ class Pipelines(WMLResource):
         patch_payload = self.ConfigurationMetaNames._generate_patch_payload(details['entity'], changes,
                                                                             with_validation=True)
 
-        url = self._href_definitions.get_pipeline_href(pipeline_uid)
+        url = self._client.service_instance._href_definitions.get_pipeline_href(pipeline_uid)
 
         if not self._ICP:
             response = requests.patch(url, json=patch_payload, params=self._client._params(),headers=self._client._get_headers())
@@ -412,9 +412,9 @@ class Pipelines(WMLResource):
         pipeline_uid = str_type_conv(pipeline_uid)
         Pipelines._validate_type(pipeline_uid, u'pipeline_uid', STR_TYPE, True)
         if self._client.WSD:
-            pipeline_endpoint = self._href_definitions.get_model_definition_assets_href() + "/" + pipeline_uid
+            pipeline_endpoint = self._client.service_instance._href_definitions.get_model_definition_assets_href() + "/" + pipeline_uid
         else:
-            pipeline_endpoint = self._href_definitions.get_pipeline_href(pipeline_uid)
+            pipeline_endpoint = self._client.service_instance._href_definitions.get_pipeline_href(pipeline_uid)
         if not self._ICP and not self._client.WSD:
             response_delete = requests.delete(pipeline_endpoint, params=self._client._params(),headers=self._client._get_headers())
         else:
@@ -458,11 +458,11 @@ class Pipelines(WMLResource):
         Pipelines._validate_type(pipeline_uid, u'pipeline_uid', STR_TYPE, False)
         Pipelines._validate_type(limit, u'limit', int, False)
         if self._client.WSD:
-            url = self._href_definitions.get_model_definition_assets_href()
+            url = self._client.service_instance._href_definitions.get_model_definition_assets_href()
             response = self._get_artifact_details(url, pipeline_uid, limit, 'definitions', summary="False")
             return self._wsd_get_required_element_from_response(response)
         else:
-            url = self._href_definitions.get_pipelines_href()
+            url = self._client.service_instance._href_definitions.get_pipelines_href()
 
         return self._get_artifact_details(url, pipeline_uid, limit, 'definitions',summary="False")
 
@@ -489,11 +489,11 @@ class Pipelines(WMLResource):
         pipeline_uid = str_type_conv(pipeline_uid)
         Pipelines._validate_type(pipeline_uid, u'pipeline_uid', STR_TYPE, True)
         Pipelines._validate_type(rev_uid, u'rev_uid', int, True)
-        if not self._client.ICP_30 and not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_35:
+        if not self._client.ICP_30 and not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_35 and not self._client.ICP_40:
             raise WMLClientError(
                 'Not supported. Revisions APIs are supported only for IBM Cloud Pak® for Data for Data 3.0 and above.')
         else:
-            url = self._href_definitions.get_pipeline_href(pipeline_uid)
+            url = self._client.service_instance._href_definitions.get_pipeline_href(pipeline_uid)
         return self._get_with_or_without_limit(url, limit=None, op_name="pipeline",
                                                summary=None, pre_defined=None, revision=rev_uid)
 
@@ -626,7 +626,7 @@ class Pipelines(WMLResource):
             self._client._check_if_either_is_set()
 
             pipeline_resources = self.get_details(limit=limit)[u'resources']
-            if self._client.CLOUD_PLATFORM_SPACES or self._client.ICP_35:
+            if self._client.CLOUD_PLATFORM_SPACES or self._client.ICP_35 or self._client.ICP_40:
                 pipeline_values = [(m[u'metadata'][u'id'], m[u'metadata'][u'name'], m[u'metadata'][u'created_at']) for m
                                    in pipeline_resources]
 
@@ -660,11 +660,11 @@ class Pipelines(WMLResource):
 
         Pipelines._validate_type(pipeline_uid, u'pipeline_uid', STR_TYPE, True)
 
-        if self._client.ICP_30 is None and not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_35:
+        if self._client.ICP_30 is None and not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_35 and not self._client.ICP_40:
             raise WMLClientError(
                 u'Revision support is not there in this WML server. It is supported only from 3.1.0 onwards.')
         else:
-            url = self._href_definitions.get_pipeline_href(pipeline_uid)
+            url = self._client.service_instance._href_definitions.get_pipeline_href(pipeline_uid)
             pipeline_resources = self._get_artifact_details(url, "revisions", limit, 'pipeline revisions')[u'resources']
             pipeline_values = [
                 (m[u'metadata'][u'rev'], m[u'metadata'][u'name'], m[u'metadata'][u'created_at']) for m in
@@ -713,7 +713,7 @@ class Pipelines(WMLResource):
                     * Space id is mandatory for move action\n
 
         """
-        if self._client.WSD or self._client.CLOUD_PLATFORM_SPACES or self._client.ICP_35:
+        if self._client.WSD or self._client.CLOUD_PLATFORM_SPACES or self._client.ICP_35 or self._client.ICP_40:
             raise WMLClientError(" Clone pipeline operation is not supported. ")
         artifact = str_type_conv(pipeline_uid)
         Pipelines._validate_type(artifact, 'exp_id', STR_TYPE, True)
@@ -728,7 +728,7 @@ class Pipelines(WMLResource):
         if rev is not None:
             clone_meta["rev"] = rev
 
-        url = self._href_definitions.get_pipeline_href(pipeline_uid)
+        url = self._client.service_instance._href_definitions.get_pipeline_href(pipeline_uid)
         if not self._ICP:
             response_post = requests.post(url, json=clone_meta,
                                               headers=self._client._get_headers())
