@@ -336,20 +336,20 @@ class OBMPipelineGraphBuilder:
                                       "day_of_week": day_of_week, "day_of_year": day_of_year, "month": month,
                                       "hour": hour, "minute": minute,
                                       "min": min, "mean": mean, "variance": variance, "distinct_count": distinct_count,
-                                      "ItemsetMI": item,
-                                      "ItemsetCOR": item,
+                                      "ItemsetMI": item, "ItemsetCOR": item,
+                                      "SymbolRecent": recent, "recent": recent, "window_max": window_max,
                                       "SymbolRecent": recent, "window_max": window_max,
                                       "window_max_trend": window_max_trend,
                                       "window_mean": window_mean, "window_mean_trend": window_mean_trend,
                                       "window_min": window_min,
                                       "window_min_trend": window_min_trend, "window_variance": window_variance,
                                       "window_variance_trend": window_variance_trend,
-                                      "normalized_count": normalized_count,
-                                      "normalized_sum": normalized_sum, "trend": trend,
+                                      "normalized_count": normalized_count, "normalised_count": normalized_count,
+                                      "normalized_sum": normalized_sum, "normalised_sum": normalized_sum, "trend": trend,
                                       "recent_gap_to_cutoff": recent_gap_to_cutoff,
                                       "max_gap_to_cutoff": max_gap_to_cutoff}
         time_series_functions = ["day_of_month", "day_of_week", "day_of_year", "minute", "hour", "month"]
-        parameterized_functions = ["SymbolRecent", "window_max",
+        parameterized_functions = ["SymbolRecent", "recent", "window_max",
                                    "window_max_trend", "window_mean", "window_mean_trend", "window_min",
                                    "window_min_trend", "window_variance", "window_variance_trend",
                                    "recent_gap_to_cutoff"]
@@ -478,7 +478,8 @@ class OBMPipelineGraphBuilder:
                                     kwargs['size'] = int(re.split('(\\d+)', op)[1])
                                 else:
                                     kwargs['age'] = int(re.split('(\\d+)', op)[1])
-                            if re.split('(\\d+)', op)[0][:-1] in time_cufoff_functions:
+                            if (re.split('(\\d+)', op)[0][:-1] in time_cufoff_functions or
+                                re.split('(\\d+)', op)[0] in time_cufoff_functions):
                                 kwargs['cutoff'] = Expr(
                                     ast.Subscript(value=ast.Name(self.main_table, ast.Store()), slice=ast.Index(
                                         ast.Str(s=self.main_table_timestamp))))
