@@ -78,7 +78,7 @@ class RemoteTrainingSystem(WMLResource):
         elif self._client.default_project_id is not None:
             meta['project_id'] = self._client.default_project_id
 
-        href = self._href_definitions.remote_training_systems_href()
+        href = self._client.service_instance._href_definitions.remote_training_systems_href()
 
         if not self._ICP:
             creation_response = requests.post(href,
@@ -140,7 +140,7 @@ class RemoteTrainingSystem(WMLResource):
         self._client._check_if_either_is_set()
         RemoteTrainingSystem._validate_type(remote_training_systems_id, u'remote_training_systems_id', STR_TYPE, True)
 
-        href = self._href_definitions.remote_training_system_href(remote_training_systems_id)
+        href = self._client.service_instance._href_definitions.remote_training_system_href(remote_training_systems_id)
 
         if not self._ICP:
             delete_response = requests.delete(href,
@@ -196,7 +196,7 @@ class RemoteTrainingSystem(WMLResource):
         RemoteTrainingSystem._validate_type(remote_training_system_id, u'remote_training_systems_id', STR_TYPE, False)
         RemoteTrainingSystem._validate_type(limit, u'limit', int, False)
 
-        href = self._href_definitions.remote_training_systems_href()
+        href = self._client.service_instance._href_definitions.remote_training_systems_href()
 
         return self._get_artifact_details(href, remote_training_system_id, limit, 'remote_training_systems')
     
@@ -298,7 +298,7 @@ class RemoteTrainingSystem(WMLResource):
         patch_payload = self.ConfigurationMetaNames._generate_patch_payload(details['entity'], changes,
                                                                             with_validation=True)
 
-        href = self._href_definitions.remote_training_system_href(remote_training_system_id)
+        href = self._client.service_instance._href_definitions.remote_training_system_href(remote_training_system_id)
 
         if not self._ICP:
             response = requests.patch(href,
@@ -333,7 +333,7 @@ class RemoteTrainingSystem(WMLResource):
 
         RemoteTrainingSystem._validate_type(remote_training_system_id, u'remote_training_system_id', STR_TYPE, False)
 
-        href = self._href_definitions.remote_training_systems_href()
+        href = self._client.service_instance._href_definitions.remote_training_systems_href()
         return self._create_revision_artifact(href, remote_training_system_id, 'remote training system')
 
     def get_revision_details(self, remote_training_system_id, rev_id):
@@ -361,7 +361,7 @@ class RemoteTrainingSystem(WMLResource):
         RemoteTrainingSystem._validate_type(remote_training_system_id, u'remote_training_system_id', STR_TYPE, True)
         RemoteTrainingSystem._validate_type(rev_id, u'rev_id', int, True)
 
-        href = self._href_definitions.remote_training_system_href(remote_training_system_id)
+        href = self._client.service_instance._href_definitions.remote_training_system_href(remote_training_system_id)
         return self._get_with_or_without_limit(href, limit=None, op_name="remote_training_system_id",
                                                summary=None, pre_defined=None, revision=rev_id)
 
@@ -388,7 +388,7 @@ class RemoteTrainingSystem(WMLResource):
 
         RemoteTrainingSystem._validate_type(remote_training_system_id, u'remote_training_system_id', STR_TYPE, True)
 
-        href = self._href_definitions.get_function_href(remote_training_system_id)
+        href = self._client.service_instance._href_definitions.get_function_href(remote_training_system_id)
 
         resources = self._get_artifact_details(href + '/revisions',
                                                None,
