@@ -467,22 +467,22 @@ class Repository(WMLResource):
         url = ""
         type = ""
         if res['model'] is True:
-            url = self._href_definitions.get_published_model_href(artifact_id)
+            url = self._client.service_instance._href_definitions.get_published_model_href(artifact_id)
             type = "model"
         elif res['library'] is True:
-            url = self._href_definitions.get_custom_library_href(artifact_id)
+            url = self._client.service_instance._href_definitions.get_custom_library_href(artifact_id)
             type = "library"
         elif res['runtime'] is True:
-            url = self._href_definitions.get_runtime_href(artifact_id)
+            url = self._client.service_instance._href_definitions.get_runtime_href(artifact_id)
             type = "runtime"
         elif res['function'] is True:
-            url = self._href_definitions.get_function_href(artifact_id)
+            url = self._client.service_instance._href_definitions.get_function_href(artifact_id)
             type = "function"
         elif res['pipeline'] is True:
-            url = self._href_definitions.get_pipeline_href(artifact_id)
+            url = self._client.service_instance._href_definitions.get_pipeline_href(artifact_id)
             type = "pipeline"
         elif res['experiment'] is True:
-            url = self._href_definitions.get_experiment_href(artifact_id)
+            url = self._client.service_instance._href_definitions.get_experiment_href(artifact_id)
             type = "experiment"
 
 
@@ -900,9 +900,9 @@ class Repository(WMLResource):
             return self._client._models.download(artifact_uid, filename, rev_uid,format)
         elif res['function'] is True:
             return self._client._functions.download(artifact_uid, filename, rev_uid)
-        elif not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_35 and res['library'] is True:
+        elif not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_35 and not self._client.ICP_40 and res['library'] is True:
             return self._client.runtimes.download_library(artifact_uid, filename)
-        elif not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_35 and res['runtime'] is True:
+        elif not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_35 and not self._client.ICP_40 and res['runtime'] is True:
             return self._client.runtimes.download_configuration(artifact_uid, filename)
         else:
             raise WMLClientError('Unexpected type of artifact to download or Artifact with artifact_uid: \'{}\' does not exist.'.format(artifact_uid) )
@@ -941,11 +941,11 @@ class Repository(WMLResource):
             params.update({'purge_on_delete': 'true'})
 
         if not self._ICP:
-            response = requests.delete(self._href_definitions.get_asset_href(artifact_uid),
+            response = requests.delete(self._client.service_instance._href_definitions.get_asset_href(artifact_uid),
                                            params=params,
                                            headers=self._client._get_headers())
         else:
-            response = requests.delete(self._href_definitions.get_asset_href(artifact_uid),
+            response = requests.delete(self._client.service_instance._href_definitions.get_asset_href(artifact_uid),
                                        params=params,
                                        headers=self._client._get_headers(), verify=False)
 
@@ -1182,7 +1182,7 @@ class Repository(WMLResource):
         Repository._validate_type(experiment_uid, u'experiment_uid', STR_TYPE, False)
         Repository._validate_type(limit, u'limit', int, False)
 
-        url = self._href_definitions.get_experiments_href()
+        url = self._client.service_instance._href_definitions.get_experiments_href()
 
         return self._client.experiments.get_details(experiment_uid, limit)
 
@@ -1889,19 +1889,19 @@ class Repository(WMLResource):
 
         if self._client.CLOUD_PLATFORM_SPACES or self._client.ICP_PLATFORM_SPACES:
             endpoints = {
-                u'model': self._href_definitions.get_published_models_href(),
-                u'experiment': self._href_definitions.get_experiments_href(),
-                u'pipeline': self._href_definitions.get_pipelines_href(),
-                u'function': self._href_definitions.get_functions_href()
+                u'model': self._client.service_instance._href_definitions.get_published_models_href(),
+                u'experiment': self._client.service_instance._href_definitions.get_experiments_href(),
+                u'pipeline': self._client.service_instance._href_definitions.get_pipelines_href(),
+                u'function': self._client.service_instance._href_definitions.get_functions_href()
             }
         else:
             endpoints = {
-                u'model': self._href_definitions.get_published_models_href(),
-                u'experiment': self._href_definitions.get_experiments_href(),
-                u'pipeline': self._href_definitions.get_pipelines_href(),
-                u'function': self._href_definitions.get_functions_href(),
-                u'runtime': self._href_definitions.get_runtimes_href(),
-                u'library': self._href_definitions.get_custom_libraries_href()
+                u'model': self._client.service_instance._href_definitions.get_published_models_href(),
+                u'experiment': self._client.service_instance._href_definitions.get_experiments_href(),
+                u'pipeline': self._client.service_instance._href_definitions.get_pipelines_href(),
+                u'function': self._client.service_instance._href_definitions.get_functions_href(),
+                u'runtime': self._client.service_instance._href_definitions.get_runtimes_href(),
+                u'library': self._client.service_instance._href_definitions.get_custom_libraries_href()
             }
 
         artifact_get = {}
@@ -2122,7 +2122,7 @@ class Repository(WMLResource):
         isIcp=self._ICP
 
         if self._client.WSD:
-            endpoint = self._href_definitions.get_model_definition_assets_href() + "/" + artifact_uid
+            endpoint = self._client.service_instance._href_definitions.get_model_definition_assets_href() + "/" + artifact_uid
             response = requests.get(
                 endpoint,
                 params=self._client._params(),
@@ -2140,20 +2140,20 @@ class Repository(WMLResource):
         else:
             if self._client.CLOUD_PLATFORM_SPACES or self._client.ICP_PLATFORM_SPACES:
                 endpoints = {
-                    u'model': self._href_definitions.get_model_last_version_href(artifact_uid),
-                    u'pipeline': self._href_definitions.get_pipeline_href(artifact_uid),
-                    u'experiment': self._href_definitions.get_experiment_href(artifact_uid),
-                    u'function': self._href_definitions.get_function_href(artifact_uid)
+                    u'model': self._client.service_instance._href_definitions.get_model_last_version_href(artifact_uid),
+                    u'pipeline': self._client.service_instance._href_definitions.get_pipeline_href(artifact_uid),
+                    u'experiment': self._client.service_instance._href_definitions.get_experiment_href(artifact_uid),
+                    u'function': self._client.service_instance._href_definitions.get_function_href(artifact_uid)
                 }
             else:
                 endpoints = {
-                        u'model': self._href_definitions.get_model_last_version_href(artifact_uid),
-                        u'pipeline': self._href_definitions.get_pipeline_href(artifact_uid),
-                        u'experiment': self._href_definitions.get_experiment_href(artifact_uid),
-                        u'function': self._href_definitions.get_function_href(artifact_uid),
-                        u'runtime': self._href_definitions.get_runtime_href(artifact_uid),
-                        u'library': self._href_definitions.get_custom_library_href(artifact_uid),
-                        u'space': self._href_definitions.get_space_href(artifact_uid)
+                        u'model': self._client.service_instance._href_definitions.get_model_last_version_href(artifact_uid),
+                        u'pipeline': self._client.service_instance._href_definitions.get_pipeline_href(artifact_uid),
+                        u'experiment': self._client.service_instance._href_definitions.get_experiment_href(artifact_uid),
+                        u'function': self._client.service_instance._href_definitions.get_function_href(artifact_uid),
+                        u'runtime': self._client.service_instance._href_definitions.get_runtime_href(artifact_uid),
+                        u'library': self._client.service_instance._href_definitions.get_custom_library_href(artifact_uid),
+                        u'space': self._client.service_instance._href_definitions.get_space_href(artifact_uid)
                     }
             future = {}
             for artifact in endpoints:
