@@ -96,16 +96,16 @@ class SwSpec(WMLResource):
         SwSpec._validate_type(sw_spec_uid, u'sw_spec_uid', STR_TYPE, True)
 
         if not self._ICP:
-            response = requests.get(self._href_definitions.get_sw_spec_href(sw_spec_uid),
+            response = requests.get(self._client.service_instance._href_definitions.get_sw_spec_href(sw_spec_uid),
                                     params=self._client._params(skip_space_project_chk=True),
                                     headers=self._client._get_headers())
         else:
             if self._client.ICP_PLATFORM_SPACES:
-                response = requests.get(self._href_definitions.get_sw_spec_href(sw_spec_uid),
+                response = requests.get(self._client.service_instance._href_definitions.get_sw_spec_href(sw_spec_uid),
                                         params=self._client._params(skip_space_project_chk=True),
                                         headers=self._client._get_headers(), verify=False)
             else:
-                response = requests.get(self._href_definitions.get_sw_spec_href(sw_spec_uid), params=self._client._params(),
+                response = requests.get(self._client.service_instance._href_definitions.get_sw_spec_href(sw_spec_uid), params=self._client._params(),
                                           headers=self._client._get_headers(), verify=False)
 
         if response.status_code == 200:
@@ -155,7 +155,7 @@ class SwSpec(WMLResource):
             client=self._client)
 
         sw_spec_meta_json = json.dumps(sw_spec_meta)
-        href = self._href_definitions.get_sw_specs_href()
+        href = self._client.service_instance._href_definitions.get_sw_specs_href()
 
         if not self._ICP:
             creation_response = requests.post(href, params=self._client._params(), headers=self._client._get_headers(), data=sw_spec_meta_json)
@@ -167,10 +167,16 @@ class SwSpec(WMLResource):
         return sw_spec_details
 
 
-    def list(self):
+    def list(self, limit=None):
         """
            List software specifications.
 
+           **Parameters**
+
+           .. important::
+                #. **limit**:  limit number of fetched records\n
+                   **type**: int\n
+
            **Output**
 
            .. important::
@@ -183,7 +189,7 @@ class SwSpec(WMLResource):
         """
 
         if not self._client.WSD_20:
-            href = self._href_definitions.get_sw_specs_href()
+            href = self._client.service_instance._href_definitions.get_sw_specs_href()
             if not self._ICP:
                 response = requests.get(href, params=self._client._params(), headers=self._client._get_headers())
             else:
@@ -194,7 +200,7 @@ class SwSpec(WMLResource):
                 (m[u'metadata'][u'name'], m[u'metadata'][u'asset_id'],m[u'entity'][u'software_specification'].get('type', 'derived')) for
                 m in asset_details]
 
-            self._list(sw_spec_values, [u'NAME', u'ASSET_ID', u'TYPE'], None, _DEFAULT_LIST_LENGTH)
+            self._list(sw_spec_values, [u'NAME', u'ASSET_ID', u'TYPE'], limit, _DEFAULT_LIST_LENGTH)
         else:
             from tabulate import tabulate
             header = [u'NAME', u'ASSET_ID', u'TYPE']
@@ -321,12 +327,12 @@ class SwSpec(WMLResource):
             parameters = self._client._params(skip_space_project_chk=True)
             parameters.update(name=sw_spec_name)
             if not self._ICP:
-                response = requests.get(self._href_definitions.get_sw_specs_href(),
+                response = requests.get(self._client.service_instance._href_definitions.get_sw_specs_href(),
                                         params=parameters,
                                         headers=self._client._get_headers())
             else:
 
-                response = requests.get(self._href_definitions.get_sw_specs_href(),
+                response = requests.get(self._client.service_instance._href_definitions.get_sw_specs_href(),
                                         params=parameters,
                                         headers=self._client._get_headers(), verify=False)
             if response.status_code == 200:
@@ -398,10 +404,10 @@ class SwSpec(WMLResource):
         SwSpec._validate_type(sw_spec_uid, u'sw_spec_uid', STR_TYPE, True)
 
         if not self._ICP:
-            response = requests.delete(self._href_definitions.get_sw_spec_href(sw_spec_uid), params=self._client._params(),
+            response = requests.delete(self._client.service_instance._href_definitions.get_sw_spec_href(sw_spec_uid), params=self._client._params(),
                                     headers=self._client._get_headers())
         else:
-            response = requests.delete(self._href_definitions.get_sw_spec_href(sw_spec_uid), params=self._client._params(),
+            response = requests.delete(self._client.service_instance._href_definitions.get_sw_spec_href(sw_spec_uid), params=self._client._params(),
                                       headers=self._client._get_headers(), verify=False)
         if response.status_code == 200:
             return self._get_required_element_from_response(response.json())
@@ -439,7 +445,7 @@ class SwSpec(WMLResource):
         self._validate_type(sw_spec_uid, u'sw_spec_uid', STR_TYPE, True)
         self._validate_type(pkg_extn_id, u'pkg_extn_id', STR_TYPE, True)
 
-        url = self._href_definitions.get_sw_spec_href(sw_spec_uid)
+        url = self._client.service_instance._href_definitions.get_sw_spec_href(sw_spec_uid)
 
         url = url + "/package_extensions/" + pkg_extn_id
 
@@ -484,7 +490,7 @@ class SwSpec(WMLResource):
         self._validate_type(sw_spec_uid, u'sw_spec_uid', STR_TYPE, True)
         self._validate_type(pkg_extn_id, u'pkg_extn_id', STR_TYPE, True)
 
-        url = self._href_definitions.get_sw_spec_href(sw_spec_uid)
+        url = self._client.service_instance._href_definitions.get_sw_spec_href(sw_spec_uid)
 
         url = url + "/package_extensions/" + pkg_extn_id
 
@@ -519,7 +525,7 @@ class SwSpec(WMLResource):
             elif self._client.default_project_id is not None:
                 if self._client.WSD:
 
-                    href = "/v2/assets/" + response_data['metadata']['asset_id'] + "?" + "project_id=" + response_data['metadata']['project_id']
+                    href = self._client.service_instance._href_definitions.get_base_asset_href(response_data['metadata']['asset_id']) + "?" + "project_id=" + response_data['metadata']['project_id']
 
                     new_el = {'metadata': {
                                            'name': response_data['metadata']['name'],
