@@ -1,7 +1,7 @@
 import unittest
 import time
 import pandas as pd
-from ibm_watson_machine_learning.utils.log_util import get_logger
+import logging
 from ibm_watson_machine_learning.wml_client_error import ApiRequestFailure
 from ibm_watson_machine_learning.tests.CP4D_35.preparation_and_cleaning import *
 
@@ -11,7 +11,7 @@ class TestWMLClientWithHybrid(unittest.TestCase):
     model_id = None
     scoring_url = None
     scoring_id = None
-    logger = get_logger(__name__)
+    logger = logging.getLogger(__name__)
 
     @classmethod
     def setUpClass(self):
