@@ -17,17 +17,18 @@ from ibm_watson_machine_learning.experiment.autoai.optimizers import RemoteAutoP
 from ibm_watson_machine_learning.utils.autoai.errors import CannotReadSavedRemoteDataBeforeFit
 
 
-from ibm_watson_machine_learning.tests.utils import get_wml_credentials, get_cos_credentials, is_cp4d, bucket_exists, bucket_name_gen, get_space_id
-from ibm_watson_machine_learning.tests.utils.cleanup import delete_model_deployment, bucket_cleanup, space_cleanup
+from ibm_watson_machine_learning.tests.utils import (get_wml_credentials, get_cos_credentials, is_cp4d, bucket_exists,
+                                                     get_space_id, create_bucket)
+from ibm_watson_machine_learning.tests.utils.cleanup import delete_model_deployment,  space_cleanup
 
 from ibm_watson_machine_learning.utils.autoai.enums import PositiveLabelClass, RunStateTypes
 from ibm_watson_machine_learning.utils.autoai.utils import chose_model_output
 
 
 
-from lale import wrap_imported_operators
-from lale.operators import TrainablePipeline
-from lale.lib.lale import Hyperopt
+# from lale import wrap_imported_operators
+# from lale.operators import TrainablePipeline
+# from lale.lib.lale import Hyperopt
 
 
 class TestAutoAIRemote(unittest.TestCase):
@@ -101,7 +102,14 @@ class TestAutoAIRemote(unittest.TestCase):
         """
 
         cls.wml_credentials = get_wml_credentials()
-
+        try:
+            del cls.wml_credentials['bedrock_url']
+        except:
+            pass
+        try:
+            del cls.wml_credentials['password']
+        except:
+            pass
         cls.wml_client = APIClient(wml_credentials=cls.wml_credentials)
 
         if not cls.wml_client.ICP:
@@ -139,15 +147,7 @@ class TestAutoAIRemote(unittest.TestCase):
         )
         # Prepare bucket
         if not bucket_exists(cos_resource, self.bucket_name):
-            try:
-                bucket_cleanup(cos_resource, prefix=f"{self.bucket_name}-")
-            except Exception as e:
-                print(f"Bucket cleanup with prefix {self.bucket_name}- failed due to:\n{e}\n skipped")
-
-            import datetime
-            TestAutoAIRemote.bucket_name = bucket_name_gen(prefix=f"{self.bucket_name}-{str(datetime.date.today())}")
-            print(f"Creating COS bucket: {TestAutoAIRemote.bucket_name}")
-            cos_resource.Bucket(TestAutoAIRemote.bucket_name).create()
+            TestAutoAIRemote.bucket_name = create_bucket(cos_resource, self.bucket_name)
 
             self.assertIsNotNone(TestAutoAIRemote.bucket_name)
             self.assertTrue(bucket_exists(cos_resource, TestAutoAIRemote.bucket_name))
@@ -155,9 +155,8 @@ class TestAutoAIRemote(unittest.TestCase):
         print(f"Using COS bucket: {TestAutoAIRemote.bucket_name}")
 
     def test_01_initialize_AutoAI_experiment__pass_credentials__object_initialized(self):
-        TestAutoAIRemote.experiment = AutoAI(wml_credentials=self.wml_credentials.copy(),
-                                             project_id=self.project_id,
-                                             space_id=self.space_id)
+        TestAutoAIRemote.experiment = AutoAI(wml_credentials=self.wml_credentials,
+                                             project_id=self.project_id)
 
         self.assertIsInstance(self.experiment, AutoAI, msg="Experiment is not of type AutoAI.")
 
@@ -217,7 +216,7 @@ class TestAutoAIRemote(unittest.TestCase):
             prediction_column='y',
             positive_label='yes',
             scoring=self.scoring_method,
-            test_size=0.1,
+            holdout_size=0.1,
             max_number_of_estimators=self.max_number_of_estimators,
             excel_sheet=self.sheet_name,
             autoai_pod_version=self.pod_version
@@ -264,7 +263,9 @@ class TestAutoAIRemote(unittest.TestCase):
         # end note
 
         status = self.remote_auto_pipelines.get_run_status()
-        self.assertNotIn(status, ['failed', 'canceled'], msg=f"Training finished with status {status}.")
+        run_details = self.remote_auto_pipelines.get_run_details().get('entity')
+        self.assertNotIn(status, ['failed', 'canceled'], msg=f"Training finished with status {status}. \n"
+                                                             f"Details: {run_details.get('status')}")
         print("\n 1st pipeline completed")
         summary_df = self.remote_auto_pipelines.summary()
         print(summary_df)
@@ -307,7 +308,8 @@ class TestAutoAIRemote(unittest.TestCase):
     def test_10_deployment_setup_and_preparation(self):
         TestAutoAIRemote.service = WebService(source_wml_credentials=self.wml_credentials.copy(),
                                               source_project_id=self.project_id,
-                                              source_space_id=self.space_id)
+                                              target_wml_credentials=self.wml_credentials,
+                                              target_space_id=self.space_id)
 
         self.wml_client.set.default_space(self.space_id)
         delete_model_deployment(self.wml_client, deployment_name=self.DEPLOYMENT_NAME)
@@ -382,6 +384,7 @@ class TestAutoAIRemote(unittest.TestCase):
         TestAutoAIRemote.pipeline = self.remote_auto_pipelines.get_pipeline(pipeline_name='Pipeline_4')
         print(f"Fetched pipeline type: {type(self.pipeline)}")
 
+        from lale.operators import TrainablePipeline
         self.assertIsInstance(self.pipeline, TrainablePipeline,
                               msg="Fetched pipeline is not of TrainablePipeline instance.")
         predictions = self.pipeline.predict(
@@ -389,6 +392,7 @@ class TestAutoAIRemote(unittest.TestCase):
         print(predictions)
 
     def test_22_get_all_pipelines_as_lale(self):
+        from lale.operators import TrainablePipeline
         summary = self.remote_auto_pipelines.summary()
         print(summary)
         failed_pipelines = []
