@@ -99,7 +99,6 @@ class TestAutoAIRemote(unittest.TestCase):
         except:
             pass
 
-        assert(cls.wml_credentials.get('bedrock_url') is not None)
         assert(cls.wml_credentials.get('username') is not None)
         assert(cls.wml_credentials.get('password') is not None)
         assert(cls.wml_credentials.get('apikey') is None)
@@ -190,8 +189,8 @@ class TestAutoAIRemote(unittest.TestCase):
             prediction_column=self.prediction_column,
             positive_label=self.positive_label,
             scoring=PositiveLabelClass.PRECISION_SCORE_MICRO,
-            cognito_transform_names=[Transformers.DIFF,Transformers.SUM,Transformers.MAX,
-                                     Transformers.SIN,Transformers.SUM],
+            # cognito_transform_names=[Transformers.DIFF,Transformers.SUM,Transformers.MAX,
+            #                          Transformers.SIN,Transformers.SUM],
             include_only_estimators=[self.experiment.ClassificationAlgorithms.LR,
                                      self.experiment.ClassificationAlgorithms.LGBM],
             test_size=0.1,
@@ -267,7 +266,9 @@ class TestAutoAIRemote(unittest.TestCase):
 
     def test_08_get_run_details(self):
         parameters = self.remote_auto_pipelines.get_run_details()
-        # print(parameters)
+        print(parameters)
+        print("\n\n")
+        print(parameters.get('entity').get('status'))
         self.assertIsNotNone(parameters)
 
     def test_09_predict_using_fitted_pipeline(self):
