@@ -199,8 +199,8 @@ class TestAutoAIRemote(unittest.TestCase):
             prediction_column=self.prediction_column,
             positive_label=self.positive_label,
             scoring=PositiveLabelClass.PRECISION_SCORE_MICRO,
-            cognito_transform_names=[Transformers.DIFF,Transformers.SUM,Transformers.MAX,
-                                     Transformers.SIN,Transformers.SUM],
+            # cognito_transform_names=[Transformers.DIFF,Transformers.SUM,Transformers.MAX,
+            #                          Transformers.SIN,Transformers.SUM],
             test_size=0.1,
             max_number_of_estimators=1,
             t_shirt_size=TShirtSize.S if self.wml_client.ICP else TShirtSize.L
