@@ -1,8 +1,4 @@
 import unittest
-import pandas as pd
-from sklearn.pipeline import Pipeline
-from lale.operators import TrainablePipeline
-from lale.lib.lale import Hyperopt
 from os import environ
 import time
 
@@ -23,8 +19,8 @@ from ibm_watson_machine_learning.utils.autoai.enums import TShirtSize, RunStateT
 from ibm_watson_machine_learning.utils.autoai.utils import chose_model_output
 
 from ibm_watson_machine_learning.tests.utils import get_wml_credentials, get_cos_credentials, is_cp4d, bucket_exists,\
-    bucket_name_gen, get_space_id
-from ibm_watson_machine_learning.tests.utils.cleanup import delete_model_deployment, bucket_cleanup, space_cleanup
+    create_bucket, get_space_id
+from ibm_watson_machine_learning.tests.utils.cleanup import delete_model_deployment, space_cleanup
 
 
 
@@ -103,7 +99,14 @@ class TestAutoAIRemote(unittest.TestCase):
         """
 
         cls.wml_credentials = get_wml_credentials()
-
+        try:
+            del cls.wml_credentials['bedrock_url']
+        except:
+            pass
+        try:
+            del cls.wml_credentials['password']
+        except:
+            pass
         cls.wml_client = APIClient(wml_credentials=cls.wml_credentials.copy())
 
         if not cls.wml_client.ICP:
@@ -141,15 +144,7 @@ class TestAutoAIRemote(unittest.TestCase):
         )
         # Prepare bucket
         if not bucket_exists(cos_resource, self.bucket_name):
-            try:
-                bucket_cleanup(cos_resource, prefix=f"{self.bucket_name}-")
-            except Exception as e:
-                print(f"Bucket cleanup with prefix {self.bucket_name}- failed due to:\n{e}\n skipped")
-
-            import datetime
-            TestAutoAIRemote.bucket_name = bucket_name_gen(prefix=f"{self.bucket_name}-{str(datetime.date.today())}")
-            print(f"Creating COS bucket: {TestAutoAIRemote.bucket_name}")
-            cos_resource.Bucket(TestAutoAIRemote.bucket_name).create()
+            TestAutoAIRemote.bucket_name = create_bucket(cos_resource, self.bucket_name)
 
             self.assertIsNotNone(TestAutoAIRemote.bucket_name)
             self.assertTrue(bucket_exists(cos_resource, TestAutoAIRemote.bucket_name))
@@ -337,6 +332,7 @@ class TestAutoAIRemote(unittest.TestCase):
         TestAutoAIRemote.lale_pipeline = self.remote_auto_pipelines.get_pipeline(
             pipeline_name='Pipeline_1')
         print(f"Fetched pipeline type: {type(self.lale_pipeline)}")
+        from lale.operators import TrainablePipeline
         self.assertIsInstance(self.lale_pipeline, TrainablePipeline)
 
     ########
@@ -344,6 +340,7 @@ class TestAutoAIRemote(unittest.TestCase):
     ########
 
     def test_17_get_all_pipelines_as_lale(self):
+        from lale.operators import TrainablePipeline
         summary = self.remote_auto_pipelines.summary()
         print(summary)
         failed_pipelines = []
