@@ -18,16 +18,12 @@ from ibm_watson_machine_learning.experiment.autoai.optimizers import RemoteAutoP
 from ibm_watson_machine_learning.utils.autoai.errors import NotExistingCOSResource
 
 from ibm_watson_machine_learning.tests.utils import (get_wml_credentials, get_cos_credentials, bucket_exists,
-                                                        bucket_name_gen, get_space_id, is_cp4d)
-from ibm_watson_machine_learning.tests.utils.cleanup import bucket_cleanup, space_cleanup, delete_model_deployment
+                                                     create_bucket, get_space_id)
+from ibm_watson_machine_learning.tests.utils.cleanup import space_cleanup, delete_model_deployment
 
 from ibm_watson_machine_learning.utils.autoai.enums import PositiveLabelClass, TShirtSize, Transformers
 
 
-from lale import wrap_imported_operators
-from lale.operators import TrainablePipeline
-from lale.lib.lale import Hyperopt
-
 
 class TestAutoAIRemote(unittest.TestCase):
     """
@@ -98,6 +94,14 @@ class TestAutoAIRemote(unittest.TestCase):
         Load WML credentials from config.ini file based on ENV variable.
         """
         cls.wml_credentials = get_wml_credentials()
+        try:
+            del cls.wml_credentials['bedrock_url']
+        except:
+            pass
+        try:
+            del cls.wml_credentials['password']
+        except:
+            pass
         cls.wml_client = APIClient(wml_credentials=cls.wml_credentials.copy())
 
         if not cls.wml_client.ICP:
@@ -133,15 +137,7 @@ class TestAutoAIRemote(unittest.TestCase):
         )
         # Prepare bucket
         if not bucket_exists(cos_resource, self.bucket_name):
-            try:
-                bucket_cleanup(cos_resource, prefix=f"{self.bucket_name}-")
-            except Exception as e:
-                print(f"Bucket cleanup with prefix {self.bucket_name}- failed due to:\n{e}\n skipped")
-
-            import datetime
-            TestAutoAIRemote.bucket_name = bucket_name_gen(prefix=f"{self.bucket_name}-{str(datetime.date.today())}")
-            print(f"Creating COS bucket: {TestAutoAIRemote.bucket_name}")
-            cos_resource.Bucket(TestAutoAIRemote.bucket_name).create()
+            TestAutoAIRemote.bucket_name = create_bucket(cos_resource, self.bucket_name)
 
             self.assertIsNotNone(TestAutoAIRemote.bucket_name)
             self.assertTrue(bucket_exists(cos_resource, TestAutoAIRemote.bucket_name))
@@ -195,7 +191,7 @@ class TestAutoAIRemote(unittest.TestCase):
             scoring=PositiveLabelClass.PRECISION_SCORE_MICRO,
             cognito_transform_names=[Transformers.DIFF,Transformers.SUM,Transformers.MAX,
                                      Transformers.SIN,Transformers.SUM],
-            test_size=0.1,
+            holdout_size=0.1,
             max_number_of_estimators=1,
             t_shirt_size=TShirtSize.S if self.wml_client.ICP else TShirtSize.L
         )
@@ -235,7 +231,7 @@ class TestAutoAIRemote(unittest.TestCase):
             scoring=PositiveLabelClass.PRECISION_SCORE_MICRO,
             cognito_transform_names=[Transformers.DIFF,Transformers.SUM,Transformers.MAX,
                                      Transformers.SIN,Transformers.SUM],
-            test_size=0.1,
+            holdout_size=0.1,
             max_number_of_estimators=1,
             t_shirt_size=TShirtSize.S if self.wml_client.ICP else TShirtSize.L,
             drop_duplicates=False
