@@ -1,8 +1,7 @@
 import unittest
 import pandas as pd
 from sklearn.pipeline import Pipeline
-from lale.operators import TrainablePipeline
-from lale.lib.lale import Hyperopt
+
 from os import environ
 
 import traceback
@@ -15,9 +14,9 @@ from ibm_watson_machine_learning.experiment.autoai.optimizers import RemoteAutoP
 from ibm_watson_machine_learning.deployment import WebService
 
 from ibm_watson_machine_learning.tests.utils import get_wml_credentials, get_cos_credentials, is_cp4d, bucket_exists, \
-    bucket_name_gen, get_space_id
+    create_bucket, get_space_id
 
-from ibm_watson_machine_learning.tests.utils.cleanup import delete_model_deployment, bucket_cleanup, space_cleanup
+from ibm_watson_machine_learning.tests.utils.cleanup import delete_model_deployment, space_cleanup
 
 
 class TestAutoAIRemote(unittest.TestCase):
@@ -90,7 +89,14 @@ class TestAutoAIRemote(unittest.TestCase):
         """
 
         cls.wml_credentials = get_wml_credentials()
-
+        try:
+            del cls.wml_credentials['bedrock_url']
+        except:
+            pass
+        try:
+            del cls.wml_credentials['password']
+        except:
+            pass
         cls.wml_client = APIClient(wml_credentials=cls.wml_credentials)
 
         if not cls.wml_client.ICP:
@@ -126,15 +132,7 @@ class TestAutoAIRemote(unittest.TestCase):
         )
         # Prepare bucket
         if not bucket_exists(cos_resource, self.bucket_name):
-            try:
-                bucket_cleanup(cos_resource, prefix=f"{self.bucket_name}-")
-            except Exception as e:
-                print(f"Bucket cleanup with prefix {self.bucket_name}- failed due to:\n{e}\n skipped")
-
-            import datetime
-            TestAutoAIRemote.bucket_name = bucket_name_gen(prefix=f"{self.bucket_name}-{str(datetime.date.today())}")
-            print(f"Creating COS bucket: {TestAutoAIRemote.bucket_name}")
-            cos_resource.Bucket(TestAutoAIRemote.bucket_name).create()
+            TestAutoAIRemote.bucket_name = create_bucket(cos_resource, self.bucket_name)
 
             self.assertIsNotNone(TestAutoAIRemote.bucket_name)
             self.assertTrue(bucket_exists(cos_resource, TestAutoAIRemote.bucket_name))
@@ -256,6 +254,7 @@ class TestAutoAIRemote(unittest.TestCase):
         TestAutoAIRemote.lale_pipeline = self.remote_auto_pipelines.get_pipeline(
             pipeline_name='Pipeline_1')
         print(f"Fetched pipeline type: {type(self.lale_pipeline)}")
+        from lale.operators import TrainablePipeline
         self.assertIsInstance(self.lale_pipeline, TrainablePipeline)
 
     ########
@@ -271,6 +270,7 @@ class TestAutoAIRemote(unittest.TestCase):
             lale_pipeline = None
             try:
                 lale_pipeline = self.remote_auto_pipelines.get_pipeline(pipeline_name=pipeline_name)
+                from lale.operators import TrainablePipeline
                 self.assertIsInstance(lale_pipeline, TrainablePipeline)
                 predictions = lale_pipeline.predict(
                     X=self.train_data.values[:1])
