@@ -18,6 +18,7 @@ from ibm_watson_machine_learning.tests.utils.cleanup import delete_model_deploym
 
 
 @unittest.skipIf(not (is_cp4d()), "Supported only on CP4D")
+@unittest.skipIf(is_cp4d(), "NFS setup not implemented in tests for all cluster")
 class TestAutoAIRemote(unittest.TestCase):
     """
     The test covers:
@@ -86,7 +87,7 @@ class TestAutoAIRemote(unittest.TestCase):
             pass
         cls.wml_client = APIClient(wml_credentials=cls.wml_credentials.copy())
         cls.project_id = cls.wml_credentials.get('project_id')
-        cls.connection_id, cls.data_location, _ = setup_nfs_env(cls.wml_credentials, cls.dataset_name)
+        cls.connection_id, cls.data_location, _ = setup_nfs_env(get_wml_credentials(), cls.dataset_name)
 
     def test_00a_space_cleanup(self):
         space_cleanup(self.wml_client,
