@@ -17,9 +17,9 @@ from ibm_watson_machine_learning.helpers.connections import S3Connection, S3Loca
 from ibm_watson_machine_learning.experiment.autoai.optimizers import RemoteAutoPipelines
 
 from ibm_watson_machine_learning.tests.utils import bucket_exists, \
-    bucket_name_gen, get_space_id
+    create_bucket, get_space_id
 
-from ibm_watson_machine_learning.tests.utils.cleanup import bucket_cleanup, space_cleanup
+from ibm_watson_machine_learning.tests.utils.cleanup import space_cleanup
 
 from ibm_watson_machine_learning.tests.utils import (
     get_wml_credentials, get_cos_credentials, is_cp4d, print_test_separators)
@@ -98,6 +98,14 @@ class TestOBMOnly(unittest.TestCase):
         Load WML credentials from config.ini file based on ENV variable.
         """
         cls.wml_credentials = get_wml_credentials()
+        try:
+            del cls.wml_credentials['bedrock_url']
+        except:
+            pass
+        try:
+            del cls.wml_credentials['password']
+        except:
+            pass
         if not is_cp4d():
             cls.cos_credentials = get_cos_credentials()
             if 'endpoint_url' in cls.cos_credentials:
@@ -135,15 +143,7 @@ class TestOBMOnly(unittest.TestCase):
         )
         # Prepare bucket
         if not bucket_exists(cos_resource, self.bucket_name):
-            try:
-                bucket_cleanup(cos_resource, prefix=f"{self.bucket_name}-")
-            except Exception as e:
-                print(f"Bucket cleanup with prefix {self.bucket_name}- failed due to:\n{e}\n skipped")
-
-            import datetime
-            TestOBMOnly.bucket_name = bucket_name_gen(prefix=f"{self.bucket_name}-{str(datetime.date.today())}")
-            print(f"Creating COS bucket: {TestOBMOnly.bucket_name}")
-            cos_resource.Bucket(TestOBMOnly.bucket_name).create()
+            TestOBMOnly.bucket_name = create_bucket(cos_resource, self.bucket_name)
 
             self.assertIsNotNone(TestOBMOnly.bucket_name)
             self.assertTrue(bucket_exists(cos_resource, TestOBMOnly.bucket_name))
