@@ -20,17 +20,16 @@ from ibm_watson_machine_learning.tests.utils import print_test_separators
 from ibm_watson_machine_learning.utils.autoai.errors import WrongDataJoinGraphNodeName
 
 from ibm_watson_machine_learning.tests.utils import get_wml_credentials, get_cos_credentials, is_cp4d, bucket_exists, \
-    bucket_name_gen, get_space_id
+    create_bucket, get_space_id
 
-from ibm_watson_machine_learning.tests.utils.cleanup import bucket_cleanup, space_cleanup
+from ibm_watson_machine_learning.tests.utils.cleanup import space_cleanup
 
 
 
 from ibm_watson_machine_learning.tests.utils.cleanup import delete_model_deployment
 
-from lale import wrap_imported_operators
-from lale.operators import TrainablePipeline
-from lale.lib.lale import Hyperopt
+# from lale.operators import TrainablePipeline
+# from lale.lib.lale import Hyperopt
 
 get_step_details = OBMPipelineGraphBuilder.get_step_details
 get_join_extractors = OBMPipelineGraphBuilder.get_join_extractors
@@ -119,6 +118,14 @@ class TestOBMAndKB(unittest.TestCase):
         Load WML credentials from config.ini file based on ENV variable.
         """
         cls.wml_credentials = get_wml_credentials()
+        try:
+            del cls.wml_credentials['bedrock_url']
+        except:
+            pass
+        try:
+            del cls.wml_credentials['password']
+        except:
+            pass
         if not is_cp4d():
             cls.cos_credentials = get_cos_credentials()
             cls.cos_endpoint = cls.cos_credentials.get('endpoint_url')
@@ -157,15 +164,7 @@ class TestOBMAndKB(unittest.TestCase):
         )
         # Prepare bucket
         if not bucket_exists(cos_resource, self.bucket_name):
-            try:
-                bucket_cleanup(cos_resource, prefix=f"{self.bucket_name}-")
-            except Exception as e:
-                print(f"Bucket cleanup with prefix {self.bucket_name}- failed due to:\n{e}\n skipped")
-
-            import datetime
-            TestOBMAndKB.bucket_name = bucket_name_gen(prefix=f"{self.bucket_name}-{str(datetime.date.today())}")
-            print(f"Creating COS bucket: {TestOBMAndKB.bucket_name}")
-            cos_resource.Bucket(TestOBMAndKB.bucket_name).create()
+            TestOBMAndKB.bucket_name = create_bucket(cos_resource, self.bucket_name)
 
             self.assertIsNotNone(TestOBMAndKB.bucket_name)
             self.assertTrue(bucket_exists(cos_resource, TestOBMAndKB.bucket_name))
@@ -349,10 +348,10 @@ class TestOBMAndKB(unittest.TestCase):
             prediction_column='next_purchase',
             scoring=AutoAI.Metrics.LOG_LOSS,
             max_number_of_estimators=1,
-            daub_include_only_estimators=[self.experiment.RegressionAlgorithms.LGBM],
+            include_only_estimators=[self.experiment.RegressionAlgorithms.LGBM],
             data_join_graph=self.data_join_graph,
             t_shirt_size=self.experiment.TShirtSize.L if not is_cp4d() else self.experiment.TShirtSize.S,
-            test_size=0.1
+            holdout_size=0.1
         )
 
         self.assertIsInstance(self.remote_auto_pipelines, RemoteAutoPipelines,
@@ -580,7 +579,7 @@ class TestOBMAndKB(unittest.TestCase):
         print("Download and load Pipeline_4 as lale...")
         TestOBMAndKB.lale_pipeline = self.remote_auto_pipelines.get_pipeline(pipeline_name='Pipeline_4')
         print(f"Fetched pipeline type: {type(self.lale_pipeline)}")
-
+        from lale.operators import TrainablePipeline
         self.assertIsInstance(self.lale_pipeline, TrainablePipeline,
                               msg="Fetched pipeline is not of TrainablePipeline instance.")
 
@@ -595,8 +594,10 @@ class TestOBMAndKB(unittest.TestCase):
             lale_pipeline = None
             try:
                 lale_pipeline = self.remote_auto_pipelines.get_pipeline(pipeline_name=pipeline_name)
+
                 self.assertWarnsRegex(Warning, "OBM",
                                       msg="Warning (OBM pipeline support only for inspection and deployment) was not raised")
+                from lale.operators import TrainablePipeline
                 self.assertIsInstance(lale_pipeline, TrainablePipeline)
                 predictions = lale_pipeline.predict(X=self.holdout_data.drop(['next_purchase'], axis=1).values[:1])
                 print(predictions)
@@ -626,6 +627,7 @@ class TestOBMAndKB(unittest.TestCase):
     @print_test_separators
     def test_20a_remove_last_freeze_trainable_prefix_returned(self):
         print("Prepare pipeline to refinery...")
+        from lale.operators import TrainablePipeline
         from lale.lib.sklearn import KNeighborsClassifier, DecisionTreeClassifier, LogisticRegression
         prefix = self.lale_pipeline.remove_last().freeze_trainable()
         self.assertIsInstance(prefix, TrainablePipeline,
@@ -634,6 +636,8 @@ class TestOBMAndKB(unittest.TestCase):
 
     @print_test_separators
     def test_20b_hyperopt_fit_new_pipepiline(self):
+        from lale.lib.lale import Hyperopt
+
         print("Do a hyperparameters optimization...")
         hyperopt = Hyperopt(estimator=TestOBMAndKB.new_pipeline, cv=3, max_evals=2)
         try:
@@ -787,7 +791,7 @@ class TestOBMAndKB(unittest.TestCase):
             ),
             prediction_type='regression',
             prediction_column='next_purchase',
-            test_size=0.1,
+            holdout_size=0.1,
             scoring='neg_log_loss',
             max_number_of_estimators=1,
         )
