@@ -20,9 +20,9 @@ from ibm_watson_machine_learning.tests.utils import print_test_separators
 from ibm_watson_machine_learning.utils.autoai.errors import WrongDataJoinGraphNodeName
 
 from ibm_watson_machine_learning.tests.utils import get_wml_credentials, get_cos_credentials, is_cp4d, bucket_exists, \
-    bucket_name_gen, get_space_id
+    create_bucket, get_space_id
 
-from ibm_watson_machine_learning.tests.utils.cleanup import bucket_cleanup, space_cleanup
+from ibm_watson_machine_learning.tests.utils.cleanup import space_cleanup
 
 from ibm_watson_machine_learning.tests.utils.cleanup import delete_model_deployment
 
@@ -115,6 +115,14 @@ class TestOBMAndKB(unittest.TestCase):
         Load WML credentials from config.ini file based on ENV variable.
         """
         cls.wml_credentials = get_wml_credentials()
+        try:
+            del cls.wml_credentials['bedrock_url']
+        except:
+            pass
+        try:
+            del cls.wml_credentials['password']
+        except:
+            pass
         if not is_cp4d():
             cls.cos_credentials = get_cos_credentials()
             cls.cos_endpoint = cls.cos_credentials.get('endpoint_url')
@@ -151,15 +159,7 @@ class TestOBMAndKB(unittest.TestCase):
         )
         # Prepare bucket
         if not bucket_exists(cos_resource, self.bucket_name):
-            try:
-                bucket_cleanup(cos_resource, prefix=f"{self.bucket_name}-")
-            except Exception as e:
-                print(f"Bucket cleanup with prefix {self.bucket_name}- failed due to:\n{e}\n skipped")
-
-            import datetime
-            TestOBMAndKB.bucket_name = bucket_name_gen(prefix=f"{self.bucket_name}-{str(datetime.date.today())}")
-            print(f"Creating COS bucket: {TestOBMAndKB.bucket_name}")
-            cos_resource.Bucket(TestOBMAndKB.bucket_name).create()
+            TestOBMAndKB.bucket_name = create_bucket(cos_resource, self.bucket_name)
 
             self.assertIsNotNone(TestOBMAndKB.bucket_name)
             self.assertTrue(bucket_exists(cos_resource, TestOBMAndKB.bucket_name))
@@ -321,10 +321,10 @@ class TestOBMAndKB(unittest.TestCase):
             prediction_column='next_purchase',
             scoring=AutoAI.Metrics.ROOT_MEAN_SQUARED_ERROR,
             max_number_of_estimators=1,
-            daub_include_only_estimators=[self.experiment.RegressionAlgorithms.LGBM],
+            include_only_estimators=[self.experiment.RegressionAlgorithms.LGBM],
             data_join_graph=self.data_join_graph,
             t_shirt_size=self.experiment.TShirtSize.L if not is_cp4d() else self.experiment.TShirtSize.S,
-            test_size=0.1,
+            holdout_size=0.1,
             autoai_pod_version=self.pod_version
         )
 
@@ -418,6 +418,12 @@ class TestOBMAndKB(unittest.TestCase):
         TestOBMAndKB.run_id = self.trained_pipeline_details['metadata']['id']
 
         TestOBMAndKB.pipeline_name = 'Pipeline_4'
+
+        status = self.remote_auto_pipelines.get_run_status()
+        run_details = self.remote_auto_pipelines.get_run_details().get('entity')
+        self.assertNotIn(status, ['failed', 'canceled'], msg=f"Training finished with status {status}. \n"
+                                                             f"Details: {run_details.get('status')}")
+
         TestOBMAndKB.model_location = \
             self.trained_pipeline_details['entity']['status']['metrics'][-1]['context']['intermediate_model'][
                 'location'][
@@ -774,7 +780,7 @@ class TestOBMAndKB(unittest.TestCase):
                     )),
                 prediction_type='regression',
                 prediction_column='next_purchase',
-                test_size=0.1,
+                holdout_size=0.1,
                 scoring='neg_log_loss',
                 max_number_of_estimators=1,
             )
@@ -799,7 +805,7 @@ class TestOBMAndKB(unittest.TestCase):
                 ),
                 prediction_type='regression',
                 prediction_column='next_purchase',
-                test_size=0.1,
+                holdout_size=0.1,
                 scoring='neg_log_loss',
                 max_number_of_estimators=1,
             )
