@@ -12,7 +12,8 @@ from ibm_watson_machine_learning.deployment import Batch
 from ibm_watson_machine_learning.preprocessing import DataJoinGraph
 from ibm_watson_machine_learning.preprocessing.data_join_pipeline import OBMPipelineGraphBuilder
 
-from ibm_watson_machine_learning.helpers.connections import S3Connection, S3Location, DataConnection, FSLocation
+from ibm_watson_machine_learning.helpers.connections import S3Connection, S3Location, DataConnection, FSLocation, \
+    DeploymentOutputAssetLocation, AssetLocation
 
 from ibm_watson_machine_learning.experiment.autoai.optimizers import RemoteAutoPipelines
 
@@ -35,7 +36,6 @@ get_extractor_columns = OBMPipelineGraphBuilder.get_extractor_columns
 get_extractor_transformations = OBMPipelineGraphBuilder.get_extractor_transformations
 
 
-@unittest.skipIf(is_cp4d(), "Excel files and delimiters not yet supported on CPD")
 class TestOBMAndKB(unittest.TestCase):
     data_join_graph: 'DataJoinGraph' = None
     wml_client: 'APIClient' = None
@@ -54,6 +54,7 @@ class TestOBMAndKB(unittest.TestCase):
     run_id = None
 
     data_connections = []
+    data_connections_space_only = []
     main_conn = None
     temp_2_conn = None
     temp_3_conn = None
@@ -97,15 +98,6 @@ class TestOBMAndKB(unittest.TestCase):
     pipeline_name =None
     # --- end note
 
-    # # CP4D CONNECTION DETAILS:
-    # if 'qa' in get_env().lower():
-    #     space_id = 'aa81ee79-795a-4a23-8265-e87966dfe437'
-    #     project_id = '3d177338-3f8b-444d-b385-9ff929fd124f'
-    # else:
-    #     project_id = '60c1cecb-e3c2-45c6-a77b-dd3f6dd428af'
-    #     # space_id = None
-    #     space_id = '4e0541b8-174b-4d04-ae21-14c15475d68a'
-
     asset_id = None
     space_id = None
 
@@ -170,26 +162,32 @@ class TestOBMAndKB(unittest.TestCase):
     def test_01_create_multiple_data_connections__connections_created(self):
         print("Creating multiple data connections...")
         if self.wml_client.ICP:
-            TestOBMAndKB.main_conn = DataConnection(
-                data_join_node_name="main",
-                location=FSLocation(path=self.data_location + 'temp_1.csv'))
+            self.wml_client.set.default_space(self.space_id)
+            for dataset_no in range(1, 5):
+                conn = DataConnection(
+                    data_join_node_name=f"temp_{dataset_no}",
+                    location=FSLocation(path=self.data_location + f'temp_{dataset_no}.csv'))
 
-            TestOBMAndKB.temp_2_conn = DataConnection(
-                data_join_node_name="temp_2",
-                location=FSLocation(path=self.data_location + 'temp_2.csv'))
+                TestOBMAndKB.data_connections.append(conn)
 
-            TestOBMAndKB.temp_3_conn = DataConnection(
-                data_join_node_name="temp_3",
-                location=FSLocation(path=self.data_location + 'temp_3.csv'))
+                # additional data assets for scoring in space should be also created
+
+                asset_details = self.wml_client.data_assets.create(
+                    name=f'temp_{dataset_no}.csv',
+                    file_path=self.data_location + f'temp_{dataset_no}.csv')
+                asset_id = asset_details['metadata']['guid']
+
+                conn_space = DataConnection(
+                    data_join_node_name=f'temp_{dataset_no}',
+                    location=AssetLocation(asset_id=asset_id))
+
+                TestOBMAndKB.data_connections_space_only.append(conn_space)
 
-            TestOBMAndKB.temp_4_conn = DataConnection(
-                data_join_node_name="temp_4",
-                location=FSLocation(path=self.data_location + 'temp_4.csv'))
 
             TestOBMAndKB.results_connection = None
         else:
             TestOBMAndKB.main_conn = DataConnection(
-                data_join_node_name="main",
+                data_join_node_name="temp_1",
                 connection=S3Connection(
                     endpoint_url=self.cos_endpoint,
                     access_key_id=self.cos_credentials['cos_hmac_keys']['access_key_id'],
@@ -232,22 +230,22 @@ class TestOBMAndKB(unittest.TestCase):
                                     path=self.results_cos_path)
             )
 
-        TestOBMAndKB.data_connections = [self.main_conn,
-                                         self.temp_2_conn,
-                                         self.temp_3_conn,
-                                         self.temp_4_conn]
+            TestOBMAndKB.data_connections = [self.main_conn,
+                                             self.temp_2_conn,
+                                             self.temp_3_conn,
+                                             self.temp_4_conn]
 
     @print_test_separators
     def test_02a_create_data_join_graph__graph_created(self):
         print("Defining DataJoinGraph...")
         data_join_graph = DataJoinGraph()
         data_join_graph.node(name="temp_2")
-        data_join_graph.node(name="main", csv_separator=",", main=True)
+        data_join_graph.node(name="temp_1", csv_separator=",", main=True)
         data_join_graph.node(name="temp_3")
         data_join_graph.node(name="temp_4")
-        data_join_graph.edge(from_node="main", to_node="temp_2",
+        data_join_graph.edge(from_node="temp_1", to_node="temp_2",
                              from_column=["device"], to_column=["device"])
-        data_join_graph.edge(from_node="temp_3", to_node="main",
+        data_join_graph.edge(from_node="temp_3", to_node="temp_1",
                              from_column=["device"], to_column=["device"])
         data_join_graph.edge(from_node="temp_4", to_node="temp_3",
                              from_column=["device"], to_column=["device"])
@@ -261,7 +259,7 @@ class TestOBMAndKB(unittest.TestCase):
         print("Defining DataJoinGraph...")
         data_join_graph = DataJoinGraph()
         data_join_graph.node(name="temp_2")
-        data_join_graph.node(name="main", csv_separator=",", main=True)
+        data_join_graph.node(name="temp_1", csv_separator=",", main=True)
         with self.assertRaises(OBMMainNodeAlreadySet, msg="Check of OBM main node failed!"):
             data_join_graph.node(name="temp_3", main=True)
 
@@ -670,9 +668,13 @@ class TestOBMAndKB(unittest.TestCase):
     @print_test_separators
     def test_26_batch_deployment_setup_and_preparation(self):
         if is_cp4d():
-            TestOBMAndKB.service = Batch(self.wml_credentials.copy(), source_space_id=self.space_id)
+            TestOBMAndKB.service = Batch(source_wml_credentials=self.wml_credentials,
+                                         source_project_id=self.project_id,
+                                         target_wml_credentials=self.wml_credentials,
+                                         target_space_id=self.space_id)
+
         else:
-            TestOBMAndKB.service = Batch(self.wml_credentials,
+            TestOBMAndKB.service = Batch(source_wml_credentials=self.wml_credentials,
                                          source_space_id=self.space_id,
                                          target_wml_credentials=self.wml_credentials,
                                          target_space_id=self.space_id)
@@ -690,15 +692,22 @@ class TestOBMAndKB(unittest.TestCase):
 
     @print_test_separators
     def test_28_score_deployed_model(self):
-        scoring_params = self.service.run_job(
-            payload=self.data_connections,
-            output_data_reference=DataConnection(
+        if is_cp4d():
+            payload_reference = self.data_connections_space_only
+            output_data_reference = DataConnection(location=DeploymentOutputAssetLocation(name="batch_output_obm.csv"))
+        else:
+            payload_reference = self.data_connections
+            output_data_reference = DataConnection(
                 connection=S3Connection(endpoint_url=self.cos_endpoint,
                                         access_key_id=self.cos_credentials['cos_hmac_keys']['access_key_id'],
                                         secret_access_key=self.cos_credentials['cos_hmac_keys']['secret_access_key']),
                 location=S3Location(bucket=self.bucket_name,
                                     path="prediction_results.csv")
             ),
+
+        scoring_params = self.service.run_job(
+            payload=payload_reference,
+            output_data_reference=output_data_reference,
             background_mode=False)
         print(scoring_params)
 
@@ -723,19 +732,34 @@ class TestOBMAndKB(unittest.TestCase):
     #################################
 
     @print_test_separators
-    def test_31_prepare_notebook_cos_version(self):
+    @unittest.skipIf( is_cp4d(), "Flow with notebook metadata works only on WS")
+    def test_31_prepare_notebook_version(self):
+        if is_cp4d():
+            try:
+                print(type(self.remote_auto_pipelines))
+                result_path = self.remote_auto_pipelines.get_run_details()['entity']['results_reference']['location'].get('path')
+            except KeyError as e:
+                print(self.remote_auto_pipelines.get_run_details())
+                raise e
+            self.assertIsNotNone(result_path)
+            metadata_training_result_ref = DataConnection(
+                                            location=FSLocation(
+                                                path=result_path))
+        else:
+            metadata_training_result_ref = DataConnection(
+                                            connection=S3Connection(endpoint_url=self.cos_endpoint,
+                                                                    access_key_id=self.cos_credentials['cos_hmac_keys']['access_key_id'],
+                                                                    secret_access_key=self.cos_credentials['cos_hmac_keys']['secret_access_key']),
+                                            location=S3Location(bucket=self.bucket_name,
+                                                                path=self.results_cos_path,
+                                                                model_location=self.model_location,
+                                                                training_status=self.training_status
+                                                                )
+                                        )
+
         TestOBMAndKB.metadata = dict(
             training_data_reference=self.data_connections,
-            training_result_reference=DataConnection(
-                connection=S3Connection(endpoint_url=self.cos_endpoint,
-                                        access_key_id=self.cos_credentials['cos_hmac_keys']['access_key_id'],
-                                        secret_access_key=self.cos_credentials['cos_hmac_keys']['secret_access_key']),
-                location=S3Location(bucket=self.bucket_name,
-                                    path=self.results_cos_path,
-                                    model_location=self.model_location,
-                                    training_status=self.training_status
-                                    )
-            ),
+            training_result_reference=metadata_training_result_ref,
             prediction_type=self.experiment.PredictionType.BINARY,
             prediction_column=self.prediction_column,
             holdout_size=0.1,
@@ -757,6 +781,7 @@ class TestOBMAndKB(unittest.TestCase):
     #     data_join_graph.visualize()
 
     @print_test_separators
+    @unittest.skipIf( is_cp4d(), "Flow with notebook metadata works only on WS")
     def test_33_download_preprocessed_obm_training_data_notebook(self):
         print("Downloading OBM preprocessed training data...")
         TestOBMAndKB.train_data = (
@@ -775,9 +800,13 @@ class TestOBMAndKB(unittest.TestCase):
     # #     data_join_pipeline.visualize()
 
     @print_test_separators
+    @unittest.skipIf( is_cp4d(), "Flow with notebook metadata works only on WS")
     def test_35_batch_deployment_setup_and_preparation_notebook(self):
         if is_cp4d():
-            TestOBMAndKB.service = Batch(self.wml_credentials.copy(), source_space_id=self.space_id)
+            TestOBMAndKB.service = Batch(self.wml_credentials,
+                                         source_project_id=self.project_id,
+                                         target_wml_credentials=self.wml_credentials,
+                                         target_space_id=self.space_id)
         else:
             TestOBMAndKB.service = Batch(self.wml_credentials,
                                          source_space_id=self.space_id,
@@ -788,6 +817,7 @@ class TestOBMAndKB(unittest.TestCase):
         self.wml_client.set.default_space(self.space_id) if self.wml_client.ICP else None
 
     @print_test_separators
+    @unittest.skipIf( is_cp4d(), "Flow with notebook metadata works only on WS")
     def test_36__deploy__deploy_best_computed_pipeline_from_autoai_on_wml_notebook(self):
         self.service.create(
             metadata=self.metadata,
@@ -797,37 +827,50 @@ class TestOBMAndKB(unittest.TestCase):
         self.wml_client.set.default_project(self.project_id) if self.wml_client.ICP else None
 
     @print_test_separators
+    @unittest.skipIf( is_cp4d(), "Flow with notebook metadata works only on WS")
     def test_37a_score_deployed_model_notebook(self):
-        scoring_params = self.service.run_job(
-            payload=self.data_connections,
-            output_data_reference=DataConnection(
+        if is_cp4d():
+            payload_reference = self.data_connections_space_only
+            output_data_reference = DataConnection(
+                location=DeploymentOutputAssetLocation(name="batch_output_obm.csv"))
+        else:
+            payload_reference = self.data_connections
+            output_data_reference = DataConnection(
                 connection=S3Connection(endpoint_url=self.cos_endpoint,
                                         access_key_id=self.cos_credentials['cos_hmac_keys']['access_key_id'],
                                         secret_access_key=self.cos_credentials['cos_hmac_keys']['secret_access_key']),
                 location=S3Location(bucket=self.bucket_name,
-                                    path="prediction_results")
+                                    path="prediction_results.csv")
             ),
+
+        scoring_params = self.service.run_job(
+            payload=payload_reference,
+            output_data_reference=output_data_reference,
             background_mode=False)
         print(scoring_params)
 
         TestOBMAndKB.job_id = scoring_params['metadata']['id']
 
     @print_test_separators
+    @unittest.skipIf( is_cp4d(), "Flow with notebook metadata works only on WS")
     def test_37b_list_jobs_notebook(self):
         jobs = self.service.list_jobs()
         print(jobs)
 
     @print_test_separators
+    @unittest.skipIf( is_cp4d(), "Flow with notebook metadata works only on WS")
     def test_37c_rerun_job_notebook(self):
         scoring_params = self.service.rerun_job(self.job_id, background_mode=False)
         print(scoring_params)
 
     @print_test_separators
+    @unittest.skipIf( is_cp4d(), "Flow with notebook metadata works only on WS")
     def test_37d_get_job_result_notebook(self):
         result = self.service.get_job_result(self.job_id)
         print(result)
 
     @print_test_separators
+    @unittest.skipIf( is_cp4d(), "Flow with notebook metadata works only on WS")
     def test_38_list_deployments_notebook(self):
         deployments = self.service.list()
         print(deployments)
@@ -836,6 +879,7 @@ class TestOBMAndKB(unittest.TestCase):
         self.assertIsNotNone(params)
 
     @print_test_separators
+    @unittest.skipIf(is_cp4d(), "Flow with notebook metadata works only on WS")
     def test_39_delete_deployment_notebook(self):
         print("Delete current deployment: {}".format(self.service.deployment_id))
         self.service.delete()
