@@ -18,16 +18,15 @@ from ibm_watson_machine_learning.experiment.autoai.optimizers import RemoteAutoP
 from ibm_watson_machine_learning.utils.autoai.errors import NotExistingCOSResource
 
 from ibm_watson_machine_learning.tests.utils import (get_wml_credentials, get_cos_credentials, bucket_exists,
-                                                        bucket_name_gen, get_space_id, is_cp4d)
-from ibm_watson_machine_learning.tests.utils.cleanup import bucket_cleanup, space_cleanup, delete_model_deployment
+                                                     create_bucket, get_space_id, is_cp4d)
+from ibm_watson_machine_learning.tests.utils.cleanup import space_cleanup, delete_model_deployment
 
 from ibm_watson_machine_learning.utils.autoai.enums import PositiveLabelClass, TShirtSize, Transformers
 
 
-from lale.operators import TrainablePipeline
 
 
-@unittest.skip('not yet supported')
+# @unittest.skip('not yet supported')
 class TestAutoAIRemote(unittest.TestCase):
     """
 
@@ -71,10 +70,6 @@ class TestAutoAIRemote(unittest.TestCase):
 
     # Corona tweets, sentiment
     data_location = './autoai/data/Corona_NLP_test_utf8.csv'
-
-    # asset_id = '0296a5cf-c677-4e07-9ce4-574bd608c387'  # _test  ~1MB
-    asset_id = "19f81b25-05aa-4dbd-a80a-6ca56c4f61c7"  # _train  ~10MB
-
     prediction_column = 'Sentiment'
     with_text_transformer = True
 
@@ -94,6 +89,14 @@ class TestAutoAIRemote(unittest.TestCase):
         Load WML credentials from config.ini file based on ENV variable.
         """
         cls.wml_credentials = get_wml_credentials()
+        try:
+            del cls.wml_credentials['bedrock_url']
+        except:
+            pass
+        try:
+            del cls.wml_credentials['password']
+        except:
+            pass
         cls.wml_client = APIClient(wml_credentials=cls.wml_credentials.copy())
 
         if not cls.wml_client.ICP:
@@ -127,15 +130,7 @@ class TestAutoAIRemote(unittest.TestCase):
         )
         # Prepare bucket
         if not bucket_exists(cos_resource, self.bucket_name):
-            try:
-                bucket_cleanup(cos_resource, prefix=f"{self.bucket_name}-")
-            except Exception as e:
-                print(f"Bucket cleanup with prefix {self.bucket_name}- failed due to:\n{e}\n skipped")
-
-            import datetime
-            TestAutoAIRemote.bucket_name = bucket_name_gen(prefix=f"{self.bucket_name}-{str(datetime.date.today())}")
-            print(f"Creating COS bucket: {TestAutoAIRemote.bucket_name}")
-            cos_resource.Bucket(TestAutoAIRemote.bucket_name).create()
+            TestAutoAIRemote.bucket_name = create_bucket(cos_resource, self.bucket_name)
 
             self.assertIsNotNone(TestAutoAIRemote.bucket_name)
             self.assertTrue(bucket_exists(cos_resource, TestAutoAIRemote.bucket_name))
@@ -151,8 +146,13 @@ class TestAutoAIRemote(unittest.TestCase):
 
     def test_02_save_remote_data_and_DataConnection_setup(self):
         if self.wml_client.ICP:
+            asset_details = self.wml_client.data_assets.create(
+                name=self.data_location.split('/')[-1],
+                file_path=self.data_location)
+            asset_id = asset_details['metadata']['guid']
+
             TestAutoAIRemote.data_connection = DataConnection(
-                location=AssetLocation(asset_id=self.asset_id))
+                location=AssetLocation(asset_id=asset_id))
             TestAutoAIRemote.results_connection = None
 
         else:  # for cloud and COS
@@ -187,13 +187,10 @@ class TestAutoAIRemote(unittest.TestCase):
             prediction_type=self.experiment.PredictionType.MULTICLASS,
             prediction_column=self.prediction_column,
             scoring=self.experiment.Metrics.ACCURACY_SCORE,
-            daub_include_only_estimators=[self.experiment.ClassificationAlgorithms.LGBM, self.experiment.ClassificationAlgorithms.XGB],
-            cognito_transform_names=[Transformers.DIFF,Transformers.SUM,Transformers.MAX,
-                                     Transformers.SIN], #,Transformers.xSUM],
-            text_processing_flag=self.with_text_transformer,
-            test_size=0.1,
+            text_processing=self.with_text_transformer,
+            holdout_size=0.1,
             max_number_of_estimators=2,
-            t_shirt_size=TShirtSize.L
+            autoai_pod_version=self.pod_version
         )
 
         self.assertIsInstance(self.remote_auto_pipelines, RemoteAutoPipelines,
@@ -219,25 +216,11 @@ class TestAutoAIRemote(unittest.TestCase):
         self.assertIsNotNone(self.data_connection.auto_pipeline_params,
                              msg='DataConnection auto_pipeline_params was not updated.')
 
-        # TestAutoAIRemote.run_id = '51a3d5f2-3c72-4072-a578-f02ee5991e9b' # hist run_id
+        # TestAutoAIRemote.run_id = '939e1252-6a2e-4b88-aa58-3014670b7365' # hist run_id
         # TestAutoAIRemote.remote_auto_pipelines = self.experiment.runs.get_optimizer(self.run_id)
 
-    def test_05b_save_logs(self):
-        import json, datetime
-
-        details = {"run_status": self.remote_auto_pipelines.get_run_status(),
-                   "elapsed_time": self.elapsed_time,
-                   "pipeline_details": self.remote_auto_pipelines.get_params(),
-                   "run_details": self.remote_auto_pipelines.get_run_details(),
-                   "ml_metrics": self.remote_auto_pipelines.get_pipeline_details()['ml_metrics'].to_dict()
-                   }
-        filename = "text_transformer_"+self.OPTIMIZER_NAME+f"{datetime.datetime.now().strftime('%H-%M-%S_%d-%m-%Y')}" + ".json"
-        with open (filename, 'w') as f:
-            json.dump(details, f)
-
     def test_06_get_train_data(self):
-        # TestAutoAIRemote.train_data = self.remote_auto_pipelines.get_data_connections()[0].read()
-        TestAutoAIRemote.train_data = pd.read_csv(self.data_location)
+        TestAutoAIRemote.train_data = self.remote_auto_pipelines.get_data_connections()[0].read()
 
         print("train data sample:")
         print(self.train_data.head())
@@ -248,11 +231,12 @@ class TestAutoAIRemote(unittest.TestCase):
 
     def test_07_get_run_status(self):
         status = self.remote_auto_pipelines.get_run_status()
+        print(status)
         self.assertEqual(status, "completed", msg="AutoAI run didn't finished successfully. Status: {}".format(status))
 
     def test_08_get_run_details(self):
         parameters = self.remote_auto_pipelines.get_run_details()
-        # print(parameters)
+        print(parameters)
         self.assertIsNotNone(parameters)
 
     def test_09_predict_using_fitted_pipeline(self):
@@ -286,6 +270,7 @@ class TestAutoAIRemote(unittest.TestCase):
         TestAutoAIRemote.pipeline = self.remote_auto_pipelines.get_pipeline(pipeline_name='Pipeline_4')
         print(f"Fetched pipeline type: {type(self.pipeline)}")
 
+        from lale.operators import TrainablePipeline
         self.assertIsInstance(self.pipeline, TrainablePipeline,
                               msg="Fetched pipeline is not of TrainablePipeline instance.")
         predictions = self.pipeline.predict(
@@ -301,6 +286,7 @@ class TestAutoAIRemote(unittest.TestCase):
             lale_pipeline = None
             try:
                 lale_pipeline = self.remote_auto_pipelines.get_pipeline(pipeline_name=pipeline_name)
+                from lale.operators import TrainablePipeline
                 self.assertIsInstance(lale_pipeline, TrainablePipeline)
                 print(lale_pipeline)
                 print(self.X_values[:5])
@@ -319,6 +305,16 @@ class TestAutoAIRemote(unittest.TestCase):
 
         self.assertEqual(len(failed_pipelines), 0, msg=f"Some pipelines failed. Full list: {failed_pipelines}")
 
+    def test_16__pretty_print_lale__checks_if_generated_python_pipeline_code_is_correct(self):
+        pipeline_code = self.pipeline.pretty_print()
+        try:
+            exec(pipeline_code)
+
+        except Exception as exception:
+            self.assertIsNone(
+                exception,
+                msg=f"Pretty print from lale pipeline was not successful \n\n Full pipeline code:\n {pipeline_code}")
+
     #################################
     #      DEPLOYMENT SECTION       #
     #################################
@@ -326,7 +322,8 @@ class TestAutoAIRemote(unittest.TestCase):
     def test_21_deployment_setup_and_preparation(self):
         TestAutoAIRemote.service = WebService(source_wml_credentials=self.wml_credentials.copy(),
                                               source_project_id=self.project_id,
-                                              source_space_id=self.space_id)
+                                              target_wml_credentials=self.wml_credentials,
+                                              target_space_id=self.space_id)
         self.wml_client.set.default_space(self.space_id)
         delete_model_deployment(self.wml_client, deployment_name=self.DEPLOYMENT_NAME)
         self.wml_client.set.default_project(self.project_id) if self.project_id else None
@@ -376,14 +373,10 @@ class TestAutoAIRemote(unittest.TestCase):
     #########################
 
     def test_30_batch_deployment_setup_and_preparation(self):
-        if self.wml_client.ICP:
-            TestAutoAIRemote.service_batch = Batch(source_wml_credentials=self.wml_credentials.copy(),
-                                                   source_project_id=self.project_id,
-                                                   target_wml_credentials=self.wml_credentials,
-                                                   target_space_id=self.space_id)
-        else:
-            TestAutoAIRemote.service_batch = Batch(self.wml_credentials,
-                                                   source_space_id=self.space_id)
+        TestAutoAIRemote.service_batch = Batch(source_wml_credentials=self.wml_credentials.copy(),
+                                               source_project_id=self.project_id,
+                                               target_wml_credentials=self.wml_credentials,
+                                               target_space_id=self.space_id)
 
         self.assertIsInstance(self.service_batch, Batch, msg="Deployment is not of Batch type.")
         self.assertIsInstance(self.service_batch._source_workspace, WorkSpace, msg="Workspace set incorrectly.")
@@ -403,7 +396,7 @@ class TestAutoAIRemote(unittest.TestCase):
 
     def test_33_score_batch_deployed_model(self):
         scoring_params = self.service_batch.run_job(
-            payload=self.train_data.drop(columns=[self.prediction_column]),
+            payload=self.train_data.drop(columns=[self.prediction_column]).dropna()[:3],
             background_mode=False)
         print(scoring_params)
         print(self.service_batch.get_job_result(scoring_params['metadata']['id']))
