@@ -18,18 +18,14 @@ from ibm_watson_machine_learning.experiment.autoai.optimizers import RemoteAutoP
 from ibm_watson_machine_learning.utils.autoai.errors import NotExistingCOSResource
 
 from ibm_watson_machine_learning.tests.utils import (get_wml_credentials, get_cos_credentials, bucket_exists,
-                                                        bucket_name_gen, get_space_id, is_cp4d)
-from ibm_watson_machine_learning.tests.utils.cleanup import bucket_cleanup, space_cleanup, delete_model_deployment
+                                                     create_bucket, get_space_id, is_cp4d)
+from ibm_watson_machine_learning.tests.utils.cleanup import space_cleanup, delete_model_deployment
 
 from ibm_watson_machine_learning.utils.autoai.enums import PositiveLabelClass, TShirtSize, Transformers
 
 
-from lale import wrap_imported_operators
-from lale.operators import TrainablePipeline
-from lale.lib.lale import Hyperopt
 
-
-@unittest.skip('not yet supported')
+# @unittest.skip('not yet supported')
 class TestAutoAIRemote(unittest.TestCase):
     """
     The test can be run on CLOUD, WMLS and CPD (not tested)
@@ -62,7 +58,7 @@ class TestAutoAIRemote(unittest.TestCase):
     pod_version = environ.get('KB_VERSION', None)
 
     cos_endpoint = "https://s3.us-south.cloud-object-storage.appdomain.cloud"
-    data_cos_path = 'data/auto_ai_exp_cfpb.csv'
+    data_cos_path = 'data/Hotel_Reviews.csv'
     cos_resource_instance_id = None
 
     results_cos_path = 'results_wml_autoai'
@@ -77,13 +73,8 @@ class TestAutoAIRemote(unittest.TestCase):
     y_values = None
     elapsed_time = None
 
-    data_location = './autoai/data/Hotel_Reviews.csv'
+    data_location = './autoai/data/Hotel_Reviews_1MB.csv'
 
-
-    # Hotel_reviews
-    # asset_id = "52531b49-4e3b-419f-a169-0496dd08f44a" #1MB
-    # asset_id = "32ad7c0a-5d51-47a7-b84c-6ee63e92282b"  # 10MB
-    asset_id = "491ca337-e5c4-4b25-84c9-c4b9dd1b3b46" #full
     prediction_column = "Reviewer_Score"
 
     with_text_transformer = True
@@ -102,6 +93,14 @@ class TestAutoAIRemote(unittest.TestCase):
         Load WML credentials from config.ini file based on ENV variable.
         """
         cls.wml_credentials = get_wml_credentials()
+        try:
+            del cls.wml_credentials['bedrock_url']
+        except:
+            pass
+        try:
+            del cls.wml_credentials['password']
+        except:
+            pass
         cls.wml_client = APIClient(wml_credentials=cls.wml_credentials.copy())
 
         if not cls.wml_client.ICP:
@@ -118,10 +117,6 @@ class TestAutoAIRemote(unittest.TestCase):
                       days_old=7)
         TestAutoAIRemote.space_id = get_space_id(self.wml_client, self.space_name,
                                      cos_resource_instance_id=self.cos_resource_instance_id)
-        if self.wml_client.ICP:
-            self.wml_client.set.default_project(self.project_id)
-        else:
-            self.wml_client.set.default_space(self.space_id)
 
     def test_00b_prepare_COS_instance(self):
         if self.wml_client.ICP:
@@ -135,15 +130,7 @@ class TestAutoAIRemote(unittest.TestCase):
         )
         # Prepare bucket
         if not bucket_exists(cos_resource, self.bucket_name):
-            try:
-                bucket_cleanup(cos_resource, prefix=f"{self.bucket_name}-")
-            except Exception as e:
-                print(f"Bucket cleanup with prefix {self.bucket_name}- failed due to:\n{e}\n skipped")
-
-            import datetime
-            TestAutoAIRemote.bucket_name = bucket_name_gen(prefix=f"{self.bucket_name}-{str(datetime.date.today())}")
-            print(f"Creating COS bucket: {TestAutoAIRemote.bucket_name}")
-            cos_resource.Bucket(TestAutoAIRemote.bucket_name).create()
+            TestAutoAIRemote.bucket_name = create_bucket(cos_resource, self.bucket_name)
 
             self.assertIsNotNone(TestAutoAIRemote.bucket_name)
             self.assertTrue(bucket_exists(cos_resource, TestAutoAIRemote.bucket_name))
@@ -152,15 +139,20 @@ class TestAutoAIRemote(unittest.TestCase):
 
     def test_01_initialize_AutoAI_experiment__pass_credentials__object_initialized(self):
         TestAutoAIRemote.experiment = AutoAI(wml_credentials=self.wml_credentials,
-                                             project_id=self.project_id)#,
-                                             # space_id=self.space_id)
+                                             space_id=self.space_id)
+        self.wml_client.set.default_space(self.space_id)
 
         self.assertIsInstance(self.experiment, AutoAI, msg="Experiment is not of type AutoAI.")
 
     def test_02_save_remote_data_and_DataConnection_setup(self):
         if self.wml_client.ICP:
+            asset_details = self.wml_client.data_assets.create(
+                name=self.data_location.split('/')[-1],
+                file_path=self.data_location)
+            asset_id = asset_details['metadata']['guid']
+
             TestAutoAIRemote.data_connection = DataConnection(
-                location=AssetLocation(asset_id=self.asset_id))
+                location=AssetLocation(asset_id=asset_id))
             TestAutoAIRemote.results_connection = None
 
         else: #for cloud and COS
@@ -193,15 +185,12 @@ class TestAutoAIRemote(unittest.TestCase):
             name=self.OPTIMIZER_NAME,
             desc='test description',
             prediction_type=self.experiment.PredictionType.REGRESSION,
+            include_only_estimators=[self.experiment.RegressionAlgorithms.XGB,
+                                     self.experiment.RegressionAlgorithms.LGBM],
             prediction_column=self.prediction_column,
             scoring=self.experiment.Metrics.ROOT_MEAN_SQUARED_ERROR,
-            daub_include_only_estimators=[self.experiment.RegressionAlgorithms.LGBM, self.experiment.RegressionAlgorithms.XGB],
-            cognito_transform_names=[Transformers.DIFF,Transformers.SUM,Transformers.MAX,
-                                     Transformers.SIN], #,Transformers.xSUM],
-            text_processing_flag=self.with_text_transformer,
-            test_size=0.1,
-            max_number_of_estimators=2,
-            t_shirt_size=TShirtSize.L
+            text_processing=self.with_text_transformer,
+            autoai_pod_version=self.pod_version
         )
 
         self.assertIsInstance(self.remote_auto_pipelines, RemoteAutoPipelines,
@@ -229,22 +218,8 @@ class TestAutoAIRemote(unittest.TestCase):
         # TestAutoAIRemote.run_id = '51a3d5f2-3c72-4072-a578-f02ee5991e9b'
         # TestAutoAIRemote.remote_auto_pipelines = self.experiment.runs.get_optimizer(self.run_id)
 
-    def test_05b_save_logs(self):
-        import json, datetime
-
-        details = {"run_status": self.remote_auto_pipelines.get_run_status(),
-                   "elapsed_time": self.elapsed_time,
-                   "pipeline_details": self.remote_auto_pipelines.get_params(),
-                   "run_details": self.remote_auto_pipelines.get_run_details()
-                   # "ml_metrics": self.remote_auto_pipelines.get_pipeline_details()['ml_metrics'].to_dict()
-                   }
-        filename = "text_transformer_"+self.OPTIMIZER_NAME+f"{datetime.datetime.now().strftime('%H-%M-%S_%d-%m-%Y')}" + ".json"
-        with open (filename, 'w') as f:
-            json.dump(details, f)
-
     def test_06_get_train_data(self):
-        # TestAutoAIRemote.train_data = self.remote_auto_pipelines.get_data_connections()[0].read()
-        TestAutoAIRemote.train_data = pd.read_csv(self.data_location)
+        TestAutoAIRemote.train_data = self.remote_auto_pipelines.get_data_connections()[0].read()
 
         print("train data sample:")
         print(self.train_data.head())
@@ -293,6 +268,7 @@ class TestAutoAIRemote(unittest.TestCase):
         TestAutoAIRemote.pipeline = self.remote_auto_pipelines.get_pipeline(pipeline_name='Pipeline_4')
         print(f"Fetched pipeline type: {type(self.pipeline)}")
 
+        from lale.operators import TrainablePipeline
         self.assertIsInstance(self.pipeline, TrainablePipeline,
                               msg="Fetched pipeline is not of TrainablePipeline instance.")
         predictions = self.pipeline.predict(
@@ -300,6 +276,7 @@ class TestAutoAIRemote(unittest.TestCase):
         print(predictions)
 
     def test_15_get_all_pipelines_as_lale(self):
+        from lale.operators import TrainablePipeline
         summary = self.remote_auto_pipelines.summary()
         print(summary)
         failed_pipelines = []
@@ -326,13 +303,22 @@ class TestAutoAIRemote(unittest.TestCase):
 
         self.assertEqual(len(failed_pipelines), 0, msg=f"Some pipelines failed. Full list: {failed_pipelines}")
 
+    def test_16__pretty_print_lale__checks_if_generated_python_pipeline_code_is_correct(self):
+        pipeline_code = self.pipeline.pretty_print()
+        try:
+            exec(pipeline_code)
+
+        except Exception as exception:
+            self.assertIsNone(
+                exception,
+                msg=f"Pretty print from lale pipeline was not successful \n\n Full pipeline code:\n {pipeline_code}")
+
     #################################
     #      DEPLOYMENT SECTION       #
     #################################
 
     def test_21_deployment_setup_and_preparation(self):
         TestAutoAIRemote.service = WebService(source_wml_credentials=self.wml_credentials.copy(),
-                                              source_project_id=self.project_id,
                                               source_space_id=self.space_id)
         self.wml_client.set.default_space(self.space_id)
         delete_model_deployment(self.wml_client, deployment_name=self.DEPLOYMENT_NAME)
@@ -385,7 +371,7 @@ class TestAutoAIRemote(unittest.TestCase):
     def test_30_batch_deployment_setup_and_preparation(self):
         if self.wml_client.ICP:
             TestAutoAIRemote.service_batch = Batch(source_wml_credentials=self.wml_credentials.copy(),
-                                                   source_project_id=self.project_id,
+                                                   source_space_id=self.space_id,
                                                    target_wml_credentials=self.wml_credentials,
                                                    target_space_id=self.space_id)
         else:
