@@ -17,15 +17,14 @@ from ibm_watson_machine_learning.helpers.connections import S3Connection, S3Loca
 from ibm_watson_machine_learning.experiment.autoai.optimizers import RemoteAutoPipelines
 
 from ibm_watson_machine_learning.tests.utils import (get_wml_credentials, get_cos_credentials, bucket_exists,
-                                                     bucket_name_gen, get_space_id, is_cp4d)
-from ibm_watson_machine_learning.tests.utils.cleanup import bucket_cleanup, space_cleanup, delete_model_deployment
+                                                     create_bucket, get_space_id, is_cp4d)
+from ibm_watson_machine_learning.tests.utils.cleanup import space_cleanup, delete_model_deployment
 
 from ibm_watson_machine_learning.utils.autoai.enums import TShirtSize, PipelineTypes
 
 from lale.operators import TrainablePipeline
 
 
-@unittest.skip('Text transformer not supported yet')
 class TestAutoAIRemote(unittest.TestCase):
     """
     The test can be run on CLOUD, WMLS and CPD (not tested)
@@ -76,17 +75,11 @@ class TestAutoAIRemote(unittest.TestCase):
 
     data_location = './autoai/data/donorchoose_1MB.csv'
 
-    if size_dataset == "1":
-        asset_id = "7b912366-ec5f-4e40-9091-c14fb03f9ca4"  # 1MB
-    else:
-        asset_id = "3253ef55-bf01-4084-adeb-7efd4cef00de"  # 10MB
-
     prediction_column = "project_is_approved"
 
-    with_text_transformer = environ.get('TT_ENABLED', 'true').lower() in (True, 'true')
-    estimator = environ.get('ESTIMATOR', None)
+    with_text_transformer = True
 
-    OPTIMIZER_NAME = f"TEXT TRANSFORMER {with_text_transformer} binary {data_location.split('/')[-1]} {size_dataset} MB {estimator}"
+    OPTIMIZER_NAME = f"TEXT TRANSFORMER {with_text_transformer} binary {data_location.split('/')[-1]} "
     DEPLOYMENT_NAME = "TEXT TRANSFORMER AutoAI Deployment tests"
 
     project_id = None
@@ -100,6 +93,14 @@ class TestAutoAIRemote(unittest.TestCase):
         Load WML credentials from config.ini file based on ENV variable.
         """
         cls.wml_credentials = get_wml_credentials()
+        try:
+            del cls.wml_credentials['bedrock_url']
+        except:
+            pass
+        try:
+            del cls.wml_credentials['password']
+        except:
+            pass
         cls.wml_client = APIClient(wml_credentials=cls.wml_credentials.copy())
 
         if not cls.wml_client.ICP:
@@ -133,15 +134,7 @@ class TestAutoAIRemote(unittest.TestCase):
         )
         # Prepare bucket
         if not bucket_exists(cos_resource, self.bucket_name):
-            try:
-                bucket_cleanup(cos_resource, prefix=f"{self.bucket_name}-")
-            except Exception as e:
-                print(f"Bucket cleanup with prefix {self.bucket_name}- failed due to:\n{e}\n skipped")
-
-            import datetime
-            TestAutoAIRemote.bucket_name = bucket_name_gen(prefix=f"{self.bucket_name}-{str(datetime.date.today())}")
-            print(f"Creating COS bucket: {TestAutoAIRemote.bucket_name}")
-            cos_resource.Bucket(TestAutoAIRemote.bucket_name).create()
+            TestAutoAIRemote.bucket_name = create_bucket(cos_resource, self.bucket_name)
 
             self.assertIsNotNone(TestAutoAIRemote.bucket_name)
             self.assertTrue(bucket_exists(cos_resource, TestAutoAIRemote.bucket_name))
@@ -157,9 +150,13 @@ class TestAutoAIRemote(unittest.TestCase):
 
     def test_02_save_remote_data_and_DataConnection_setup(self):
         if self.wml_client.ICP:
-            TestAutoAIRemote.data_connection = DataConnection(
-                location=AssetLocation(asset_id=self.asset_id))
+            asset_details = self.wml_client.data_assets.create(
+                name=self.data_location.split('/')[-1],
+                file_path=self.data_location)
+            asset_id = asset_details['metadata']['guid']
 
+            TestAutoAIRemote.data_connection = DataConnection(
+                location=AssetLocation(asset_id=asset_id))
             TestAutoAIRemote.results_connection = None
 
         else:  # for cloud and COS
@@ -181,26 +178,17 @@ class TestAutoAIRemote(unittest.TestCase):
 
         self.assertIsNotNone(obj=TestAutoAIRemote.data_connection)
 
-    def test_02a_read_saved_remote_data_before_fit(self):
-        data = self.data_connection.read()
-        print(f"Data sample")
-        print(data.head())
-        self.assertGreater(len(data), 0)
-
     def test_03_initialize_optimizer(self):
         TestAutoAIRemote.remote_auto_pipelines = self.experiment.optimizer(
             name=self.OPTIMIZER_NAME,
             desc='test description',
             prediction_type=self.experiment.PredictionType.BINARY,
             prediction_column=self.prediction_column,
-            scoring=self.experiment.Metrics.ACCURACY_SCORE,
-            include_only_estimators=[self.experiment.ClassificationAlgorithms.XGB],
-            holdout_size=0.1,
+            scoring=self.experiment.Metrics.LOG_LOSS,
             train_sample_columns_index_list=[4.0, 5.0, 9.0],
             text_processing=True,
-            word2vec_feature_number=20,
-            autoai_pod_version=self.pod_version,
-            t_shirt_size=TShirtSize.L
+            word2vec_feature_number=15,
+            autoai_pod_version=self.pod_version
         )
 
         self.assertIsInstance(self.remote_auto_pipelines, RemoteAutoPipelines,
@@ -229,8 +217,7 @@ class TestAutoAIRemote(unittest.TestCase):
         # TestAutoAIRemote.remote_auto_pipelines = self.experiment.runs.get_optimizer(self.run_id)
 
     def test_06_get_train_data(self):
-        # TestAutoAIRemote.train_data = self.remote_auto_pipelines.get_data_connections()[0].read()
-        TestAutoAIRemote.train_data = pd.read_csv(self.data_location)
+        TestAutoAIRemote.train_data = self.remote_auto_pipelines.get_data_connections()[0].read()
 
         print("train data sample:")
         print(self.train_data.head())
@@ -245,7 +232,7 @@ class TestAutoAIRemote(unittest.TestCase):
 
     def test_08_get_run_details(self):
         parameters = self.remote_auto_pipelines.get_run_details()
-        # print(parameters)
+        print(parameters)
         self.assertIsNotNone(parameters)
 
     def test_09_predict_using_fitted_pipeline(self):
@@ -280,7 +267,6 @@ class TestAutoAIRemote(unittest.TestCase):
                                                                             astype=PipelineTypes.SKLEARN)
         print(f"Fetched pipeline type: {type(self.pipeline)}")
 
-
         self.assertIsInstance(self.pipeline, Pipeline,
                               msg="Fetched pipeline is not of Sklearn Pipeline instance.")
 
@@ -344,7 +330,8 @@ class TestAutoAIRemote(unittest.TestCase):
     def test_21_deployment_setup_and_preparation(self):
         TestAutoAIRemote.service = WebService(source_wml_credentials=self.wml_credentials.copy(),
                                               source_project_id=self.project_id,
-                                              source_space_id=self.space_id)
+                                              target_wml_credentials=self.wml_credentials,
+                                              target_space_id=self.space_id)
         self.wml_client.set.default_space(self.space_id)
         delete_model_deployment(self.wml_client, deployment_name=self.DEPLOYMENT_NAME)
         self.wml_client.set.default_project(self.project_id) if self.project_id else None
@@ -394,14 +381,10 @@ class TestAutoAIRemote(unittest.TestCase):
     #########################
 
     def test_30_batch_deployment_setup_and_preparation(self):
-        if self.wml_client.ICP:
-            TestAutoAIRemote.service_batch = Batch(source_wml_credentials=self.wml_credentials.copy(),
-                                                   source_project_id=self.project_id,
-                                                   target_wml_credentials=self.wml_credentials,
-                                                   target_space_id=self.space_id)
-        else:
-            TestAutoAIRemote.service_batch = Batch(self.wml_credentials,
-                                                   source_space_id=self.space_id)
+        TestAutoAIRemote.service_batch = Batch(source_wml_credentials=self.wml_credentials.copy(),
+                                               source_project_id=self.project_id,
+                                               target_wml_credentials=self.wml_credentials,
+                                               target_space_id=self.space_id)
 
         self.assertIsInstance(self.service_batch, Batch, msg="Deployment is not of Batch type.")
         self.assertIsInstance(self.service_batch._source_workspace, WorkSpace, msg="Workspace set incorrectly.")
