@@ -16,20 +16,22 @@ from ibm_watson_machine_learning.helpers.connections import S3Connection, S3Loca
 from ibm_watson_machine_learning.experiment.autoai.optimizers import RemoteAutoPipelines
 
 from ibm_watson_machine_learning.tests.utils import (get_wml_credentials, get_cos_credentials, bucket_exists,
-                                                        bucket_name_gen, get_space_id, is_cp4d)
-from ibm_watson_machine_learning.tests.utils.cleanup import bucket_cleanup, space_cleanup, delete_model_deployment
+                                                     create_bucket, get_space_id, is_cp4d)
+from ibm_watson_machine_learning.tests.utils.cleanup import space_cleanup, delete_model_deployment
 
 from ibm_watson_machine_learning.utils.autoai.enums import TShirtSize, PipelineTypes
+from ibm_watson_machine_learning.utils.autoai.errors import CannotReadSavedRemoteDataBeforeFit
 
 
 from lale.operators import TrainablePipeline
 
 
-@unittest.skip('not supported yet')
+# @unittest.skip('not supported yet')
 class TestAutoAIRemote(unittest.TestCase):
     """
-    The test can be run on CLOUD, WMLS and CPD (not tested)
+    The test can be run on CLOUD, WMLS and CPD
     The test covers:
+    - training on space (Cloud) or project (CPD)
     - COS set-up (if run on Cloud): checking if bucket exists for the cos instance, if not new bucket is create
     - Saving data `/bank.cdv` to COS/data assets
     - downloading training data from cos/data assets
@@ -73,22 +75,13 @@ class TestAutoAIRemote(unittest.TestCase):
     X_values = None
     y_values = None
     elapsed_time = None
-    size_dataset = environ.get('SIZE_DATASET_MB', "10")
-
     data_location = './autoai/data/fake_job_postings_2MB.csv'
 
-
-    if size_dataset == "1":
-        asset_id = "7b912366-ec5f-4e40-9091-c14fb03f9ca4" # 1MB
-    else:
-        asset_id = "3253ef55-bf01-4084-adeb-7efd4cef00de" # 10MB
-
     prediction_column = "fraudulent"
 
-    with_text_transformer = environ.get('TT_ENABLED', 'true').lower() in (True, 'true')
-    estimator = environ.get('ESTIMATOR', None)
+    with_text_transformer = True
 
-    OPTIMIZER_NAME = f"TEXT TRANSFORMER {with_text_transformer} binary {data_location.split('/')[-1]} {size_dataset} MB {estimator}"
+    OPTIMIZER_NAME = f"TEXT TRANSFORMER {with_text_transformer} binary {data_location.split('/')[-1]}"
     DEPLOYMENT_NAME = "TEXT TRANSFORMER AutoAI Deployment tests"
 
     project_id = None
@@ -103,6 +96,14 @@ class TestAutoAIRemote(unittest.TestCase):
         Load WML credentials from config.ini file based on ENV variable.
         """
         cls.wml_credentials = get_wml_credentials()
+        try:
+            del cls.wml_credentials['bedrock_url']
+        except:
+            pass
+        try:
+            del cls.wml_credentials['password']
+        except:
+            pass
         cls.wml_client = APIClient(wml_credentials=cls.wml_credentials.copy())
 
         if not cls.wml_client.ICP:
@@ -136,15 +137,7 @@ class TestAutoAIRemote(unittest.TestCase):
         )
         # Prepare bucket
         if not bucket_exists(cos_resource, self.bucket_name):
-            try:
-                bucket_cleanup(cos_resource, prefix=f"{self.bucket_name}-")
-            except Exception as e:
-                print(f"Bucket cleanup with prefix {self.bucket_name}- failed due to:\n{e}\n skipped")
-
-            import datetime
-            TestAutoAIRemote.bucket_name = bucket_name_gen(prefix=f"{self.bucket_name}-{str(datetime.date.today())}")
-            print(f"Creating COS bucket: {TestAutoAIRemote.bucket_name}")
-            cos_resource.Bucket(TestAutoAIRemote.bucket_name).create()
+            TestAutoAIRemote.bucket_name = create_bucket(cos_resource, self.bucket_name)
 
             self.assertIsNotNone(TestAutoAIRemote.bucket_name)
             self.assertTrue(bucket_exists(cos_resource, TestAutoAIRemote.bucket_name))
@@ -152,16 +145,23 @@ class TestAutoAIRemote(unittest.TestCase):
         print(f"Using COS bucket: {TestAutoAIRemote.bucket_name}")
 
     def test_01_initialize_AutoAI_experiment__pass_credentials__object_initialized(self):
-        TestAutoAIRemote.experiment = AutoAI(wml_credentials=self.wml_credentials.copy(),
-                                             project_id=self.project_id)
-                                             # space_id=self.space_id)
+        if self.wml_client.ICP:
+            TestAutoAIRemote.experiment = AutoAI(wml_credentials=self.wml_credentials.copy(),
+                                                 project_id=self.project_id)
+        else:
+            TestAutoAIRemote.experiment = AutoAI(wml_credentials=self.wml_credentials.copy(),
+                                                 space_id=self.space_id)
 
         self.assertIsInstance(self.experiment, AutoAI, msg="Experiment is not of type AutoAI.")
 
     def test_02_save_remote_data_and_DataConnection_setup(self):
         if self.wml_client.ICP:
+            asset_details = self.wml_client.data_assets.create(
+                name=self.data_location.split('/')[-1],
+                file_path=self.data_location)
+            asset_id = asset_details['metadata']['guid']
             TestAutoAIRemote.data_connection = DataConnection(
-                location=AssetLocation(asset_id=self.asset_id))
+                location=AssetLocation(asset_id=asset_id))
 
             TestAutoAIRemote.results_connection = None
 
@@ -185,10 +185,17 @@ class TestAutoAIRemote(unittest.TestCase):
         self.assertIsNotNone(obj=TestAutoAIRemote.data_connection)
 
     def test_02a_read_saved_remote_data_before_fit(self):
-        data = self.data_connection.read()
-        print(f"Data sample")
-        print(data.head())
-        self.assertGreater(len(data), 0)
+        if self.wml_client.ICP:
+            with self.assertRaises(CannotReadSavedRemoteDataBeforeFit, msg="Should fail with adequate error"):
+                data = self.data_connection.read()
+
+            with self.assertRaises(CannotReadSavedRemoteDataBeforeFit, msg="Should fail with adequate error"):
+                data = self.data_connection.read()
+        else:
+            data = self.data_connection.read()
+            print(f"Data sample")
+            print(data.head())
+            self.assertGreater(len(data), 0)
 
     def test_03_initialize_optimizer(self):
         TestAutoAIRemote.remote_auto_pipelines = self.experiment.optimizer(
@@ -197,9 +204,8 @@ class TestAutoAIRemote(unittest.TestCase):
             prediction_type=self.experiment.PredictionType.BINARY,
             prediction_column=self.prediction_column,
             scoring=self.experiment.Metrics.ACCURACY_SCORE,
-            daub_include_only_estimators=[self.experiment.ClassificationAlgorithms.XGB],
-            # text_processing_flag=self.with_text_transformer,
-            test_size=0.1,
+            text_processing=self.with_text_transformer,
+            holdout_size=0.1,
             autoai_pod_version=self.pod_version,
             t_shirt_size=TShirtSize.L
         )
@@ -226,44 +232,12 @@ class TestAutoAIRemote(unittest.TestCase):
 
         self.assertIsNotNone(self.data_connection.auto_pipeline_params,
                              msg='DataConnection auto_pipeline_params was not updated.')
-        # TestAutoAIRemote.run_id = 'da33db18-abd5-489c-bfde-82a413563560'
+        # TestAutoAIRemote.run_id = '47111a26-b2bf-4ee2-bcf5-81137dc99b27'
         # TestAutoAIRemote.remote_auto_pipelines = self.experiment.runs.get_optimizer(self.run_id)
 
-    def test_05b_save_logs(self):
-        import json
-        import datetime
-
-        times_per_run_id = dict()
-        training_details = self.wml_client.training.get_details(self.run_id)
-
-        times_in_row = ""
-        for pipeline_metrics in training_details['entity']['status']['metrics']:
-            if pipeline_metrics['context']['phase'] not in times_per_run_id.keys():
-                times_in_row += f"{pipeline_metrics['context']['intermediate_model']['duration'] / 1000}\t" # devide by 1000 -> converting miliseconds to seconds
-            times_per_run_id[pipeline_metrics['context']['phase']] = pipeline_metrics['context']['intermediate_model'][
-                                                                         'duration'] / 1000
-        print(times_in_row)
-
-        details = {"run_status": self.remote_auto_pipelines.get_run_status(),
-                   "elapsed_time": self.elapsed_time,
-                   "pipeline_details": self.remote_auto_pipelines.get_params(),
-                   "run_details": self.remote_auto_pipelines.get_run_details(),
-                   # "ml_metrics": self.remote_auto_pipelines.get_pipeline_details()['ml_metrics'].to_dict()
-                   "duration_phases": times_per_run_id
-                   }
-        try:
-            details["ml_metrics"] = self.remote_auto_pipelines.get_pipeline_details()['ml_metrics'].to_dict()
-        except Exception as e:
-            print("Not able to get ml_metrics, skipped")
-            print(e)
-
-        filename = f"tt_results/text_transformer_"+self.OPTIMIZER_NAME+f"{datetime.datetime.now().strftime('%H-%M-%S_%d-%m-%Y')}" + ".json"
-        with open(filename, 'w') as f:
-            json.dump(details, f)
-
     def test_06_get_train_data(self):
-        # TestAutoAIRemote.train_data = self.remote_auto_pipelines.get_data_connections()[0].read()
-        TestAutoAIRemote.train_data = pd.read_csv(self.data_location)
+        TestAutoAIRemote.train_data = self.remote_auto_pipelines.get_data_connections()[0].read()
+        # TestAutoAIRemote.train_data = pd.read_csv(self.data_location)
 
         print("train data sample:")
         print(self.train_data.head())
@@ -373,9 +347,14 @@ class TestAutoAIRemote(unittest.TestCase):
     #################################
 
     def test_21_deployment_setup_and_preparation(self):
-        TestAutoAIRemote.service = WebService(source_wml_credentials=self.wml_credentials.copy(),
+        if self.wml_client.ICP:
+            TestAutoAIRemote.service = WebService(source_wml_credentials=self.wml_credentials.copy(),
                                               source_project_id=self.project_id,
-                                              source_space_id=self.space_id)
+                                              target_wml_credentials=self.wml_credentials,
+                                              target_space_id=self.space_id)
+        else:
+            TestAutoAIRemote.service = WebService(source_wml_credentials=self.wml_credentials.copy(),
+                                                 source_space_id=self.space_id)
         self.wml_client.set.default_space(self.space_id)
         delete_model_deployment(self.wml_client, deployment_name=self.DEPLOYMENT_NAME)
         self.wml_client.set.default_project(self.project_id) if self.project_id else None
@@ -452,7 +431,7 @@ class TestAutoAIRemote(unittest.TestCase):
 
     def test_33_score_batch_deployed_model(self):
         scoring_params = self.service_batch.run_job(
-            payload=self.train_data.drop(columns=[self.prediction_column]),
+            payload=self.train_data.drop(columns=[self.prediction_column])[:100],
             background_mode=False)
         print(scoring_params)
         print(self.service_batch.get_job_result(scoring_params['metadata']['id']))
