@@ -18,17 +18,12 @@ from ibm_watson_machine_learning.experiment.autoai.optimizers import RemoteAutoP
 from ibm_watson_machine_learning.utils.autoai.errors import NotExistingCOSResource, ForecastingUnsupportedOperation
 
 from ibm_watson_machine_learning.tests.utils import (get_wml_credentials, get_cos_credentials, bucket_exists,
-                                                        bucket_name_gen, get_space_id, is_cp4d)
-from ibm_watson_machine_learning.tests.utils.cleanup import bucket_cleanup, space_cleanup, delete_model_deployment
+                                                     create_bucket, get_space_id, is_cp4d)
+from ibm_watson_machine_learning.tests.utils.cleanup import space_cleanup, delete_model_deployment
 
 from ibm_watson_machine_learning.utils.autoai.enums import PositiveLabelClass, TShirtSize, Transformers
 
 
-from lale import wrap_imported_operators
-from lale.operators import TrainablePipeline
-from lale.lib.lale import Hyperopt
-
-
 class TestAutoAIRemote(unittest.TestCase):
     """
     The test can be run on CLOUD, WMLS and CPD (not tested)
@@ -95,6 +90,14 @@ class TestAutoAIRemote(unittest.TestCase):
         Load WML credentials from config.ini file based on ENV variable.
         """
         cls.wml_credentials = get_wml_credentials()
+        try:
+            del cls.wml_credentials['bedrock_url']
+        except:
+            pass
+        try:
+            del cls.wml_credentials['password']
+        except:
+            pass
         cls.wml_client = APIClient(wml_credentials=cls.wml_credentials.copy())
 
         if not cls.wml_client.ICP:
@@ -130,15 +133,7 @@ class TestAutoAIRemote(unittest.TestCase):
         )
         # Prepare bucket
         if not bucket_exists(cos_resource, self.bucket_name):
-            try:
-                bucket_cleanup(cos_resource, prefix=f"{self.bucket_name}-")
-            except Exception as e:
-                print(f"Bucket cleanup with prefix {self.bucket_name}- failed due to:\n{e}\n skipped")
-
-            import datetime
-            TestAutoAIRemote.bucket_name = bucket_name_gen(prefix=f"{self.bucket_name}-{str(datetime.date.today())}")
-            print(f"Creating COS bucket: {TestAutoAIRemote.bucket_name}")
-            cos_resource.Bucket(TestAutoAIRemote.bucket_name).create()
+            TestAutoAIRemote.bucket_name = create_bucket(cos_resource, self.bucket_name)
 
             self.assertIsNotNone(TestAutoAIRemote.bucket_name)
             self.assertTrue(bucket_exists(cos_resource, TestAutoAIRemote.bucket_name))
