@@ -1,5 +1,9 @@
 import unittest
-from sklearn.externals import joblib
+
+try:
+    from sklearn.externals import joblib
+except ImportError:
+    import joblib
 
 from ibm_watson_machine_learning.helpers import pipeline_to_script
 
