@@ -120,7 +120,7 @@ class Training(WMLResource):
         training_uid = str_type_conv(training_uid)
         Training._validate_type(training_uid, 'training_uid', STR_TYPE, False)
 
-        url = self._href_definitions.get_trainings_href()
+        url = self._client.service_instance._href_definitions.get_trainings_href()
 
         return self._get_artifact_details(url, training_uid, limit, 'trained models')
 
@@ -428,7 +428,7 @@ class Training(WMLResource):
                 else:
                     raise WMLClientError("It is mandatory to set the space/project id. Use client.set.default_space(<SPACE_UID>)/client.set.default_project(<PROJECT_UID>) to proceed.")
 
-        train_endpoint = self._href_definitions.get_trainings_href()
+        train_endpoint = self._client.service_instance._href_definitions.get_trainings_href()
         if not self._ICP:
             if self._client.CLOUD_PLATFORM_SPACES:
                 params = self._client._params()
@@ -465,7 +465,11 @@ class Training(WMLResource):
 
         run_details = self._handle_response(201, u'training', response_train_post)
 
-        trained_model_guid = self.get_uid(run_details)
+        try:
+            trained_model_guid = self.get_id(run_details)
+
+        except Exception:
+            trained_model_guid = self.get_uid(run_details)
 
         if asynchronous is True:
             return run_details
@@ -513,9 +517,9 @@ class Training(WMLResource):
         self._client._check_if_either_is_set()
         details = self.get_details(limit=limit)
         resources = details[u'resources']
-        values = [(m[u'metadata'][u'guid'], m[u'entity'][u'status'][u'state'], m[u'metadata'][u'created_at']) for m in resources]
+        values = [(m[u'metadata'].get('id', m[u'metadata'].get('guid')), m[u'entity'][u'status'][u'state'], m[u'metadata'][u'created_at']) for m in resources]
 
-        self._list(values, [u'GUID (training)', u'STATE', u'CREATED'], limit, 50)
+        self._list(values, [u'ID (training)', u'STATE', u'CREATED'], limit, 50)
 
     def list_subtrainings(self, training_uid):
         """
@@ -524,7 +528,7 @@ class Training(WMLResource):
            **Parameters**
 
            .. important::
-                #. **training_uid**:  Training GUID\n
+                #. **training_uid**:  Training ID\n
                    **type**: str\n
 
            **Output**
@@ -557,9 +561,9 @@ class Training(WMLResource):
         )
         details_json = self._handle_response(200, "Get training details", details_parent)
         resources = details_json["resources"]
-        values = [(m[u'metadata'][u'guid'], m[u'entity'][u'status'][u'state'], m[u'metadata'][u'created_at']) for m in resources]
+        values = [(m[u'metadata'].get('id', m[u'metadata'].get('guid')), m[u'entity'][u'status'][u'state'], m[u'metadata'][u'created_at']) for m in resources]
 
-        self._list(values, [u'GUID (sub_training)', u'STATE', u'CREATED'], None, 50)
+        self._list(values, [u'ID (sub_training)', u'STATE', u'CREATED'], None, 50)
 
     def list_intermediate_models(self, training_uid):
         """
@@ -568,7 +572,7 @@ class Training(WMLResource):
            **Parameters**
 
            .. important::
-                #. **training_uid**:  Training GUID\n
+                #. **training_uid**:  Training ID\n
                    **type**: str\n
 
            **Output**
@@ -682,10 +686,10 @@ class Training(WMLResource):
                 params.update({'hard_delete': u'true'})
 
         if not self._ICP and not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_PLATFORM_SPACES:
-            response_delete = requests.delete(self._href_definitions.get_training_href(training_uid),
+            response_delete = requests.delete(self._client.service_instance._href_definitions.get_training_href(training_uid),
                                           headers=self._client._get_headers(),params=params)
         else:
-            response_delete = requests.delete(self._href_definitions.get_training_href(training_uid),
+            response_delete = requests.delete(self._client.service_instance._href_definitions.get_training_href(training_uid),
                                               headers=self._client._get_headers(),params=params,verify=False)
 
         if response_delete.status_code == 400 and \
@@ -728,7 +732,7 @@ class Training(WMLResource):
 
                 else:
                     try:
-                        key = "data/" + run_details["metadata"]["guid"] + "/pipeline-model.json"
+                        key = "data/" + run_details["metadata"].get("id", run_details["metadata"].get('guid')) + "/pipeline-model.json"
 
                         obj = client_cos.get_object(Bucket=bucket, Key=key)
                         pipeline_model = json.loads((obj['Body'].read().decode('utf-8')))
@@ -787,7 +791,7 @@ class Training(WMLResource):
                 key = logs + "/learner-1/evaluation-metrics.txt"
             else:
                 try:
-                    key = run_details["metadata"]["guid"] + "/pipeline-model.json"
+                    key = run_details["metadata"].get("id", run_details["metadata"].get('guid')) + "/pipeline-model.json"
 
                     obj = client_cos.get_object(Bucket=bucket, Key=key)
 
