@@ -59,7 +59,8 @@ __all__ = [
     'NoAvailableMetrics',
     'WrongAssetType',
     'TSNotSupported',
-    'InvalidDataAsset'
+    'InvalidDataAsset',
+    'ParamOutOfRange'
 ]
 
 from ibm_watson_machine_learning.utils import WMLClientError
@@ -313,3 +314,7 @@ class InvalidDataAsset(WMLClientError, ValueError):
     def __init__(self, reason='Wrong Data Asset'):
         WMLClientError.__init__(self, "Data Asset without 'connection' is not supported for result store action.",
                                 reason)
+
+class ParamOutOfRange(WMLClientError, ValueError):
+    def __init__(self, param_name, value, min, max):
+        WMLClientError.__init__(self, f"Value of parameter `{param_name}`, {value}, is out of expected range - between {min} and {max}.")
