@@ -1220,7 +1220,7 @@ def create_summary(details: dict, scoring: str) -> 'DataFrame':
                     enhancements.append('HPO')
                 if 'cognito' in steps:
                     enhancements.append('FE')
-                if 'Text_FE' in steps:
+                if 'TextTransformer' in pipeline['context']['intermediate_model']['pipeline_nodes']:
                     enhancements.append('Text_FE')
 
                 enhancements = ', '.join(enhancements)
