@@ -226,7 +226,7 @@ def save_computed_pipelines_for_ui(wml_client: 'APIClient', run_id: str) -> None
         generated_path = f"{remote_path}{output}"
 
         response = requests.get(
-            url=f"{wml_client.data_assets._href_definitions.get_wsd_model_attachment_href()}auto_ml/{generated_path}",
+            url=f"{wml_client.service_instance._href_definitions.get_wsd_model_attachment_href()}auto_ml/{generated_path}",
             headers=wml_client._get_headers(),
             params={'space_id': wml_client.default_space_id,
                     'flat': 'true'},
@@ -242,7 +242,7 @@ def save_computed_pipelines_for_ui(wml_client: 'APIClient', run_id: str) -> None
             create_dir(generated_local_path)
 
             response_with_file = requests.get(
-                url=f"{wml_client.data_assets._href_definitions.get_wsd_model_attachment_href()}auto_ml/{generated_path}/{pipeline_dir}/{file_name}",
+                url=f"{wml_client.service_instance._href_definitions.get_wsd_model_attachment_href()}auto_ml/{generated_path}/{pipeline_dir}/{file_name}",
                 headers=wml_client._get_headers(),
                 params={'space_id': wml_client.default_space_id},
                 verify=False)
