@@ -64,10 +64,10 @@ class Volume(WMLResource):
                   'include_service_status':True
                   }
         if not self._ICP:
-            response = requests.get(self._href_definitions.volume_href(volume_id),
+            response = requests.get(self._client.service_instance._href_definitions.volume_href(volume_id),
                                     headers=self._client._get_headers(zen=True))
         else:
-            response = requests.get(self._href_definitions.volume_href(volume_id),
+            response = requests.get(self._client.service_instance._href_definitions.volume_href(volume_id),
                                       headers=self._client._get_headers(zen=True), verify=False)
         if response.status_code == 200:
             return response.json()
@@ -170,13 +170,13 @@ class Volume(WMLResource):
         try:
             if self._client.CLOUD_PLATFORM_SPACES:
                 creation_response = requests.post(
-                    self._href_definitions.volumes_href(),
+                    self._client.service_instance._href_definitions.volumes_href(),
                     headers=self._client._get_headers(zen=True),
                     json=input_meta
                 )
 
             else:
-                creation_response = requests.post(self._href_definitions.volumes_href(),
+                creation_response = requests.post(self._client.service_instance._href_definitions.volumes_href(),
                         headers=self._client._get_headers(zen=True),
                         json=input_meta,
                         verify=False
@@ -221,7 +221,7 @@ class Volume(WMLResource):
         WMLResource._chk_and_block_create_update_for_python36(self)
         if not self._client.ICP_PLATFORM_SPACES and not self._client.CLOUD_PLATFORM_SPACES:
             raise WMLClientError("Volume APIs are not supported. It is supported only for CP4D 3.5")
-        start_url = self._href_definitions.volume_service_href(name)
+        start_url = self._client.service_instance._href_definitions.volume_service_href(name)
         # Start the volume  service
         start_data = {}
         try:
@@ -284,7 +284,7 @@ class Volume(WMLResource):
         zen_token = header_input.get('Authorization')
 
         filename_to_upload = file_path.split('/')[-1]
-        upload_url_file = self._href_definitions.volume_upload_href(name) + filename_to_upload
+        upload_url_file = self._client.service_instance._href_definitions.volume_upload_href(name) + filename_to_upload
         cmd_str = 'curl -k  -X PUT "' + upload_url_file + '"' + "  -H 'Content-Type: multipart/form-data' -H 'Authorization: " + zen_token + \
                   "' -F upFile='@" + file_path + "'"
         args = shlex.split(cmd_str)
@@ -324,15 +324,15 @@ class Volume(WMLResource):
        #
        #
        #  filename_to_upload = file_path.split('/')[-1]
-       #  #upload_url_file = self._href_definitions.volume_upload_href(name) +
-       #  upload_url_file = self._href_definitions.volume_upload_href(name) + "wmldir/"
-       # #  #upload_url_file = self._href_definitions.volume_upload_href(name) +
+       #  #upload_url_file = self._client.service_instance._href_definitions.volume_upload_href(name) +
+       #  upload_url_file = self._client.service_instance._href_definitions.volume_upload_href(name) + "wmldir/"
+       # #  #upload_url_file = self._client.service_instance._href_definitions.volume_upload_href(name) +
        # #  import urllib
-       # #  upload_url_file = self._href_definitions.volume_upload_href(name)  + urllib.parse.quote(filename_to_upload, safe='')
+       # #  upload_url_file = self._client.service_instance._href_definitions.volume_upload_href(name)  + urllib.parse.quote(filename_to_upload, safe='')
        # #  print(upload_url_file)
        #  import urllib
-       #  upload_url_file = self._href_definitions.volume_upload_href(name) + filename_to_upload
-       #  #upload_url_file = urllib.parse.quote(self._href_definitions.volume_upload_href(name) + "wmldir/" +filename_to_upload, safe='')
+       #  upload_url_file = self._client.service_instance._href_definitions.volume_upload_href(name) + filename_to_upload
+       #  #upload_url_file = urllib.parse.quote(self._client.service_instance._href_definitions.volume_upload_href(name) + "wmldir/" +filename_to_upload, safe='')
        #  files = {'upload_file': (filename_to_upload,  open(file_path, 'rb'))}
        #
        #  with open(file_path, 'rb') as f:
@@ -380,7 +380,7 @@ class Volume(WMLResource):
             >>> client.volumes.list()
         """
 
-        href = self._href_definitions.volumes_href()
+        href = self._client.service_instance._href_definitions.volumes_href()
         params = {}
         params.update({'addon_type': 'volumes'})
         if not self._ICP:
@@ -492,10 +492,10 @@ class Volume(WMLResource):
             raise WMLClientError(u'Volume API is not supported.')
 
         if not self._ICP:
-            response = requests.delete(self._href_definitions.volume_href(volume_id),
+            response = requests.delete(self._client.service_instance._href_definitions.volume_href(volume_id),
                                        headers=self._client._get_headers(zen=True))
         else:
-            response = requests.delete(self._href_definitions.volume_href(volume_id),
+            response = requests.delete(self._client.service_instance._href_definitions.volume_href(volume_id),
                                       headers=self._client._get_headers(zen=True), verify=False)
 
         if response.status_code == 200 or response.status_code == 204:
@@ -533,10 +533,10 @@ class Volume(WMLResource):
             raise WMLClientError(u'Volume API is not supported.')
 
         if not self._ICP:
-            response = requests.delete(self._href_definitions.volume_service_href(volume_name),
+            response = requests.delete(self._client.service_instance._href_definitions.volume_service_href(volume_name),
                                        headers=self._client._get_headers(zen=True))
         else:
-            response = requests.delete(self._href_definitions.volume_service_href(volume_name),
+            response = requests.delete(self._client.service_instance._href_definitions.volume_service_href(volume_name),
                                        headers=self._client._get_headers(zen=True), verify=False)
         if response.status_code == 200:
             print("Successfully stopped volume service.")
