@@ -26,7 +26,8 @@ __all__ = [
     "ForbiddenActionForPlan",
     "NoVirtualDeploymentSupportedForICP",
     "MissingArgument",
-    "WrongEnvironmentVersion"
+    "WrongEnvironmentVersion",
+    "CannotAutogenerateBedrockUrl"
 ]
 
 
@@ -91,4 +92,11 @@ class WrongEnvironmentVersion(WMLClientError, ValueError):
         WMLClientError.__init__(self, "Version used in credentials not supported in this environment",
                                 reason=f"Version {used_version} isn't supported in "
                                        f"{environment_name} environment, "
-                                       f"select from {supported_versions}")
\ No newline at end of file
+                                       f"select from {supported_versions}")
+
+
+class CannotAutogenerateBedrockUrl(WMLClientError, ValueError):
+    def __init__(self):
+        WMLClientError.__init__(self, "Attempt of generating `bedrock_url` automatically failed. "
+                                      "If iamintegration=True, please provide `bedrock_url` in wml_credentials. "
+                                      "If iamintegration=False, please validate your credentials.")
\ No newline at end of file
