@@ -41,14 +41,8 @@ class WMLResource:
 
         if (client.ICP or client.WSD) and not client.ICP_PLATFORM_SPACES:
             self._wml_credentials = client.wml_credentials
-            self._href_definitions = HrefDefinitions(client.wml_credentials)
         else:
             self._wml_credentials = client.service_instance._wml_credentials
-            self._href_definitions = HrefDefinitions(client.service_instance._wml_credentials,
-                                                     self._client.CLOUD_PLATFORM_SPACES,
-                                                     self._client.PLATFORM_URL,
-                                                     self._client.CAMS_URL,
-                                                     self._client.ICP_PLATFORM_SPACES)
 
     def _handle_response(self, expected_status_code, operationName, response, json_response=True):
         if "dele" in operationName or "cancel migration" == operationName:
@@ -160,11 +154,11 @@ class WMLResource:
     def _check_if_lib_or_def(self, lib_uid):
 
         verify = False
-        lib_details = requests.get(self._href_definitions.get_custom_library_href(lib_uid),
+        lib_details = requests.get(self._client.service_instance._href_definitions.get_custom_library_href(lib_uid),
                                    headers=self._client._get_headers(), verify=verify)
         if lib_details.status_code == 200:
             return lib_details.json()["metadata"]["href"]
-        def_details = requests.get(self._href_definitions.get_model_definition_assets_href() + u'/' + lib_uid,
+        def_details = requests.get(self._client.service_instance._href_definitions.get_model_definition_assets_href() + u'/' + lib_uid,
                                    params=self._client._params(), headers=self._client._get_headers(), verify=verify)
         if def_details.status_code == 200:
             return def_details.json()["href"]
@@ -366,7 +360,7 @@ class WMLResource:
         params = self._client._params()
         if 'project_id' in params.keys():
             return 0
-        deployment_href = self._href_definitions.get_deployments_href() + "?asset_id=" + asset_id
+        deployment_href = self._client.service_instance._href_definitions.get_deployments_href() + "?asset_id=" + asset_id
         response_deployment = requests.get(deployment_href, params=self._client._params(),
                                            headers=self._client._get_headers(), verify=False)
         deployment_json = self._handle_response(200, "Get deployment details", response_deployment)
@@ -389,13 +383,13 @@ class WMLResource:
             if default_limit is not None and len(values) > default_limit:
                 print('Note: Only first {} records were displayed. To display more use \'limit\' parameter.'.format(default_limit))
         else:
-            table = tabulate([header] + values)
+            table = tabulate([header] + values[:limit])
             print(table)
 
     def _wsd_list_assets(self, asset_type, limit=None):
         _DEFAULT_LIST_LENGTH = 50
         ##For CP4D, check if either spce or project ID is set
-        href = self._href_definitions.get_wsd_asset_search_href(asset_type)
+        href = self._client.service_instance._href_definitions.get_wsd_asset_search_href(asset_type)
         if limit is None:
             data = {
                 "query": "*:*"
@@ -463,7 +457,7 @@ class WMLResource:
 
         params = self._client._params()
         headers = self._client._get_headers()
-        url = self._href_definitions.get_wsd_model_href()
+        url = self._client.service_instance._href_definitions.get_wsd_model_href()
 
         if asset_type != 'wml_model_definition':
             cams_entity = copy.deepcopy(input_payload)
@@ -478,7 +472,7 @@ class WMLResource:
                 "name": asset_type
             }
             atype_payload = json.dumps(atype_body, separators=(',', ':'))
-            atype_url = self._href_definitions.get_wsd_asset_type_href()
+            atype_url = self._client.service_instance._href_definitions.get_wsd_asset_type_href()
             aheaders = {
                 'Content-Type': "application/json"
             }
@@ -512,12 +506,12 @@ class WMLResource:
                 else:
                     file_name_to_attach = 'function_attachment'
                 if asset_type == 'data_asset':
-                    content_upload_url = self._href_definitions.get_wsd_model_attachment_href() + \
+                    content_upload_url = self._client.service_instance._href_definitions.get_wsd_model_attachment_href() + \
                                          urllib.parse.quote(asset_type + "/" + input_payload['name'],safe='')
                 else:
-                    content_upload_url = self._href_definitions.get_wsd_model_attachment_href() + \
+                    content_upload_url = self._client.service_instance._href_definitions.get_wsd_model_attachment_href() + \
                                      urllib.parse.quote(asset_type + "/" + asset_uid + "/" + file_name_to_attach, safe='')
-                attach_url = self._href_definitions.get_model_definition_assets_href() + "/" + \
+                attach_url = self._client.service_instance._href_definitions.get_model_definition_assets_href() + "/" + \
                              urllib.parse.quote(asset_uid + "/attachments")
                 if type(path_to_archive) is STR_TYPE:
                     with open(path_to_archive, 'rb') as f:
@@ -586,21 +580,23 @@ class WMLResource:
 
     def _wsd_delete_asset(self, asset_type, asset_id):
         asset_uid = str_type_conv(asset_id)
-        delete_endpoint = self._href_definitions.get_model_definition_assets_href() + "/" + asset_uid
+        delete_endpoint = self._client.service_instance._href_definitions.get_model_definition_assets_href() + "/" + asset_uid
         self._logger.debug(u'Deletion artifact {} endpoint: {}'.format(asset_type, delete_endpoint))
         response_delete = requests.delete(delete_endpoint, params=self._client._params(),
                                               headers=self._client._get_headers(), verify=False)
         return response_delete
 
     def _wsd_get_asset_details(self, asset_type, asset_id, limit=None):
-        url = self._href_definitions.get_model_definition_assets_href()
+        url = self._client.service_instance._href_definitions.get_model_definition_assets_href()
         return self._get_artifact_details(url, asset_id, limit, asset_type)
 
     def _wsd_get_required_element_from_response(self, response_data):
         WMLResource._validate_type(response_data, u'model response', dict)
         try:
             if self._client.default_project_id is not None and self._client.WSD:
-                href = "/v2/assets/" + response_data['metadata']['asset_type'] + "/" +response_data['metadata']['asset_id'] + "?" + "project_id=" + response_data['metadata']['project_id']
+                href = self._client.service_instance._href_definitions.get_base_asset_with_type_href(
+                    response_data['metadata']['asset_type'],
+                    response_data['metadata']['asset_id']) + "?" + "project_id=" + response_data['metadata']['project_id']
                 metadata_val = {'project_id': response_data['metadata']['project_id'],
                                        'asset_id': response_data['metadata']['asset_id'],
                                        'href': href,
@@ -661,7 +657,7 @@ class WMLResource:
     def _create_revision_artifact_for_assets(self, uid, resource_name):
         op_name = 'Creation revision for {}'.format(resource_name)
 
-        url = self._href_definitions.get_asset_href(uid) + "/revisions"
+        url = self._client.service_instance._href_definitions.get_asset_href(uid) + "/revisions"
         commit_message = "Revision creation for " + resource_name + " " + uid
 
         payload_json = {
@@ -696,7 +692,7 @@ class WMLResource:
 
         if current_attachment_id is not None:
             # Delete existing attachment to upload new attachment
-            attachments_id_url = self._href_definitions.get_asset_href(
+            attachments_id_url = self._client.service_instance._href_definitions.get_asset_href(
                 asset_id) + '/attachments/' + current_attachment_id
 
             if not self._ICP:
@@ -719,7 +715,7 @@ class WMLResource:
                 "name": "attachment_" + asset_id
             }
 
-            attachments_url = self._href_definitions.get_asset_href(asset_id) + '/attachments'
+            attachments_url = self._client.service_instance._href_definitions.get_asset_href(asset_id) + '/attachments'
 
             # STEP 3b.
             # Get the signed url from CAMS to upload the attachment
@@ -766,14 +762,14 @@ class WMLResource:
                     # Mark attachment complete
                     if not self._ICP:
                         complete_response = requests.post(
-                            self._href_definitions.get_attachment_href(asset_id, attachment_id) + "/complete",
+                            self._client.service_instance._href_definitions.get_attachment_href(asset_id, attachment_id) + "/complete",
                             headers=self._client._get_headers(),
                             params=self._client._params()
 
                         )
                     else:
                         complete_response = requests.post(
-                            self._href_definitions.get_attachment_href(asset_id, attachment_id) + "/complete",
+                            self._client.service_instance._href_definitions.get_attachment_href(asset_id, attachment_id) + "/complete",
                             headers=self._client._get_headers(),
                             params=self._client._params(),
                             verify=False
