@@ -81,3 +81,21 @@ def get_party_router(router, party_proto_handler):
         '{}'.format(MessageType.STOP.value): party_proto_handler.handle_request,
         'default': default_end_point
     })
+
+
+def get_authority_router(router, authority_proto_handler):
+    """
+    Route for authority party
+
+    :param router: Router object
+    :type router: `Router`
+    :param authority_proto_handler: ProtoHandler object
+    :type authority_proto_handler: `ProtoHandler`
+    :return: None
+    """
+    router.add_routes({
+        '{}'.format(MessageType.PUBLIC_PARAMETER.value): authority_proto_handler.handle_request_public_parameter,
+        '{}'.format(MessageType.SECRET_KEY.value): authority_proto_handler.handle_request_secret_key,
+        '{}'.format(MessageType.DECRYPT_KEY.value): authority_proto_handler.handle_request_decrypt_key,
+        'default': default_end_point
+    })
