@@ -12,6 +12,7 @@ Module providing utility functions helpful for preproccessing data
 import numpy as np
 import pandas as pd
 from sklearn import preprocessing
+from diffprivlib import tools as dp
 import logging
 
 from ibmfl.exceptions import FLException
@@ -303,10 +304,23 @@ def get_reweighing_weights(data, sensitive_attribute, columns):
 
     tmp_unp_train_data = training_dataset[training_dataset[sensitive_attribute] == 0]
     tmp_p_train_data = training_dataset[training_dataset[sensitive_attribute] == 1]
-    unpriv_neg = tmp_unp_train_data['class'].value_counts()[0]/nrows
-    unpriv_pos = tmp_unp_train_data['class'].value_counts()[1] / nrows
-    priv_neg = tmp_p_train_data['class'].value_counts()[0] / nrows
-    priv_pos = tmp_p_train_data['class'].value_counts()[1] / nrows
+
+    if len(tmp_unp_train_data) > 0:
+        unpriv_neg = tmp_unp_train_data['class'].value_counts()[0]/nrows
+        if sum(tmp_unp_train_data['class']) > 0:
+            unpriv_pos = tmp_unp_train_data['class'].value_counts()[1]/nrows
+        else:
+            unpriv_pos = 0
+    else:
+        unpriv_neg = 0
+    if len(tmp_p_train_data) > 0:
+        priv_neg = tmp_p_train_data['class'].value_counts()[0]/nrows
+        if sum(tmp_p_train_data['class']) > 0:
+            priv_pos = tmp_p_train_data['class'].value_counts()[1]/nrows
+        else:
+            priv_pos = 0
+    else:
+        priv_pos = 0
 
     weight = []
     for index, row in training_dataset.iterrows():
@@ -320,3 +334,63 @@ def get_reweighing_weights(data, sensitive_attribute, columns):
             weight.append(priv * pos / priv_pos)
 
     return np.array(weight)
+
+def get_hist_counts(data, sensitive_attribute, columns, eps):
+    """
+    Calculates noisy counts for reweighing with differential privacy (epsilon set in
+    datahandler), assuming:
+    * privileged group has sensitive attribute value = 1, unprivileged group is 0
+    * positive class has value = 1, negative class is 0
+    weight = P_expected(sensitive_attribute & class)/P_observed(sensitive_attribute & class)
+
+    :param data: Provided dataset, assume each row is a data sample and
+    each column is one feature.
+    :type data: `tuple` of `nd.array`
+    :param sensitive_attribute: Sensitive attribute
+    :type sensitive_attribute: `str`
+    :param columns: dataset column names
+    :type columns: `list`
+    :param eps: epsilon utilized for differential privacy
+    :type eps: `float`
+    :return: counts
+    :rtype: `dict`
+    """
+    (features, labels) = data
+    counts = {}
+
+    training_dataset = pd.DataFrame(data=features)
+    class_values = labels.tolist()
+
+    training_dataset.columns = columns
+    training_dataset['class'] = class_values
+
+    data_whole = training_dataset[[sensitive_attribute, 'class']]
+    data_whole_0 = data_whole[data_whole[sensitive_attribute] == 0]
+    data_whole_0_t = data_whole_0.T
+
+    data_whole_0_t = np.array(data_whole_0_t)
+    dp_hist_0, dp_bins_0 = dp.histogram(data_whole_0_t[1], bins=2, epsilon=eps)
+    counts['unp_neg'] = dp_hist_0[0]
+    counts['unp_pos'] = dp_hist_0[1]
+
+    data_whole_1 = data_whole[data_whole[sensitive_attribute] == 1]
+    data_whole_1_t = data_whole_1.T
+
+    data_whole_1_t = np.array(data_whole_1_t)
+    dp_hist_1, dp_bins_1 = dp.histogram(data_whole_1_t[1], bins=2, epsilon=eps)
+    counts['p_neg'] = dp_hist_1[0]
+    counts['p_pos'] = dp_hist_1[1]
+
+    tmp_unp_train_data = training_dataset[training_dataset[sensitive_attribute] == 0]
+    tmp_p_train_data = training_dataset[training_dataset[sensitive_attribute] == 1]
+    unpriv_neg = tmp_unp_train_data['class'].value_counts()[0]
+    unpriv_pos = tmp_unp_train_data['class'].value_counts()[1]
+    priv_neg = tmp_p_train_data['class'].value_counts()[0]
+    priv_pos = tmp_p_train_data['class'].value_counts()[1]
+
+    counts['unpriv_neg'] = unpriv_neg
+    counts['unpriv_pos'] = unpriv_pos
+    counts['priv_neg'] = priv_neg
+    counts['priv_pos'] = priv_pos
+
+    return counts
