@@ -33,4 +33,7 @@ class MessageType(Enum):
     SYNC_MODEL = 12
     DECRYPT_FUSED = 13
     STOP = 14
+    PUBLIC_PARAMETER = 15
+    SECRET_KEY = 16
+    DECRYPT_KEY = 17
     ERROR_AUTH = 400
