@@ -9,8 +9,10 @@ irrespective of what has been deposited with the U.S. Copyright Office.
 
 from __future__ import print_function
 import time
+import uuid
 import pickle
 import logging
+from functools import partial
 
 from sklearn.utils.validation import check_is_fitted
 from sklearn.ensemble._hist_gradient_boosting.loss import *
@@ -20,14 +22,14 @@ from sklearn.utils.multiclass import check_classification_targets
 from sklearn.metrics import check_scoring, accuracy_score, r2_score
 from sklearn.utils import check_X_y, check_random_state, check_array
 from sklearn.ensemble._hist_gradient_boosting.grower import TreePredictor
+from sklearn.ensemble._hist_gradient_boosting.common import X_DTYPE, X_BINNED_DTYPE
 
 from ibmfl.util import fl_metrics
 from ibmfl.util import config
 from ibmfl.model.fl_model import FLModel
 from ibmfl.util.xgboost.utils import is_classifier
 from ibmfl.util.xgboost.export import export_sklearn
-from ibmfl.exceptions import LocalTrainingException, \
-    ModelInitializationException, ModelException
+from ibmfl.exceptions import ModelInitializationException, ModelException
 from ibmfl.util.xgboost.hyperparams import init_parameters, \
     validate_parameters
 
@@ -39,7 +41,7 @@ class XGBFLModel(FLModel, ABC):
     Wrapper class implementation for XGBoost containing the XGBoost Model Object
     """
 
-    def __init__(self, model_type, model_spec, xgb_model=None, **kwargs):
+    def __init__(self, model_name, model_spec, xgb_model=None, **kwargs):
         """
         Create a XGBFLModel instance for XGBoost model based either on an
         existing model object or an entirely new model object.
@@ -54,7 +56,7 @@ class XGBFLModel(FLModel, ABC):
          to initialize a XGBoost model.
         :type kwargs: `dict`
         """
-        super().__init__(model_type, model_spec, **kwargs)
+        super().__init__(model_name, model_spec, **kwargs)
 
         # Initialize Input Model Object Parameters
         # Note: For model loading process, onboard from `xgb_model` parameter.
@@ -66,12 +68,16 @@ class XGBFLModel(FLModel, ABC):
         self._raw_predictions = None
         self.n_features_ = 0
         self.loss_ = None
+        self._in_fit = False
 
         # Validate and Initialize Model Hyperparameters
         validate_parameters(model_spec)
         init_parameters(self, model_spec)
 
-    def fit_model(self, train_data, fit_params=None):
+        # Generate Party-Based UUID (For Model + Metrics Persistence)
+        self.party_uuid = str(uuid.uuid4())
+
+    def fit_model(self, train_data, fit_params=None, **kwargs):
         """
         This function is not implemented as model training is not operated
         within the FL Model object and is part of an external process.
@@ -100,7 +106,7 @@ class XGBFLModel(FLModel, ABC):
             else:
                 raise ValueError('Provided model object is not of the correct '
                                  'data type. Should be a `list`. '
-                                 'Type provided ' + str(type(model_update)))
+                                 'Type provided: ' + str(type(model_update)))
 
     def _raw_predict(self, x):
         """
@@ -118,18 +124,22 @@ class XGBFLModel(FLModel, ABC):
 
         # Initialize Prediction Object
         n_samples = x.shape[0]
-        preds = np.zeros(shape=(self.n_trees, n_samples), dtype=np.float64)
-
-        # Append Null Model Predictions
-        if self._baseline_prediction is not None:
-            preds += self._baseline_prediction
-        elif self._raw_predictions is not None:
-            preds += self._raw_predictions
+        is_binned = getattr(self, '_in_fit', False)
 
         # Generate Predictions
+        preds = np.zeros(shape=(self.n_trees, n_samples))
+        if self._baseline_prediction != None:
+            preds += self._baseline_prediction
         for p in self._predictors:
             for k, p_i in enumerate(p):
-                preds[k, :] += p_i.predict(x)
+                if is_binned:
+                    predict = partial(
+                        p_i.predict_binned,
+                        missing_values_bin_idx=self.bin_mapper_.missing_values_bin_idx_
+                    )
+                else:
+                    predict = p_i.predict
+                preds[k, :] += predict(x)
 
         return preds
 
@@ -169,7 +179,9 @@ class XGBFLModel(FLModel, ABC):
         :return: filename
         """
         if filename is None:
-            filename = self.model_type + '_{}.pickle'.format(time.time())
+            file = self.model_name if self.model_name else self.model_type
+            filename = '{}_{}.pickle'.format(file, self.party_uuid)
+
         full_path = super().get_model_absolute_path(filename)
 
         # Scikit-Learn Export Demo
@@ -230,8 +242,8 @@ class XGBFLModel(FLModel, ABC):
         """
 
         if type(test_dataset) is tuple:
-            x_test = test_dataset[0]
-            y_test = test_dataset[1]
+            x_test = test_dataset[0].astype(X_DTYPE)
+            y_test = test_dataset[1].astype(Y_DTYPE)
 
             return self.evaluate_model(x_test, y_test)
 
@@ -359,8 +371,8 @@ class XGBClassifierFLModel(XGBFLModel):
         if self.classes_.shape[0] != self.num_classes:
             raise ValueError('Number of classes defined in configuration file '
                              'and the classes derived from the data does not '
-                             'match. Found %d classes, while config file '
-                             'is defined as %d classes.'.format(
+                             'match. Found {0} classes, while config file '
+                             'is defined as {1} classes.'.format(
                              self.classes_.shape[0], self.num_classes))
 
         if self.loss == 'auto':
@@ -445,6 +457,7 @@ class XGBClassifierFLModel(XGBFLModel):
         acc = {}
         if len(self._predictors) > 0:
             y_hat = self.predict(x)
+
             correct = 0
             for i in range(x.shape[0]):
                 if y_hat[i] == y[i]:
@@ -453,7 +466,6 @@ class XGBClassifierFLModel(XGBFLModel):
             acc = {'acc': correct/float(len(y))}
             additional_metrics = fl_metrics.get_eval_metrics_for_classificaton(
                 y, y_hat)
-
             acc = {**acc, **additional_metrics}
             return acc
         else:
