@@ -49,7 +49,8 @@ class Party:
         :type config_dict: `dict`
         :return None
         """
-        configure_logging_from_file()
+        log_level = kwargs.get('log_level', 'INFO')
+        configure_logging_from_file(log_level=log_level)
 
         config_file = kwargs.get('config_file')
         config_dict = kwargs.get('config_dict')
@@ -185,6 +186,8 @@ class Party:
                     returnValue = False
             else:
                 logger.error('Registration Failed: Failure status from aggregator')
+                if response is not None:
+                    logger.error(response.get_data().get('detail', "No Detail Provided"))
         except Exception as ex:
             logger.error("Error occurred during registration" + str(ex))
 
@@ -236,6 +239,8 @@ class Party:
                 logger.info('Listening for commands from Aggregator')
                 self.is_running = True
                 self.initialize_model_config()
+            else:
+                self.stop_connection()
         else:
             logger.info('Party already running.')
 
@@ -317,16 +322,18 @@ if __name__ == '__main__':
     parser.add_argument('-s', '--self_signed_cert', help='flag for self-signed certificate', action='store_true')
     parser.add_argument('-i', '--interactive',
                         help='run interactively', action='store_true')
-
+    parser.add_argument('log_level', type=str, default="INFO", required=False,
+                        help='log_level should be a value from [DEBUG, INFO, WARNING, ERROR, CRITICAL]')
     args = parser.parse_args()
 
-    
     if (args.self_signed_cert):
         self_signed_cert_arg = True
     else:
         self_signed_cert_arg = None
 
-    p = Party(config_file=args.config_file, token=args.token, self_signed_cert=self_signed_cert_arg)
+    p = Party(config_file=args.config_file, token=args.token, self_signed_cert=self_signed_cert_arg,
+              log_level=args.log_level)
+
     if (args.interactive):
         # Indefinite loop to accept user commands to execute
         while 1:
