@@ -13,12 +13,12 @@ import importlib
 
 from warnings import warn
 
-required_libraries = ["tensorflow==2.1.0", "scikit-learn==0.23.1",
-                        "keras==2.2.4", "numpy==1.17.4", "pandas", "pytest",
-                        "PyYAML", "parse", "websockets", "jsonpickle", "requests",
+required_libraries = ["tensorflow==2.4.1", "sklearn==0.23.2", "torch==1.7.1",
+                        "keras==2.2.4", "numpy", "pandas", "pytest",
+                        "yaml", "parse", "websockets", "jsonpickle", "requests",
                         "scipy==1.4.1", "environs", "pathlib2", "diffprivlib",
                         "psutil", "setproctitle", "tabulate", "lz4",
-                        "opencv-python", "gym", "ray==0.8.0", "cloudpickle==1.3.0", "image"]
+                        "cv2", "gym", "ray==0.8.0", "cloudpickle==1.3.0", "image"]
 
 
 for lib in required_libraries:
