@@ -51,7 +51,7 @@ def read_yaml_config(config_file):
 
 
 def configure_logging_from_file(config_file='log_config.yaml',
-                                log_level=logging.INFO):
+                                log_level='INFO'):
     """
     configures logging for application based on the configuration file
 
@@ -60,10 +60,10 @@ def configure_logging_from_file(config_file='log_config.yaml',
             based on the required granularity
     :return: a boolean object. False for default basic config True otherwise
     """
-
+    log_level = logging.getLevelName(log_level)
     config = read_yaml_config(config_file)
 
-    result = log_config.configure_logging(config, log_level=logging.INFO)
+    result = log_config.configure_logging(config, log_level)
 
     return result
 
@@ -106,6 +106,26 @@ def get_party_config(**kwargs):
         return get_config_from_args(**kwargs)
 
 
+def get_authority_config(**kwargs):
+    """
+    Retrieve connections settings from config file or arguments
+
+    :param \\*\\*kwargs: Arguments that are passed into the party instance
+    """
+
+    if not kwargs:
+        raise InvalidConfigurationException(
+            'No arguments given to Authority at runtime')
+
+    config_file = kwargs.get('config_file')
+
+    if config_file:
+        logger.info('Getting config from file')
+        return get_config_from_file(config_file=config_file)
+    else:
+        return get_config_from_args(**kwargs)
+
+
 def get_config_from_file(config_file):
     """
     Reads a yaml file and resolves the string configuration to appropriate
@@ -159,6 +179,7 @@ def get_cls_by_config(config_dict):
     # TODO: since all the configuration blocks carry same signature this
     # should be done in iterative way for all keys in the dictionary
     cls_config['data'] = get_data_from_config(config_dict.get('data'))
+    cls_config['metrics_recorder'] = get_mrec_from_config(config_dict.get('metrics_recorder'))
     cls_config['model'] = get_model_from_config(config_dict.get('model'))
     cls_config['fusion'] = get_fusion_from_config(config_dict.get('fusion'))
     cls_config['connection'] = get_connection_from_config(
@@ -169,6 +190,9 @@ def get_cls_by_config(config_dict):
     cls_config['aggregator'] = config_dict.get('aggregator')
     cls_config['local_training'] = get_lt_from_config(
         config_dict.get('local_training'))
+    cls_config['privacy'] = config_dict.get('privacy')
+    cls_config['metrics'] = get_mh_from_config(config_dict.get('metrics'))
+    cls_config['key_generators'] = config_dict.get('key_generators')
 
     return cls_config
 
@@ -284,7 +308,7 @@ def get_fusion_from_config(config):
                 'Error occurred while loading fusion config.')
 
     else:
-        logger.info('No fusion config provided for this setup.')
+        logger.debug('No fusion config provided for this setup.')
 
     return fusion_config
 
@@ -302,7 +326,8 @@ def get_ph_from_config(config):
         try:
             ph_config['cls_ref'] = get_class_by_name(
                 config['path'], config['name'])
-
+            if 'info' in config:
+                ph_config['info'] = config['info']
         except Exception as ex:
             logger.exception(ex)
 
@@ -338,11 +363,88 @@ def get_lt_from_config(config):
                 'Error occurred while loading local training config.')
 
     else:
-        logger.info('No local training config provided for this setup.')
+        logger.debug('No local training config provided for this setup.')
 
     return lt_config
 
 
+def get_mh_from_config(config):
+    """ Load data class information from params provided in config file
+    :param config: dictionary of configuration
+    :type config: `dict`
+    :return: dictionary of class references
+    :rtype: `dict`
+    """
+    # TODO: validation needs to be added
+    mh_config = None
+    if config:
+        mh_config = {}
+        try:
+            mh_config['cls_ref'] = get_class_by_name(
+                config['path'], config['name'])
+            mh_config['info'] = config.get('info')
+        except InvalidConfigurationException as ex:
+            logger.exception(ex)
+            raise InvalidConfigurationException(
+                'Error occurred while loading mh config.')
+
+    else:
+        logger.info('No data config provided for this setup.')
+    return mh_config
+
+
+def get_mrec_from_config(config):
+    """ Load metrics recorder class information from params provided in config file
+    :param config: dictionary of configuration
+    :type config: `dict`
+    :return: dictionary of class references
+    :rtype: `dict`
+    """
+    # TODO: validation needs to be added
+    pm_config = None
+    if config:
+        pm_config = {}
+        try:
+            pm_config['cls_ref'] = get_class_by_name(
+                config['path'], config['name'])
+            pm_config['output_file'] = config['output_file']
+            pm_config['output_type'] = config['output_type']
+            pm_config['compute_pre_train_eval'] = config['compute_pre_train_eval']
+            pm_config['compute_post_train_eval'] = config['compute_post_train_eval']
+        except InvalidConfigurationException as ex:
+            logger.exception(ex)
+            raise InvalidConfigurationException(
+                'Error occured while loading data config.')
+
+    else:
+        logger.info('No metrics recorder config provided for this setup.')
+    return pm_config
+
+
+def get_key_generator_from_config(config):
+    """ Load data class information from params provided in config file
+    :param config: dictionary of configuration
+    :type config: `dict`
+    :return: dictionary of class references
+    :rtype: `dict`
+    """
+    key_generator_config = None
+    if config:
+        key_generator_config = {}
+        try:
+            key_generator_config['cls_ref'] = get_class_by_name(
+                config['path'], config['name'])
+            key_generator_config['sec_config'] = config.get('sec_config')
+        except InvalidConfigurationException as ex:
+            logger.exception(ex)
+            raise InvalidConfigurationException(
+                'Error occurred while loading mh config.')
+
+    else:
+        logger.info('No data config provided for this setup.')
+    return key_generator_config
+
+
 def get_class_by_name(path, name_class):
     """
     Gets object according to the name_class and the path where it is located.
@@ -360,8 +462,7 @@ def get_class_by_name(path, name_class):
     except Exception as ex:
         logger.exception(ex)
         raise InvalidConfigurationException(
-            'Error occurred while loading class %s', name_class,
-            'from path %s', path)
+            'Error occurred while loading class '+name_class+'from path ' + path)
     return cls_ref
 
 
@@ -386,8 +487,7 @@ def get_attr_from_path(path, attr):
             module = loader.load_module()
         else:
             raise InvalidConfigurationException(
-                "File does not exists! " + "file with given path "
-                + path+" not found in both current and working directory!!")
+                "File does not exist. "+path+" not found in current or working directory.")
 
     else:
         module = importlib.import_module(path)
@@ -427,7 +527,7 @@ def get_absolute_path(path):
 
     if file_path.is_absolute == True and not file_path.exists():
         raise InvalidConfigurationException(
-            "File does not exists! " + "file with given path " + path+" not found!!")
+            "File does not exist. "+path+" not found.")
 
     elif get_current_dir_ap(path):
         absolute_path = get_current_dir_ap(path)
@@ -437,7 +537,7 @@ def get_absolute_path(path):
 
     if absolute_path is None or os.path.exists(absolute_path) is False:
         raise InvalidConfigurationException(
-            "File does not exists! " + "could not find file !" + path + 'in both current and working directory')
+            "File does not exist. "+path+" not found in current or working directory.")
 
     return absolute_path
 
@@ -502,10 +602,10 @@ def convert_zip_to_bytes(filename):
 
         except InvalidConfigurationException as ex:
             logger.error(str(ex))
-            raise InvalidConfigurationException("Zip file does not exist!")
+            raise InvalidConfigurationException("Zip file does not exist.")
         except Exception as identifier:
             raise FLException(
-                "Error while converting zip file to bytes!")
+                "Error while converting zip file to bytes.")
 
     return byte_arr
 
@@ -525,4 +625,4 @@ def convert_bytes_to_zip(byte_arr, destination_file):
 
     except Exception as identifier:
         raise FLException(
-            "Error while creating a file at!" + destination_file)
+            "Error while creating a file at " + destination_file)
