@@ -39,7 +39,7 @@ def validate_parameters(hyperparams):
             raise ValueError('Global parameters have not been defined.')
 
         if 'learning_rate' in params:
-            if params['learning_rate'] < 0:
+            if params['learning_rate'] <= 0:
                 raise ValueError('learning_rate={} must be strictly '
                                  'positive'.format(params['learning_rate']))
         else:
@@ -98,9 +98,9 @@ def validate_parameters(hyperparams):
             raise ValueError('max_iter has not been defined.')
 
         if 'max_depth' in params:
-            if params['max_depth'] is not None and params['max_depth'] <= 1:
+            if params['max_depth'] is not None and params['max_depth'] < 0:
                 raise ValueError('max_depth={} must be strictly greater'
-                                 'than 1.'.format(params['max_leaf_nodes']))
+                                 'than 0.'.format(params['max_depth']))
 
         if 'max_leaf_nodes' in params:
             if params['max_leaf_nodes'] is not None and params['max_leaf_nodes'] <= 1:
@@ -114,7 +114,7 @@ def validate_parameters(hyperparams):
 
     except Exception as ex:
         logger.exception(str(ex))
-        raise HyperparamsException('Defined global hyperparameters malformed.')
+        raise HyperparamsException('Defined global hyperparameters malformed. '+str(ex))
 
 
 def init_parameters(obj, hyperparameters):
